@@ -1,7 +1,7 @@
 import { __, s__ } from '~/locale';
 
 export const I18N_DELETION_PROTECTION = {
-  label: s__('DeletionSettings|Deletion protection'),
+  label: s__('DeletionSettings|Retention period'),
   helpText: s__(
     'DeletionSettings|Period that deleted groups and projects will remain restorable for.',
   ),
