@@ -19,18 +19,17 @@ export default (containerId = 'js-jobs-table') => {
     return false;
   }
 
-  const { fullPath, jobStatuses, pipelineEditorPath, emptyStateSvgPath, admin } =
-    containerEl.dataset;
+  const { fullPath, jobStatuses, pipelineEditorPath, admin, projectId } = containerEl.dataset;
 
   return new Vue({
     el: containerEl,
     apolloProvider,
     provide: {
-      emptyStateSvgPath,
       fullPath,
       pipelineEditorPath,
       jobStatuses: JSON.parse(jobStatuses),
       admin: parseBoolean(admin),
+      projectId,
     },
     render(createElement) {
       return createElement(JobsTableApp);
