@@ -2,7 +2,7 @@ import Vue from 'vue';
 import VueApollo from 'vue-apollo';
 import VueRouter from 'vue-router';
 import createDefaultClient from '~/lib/graphql';
-import { showAlertFromLocalStorage } from '../local_storage_alert/show_alert_from_local_storage';
+import { showAlertFromLocalStorage } from '~/lib/utils/local_storage_alert';
 import AdminRunnerShowApp from './admin_runner_show_app.vue';
 
 Vue.use(VueApollo);
