@@ -1,8 +1,10 @@
-import { Mark } from '@tiptap/core';
+import { Mark, markInputRule } from '@tiptap/core';
 import { Fragment } from '@tiptap/pm/model';
 import Code from '@tiptap/extension-code';
 import { EXTENSION_PRIORITY_LOWER } from '../constants';
 
+export const inputRegex = /(^|[^`])`([^`]+)`(?!`)$/;
+
 export default Code.extend({
   excludes: null,
 
@@ -25,6 +27,15 @@ export default Code.extend({
     ];
   },
 
+  addInputRules() {
+    return [
+      markInputRule({
+        find: inputRegex,
+        type: this.type,
+      }),
+    ];
+  },
+
   addKeyboardShortcuts() {
     return {
       ArrowRight: () => {
