@@ -8,7 +8,6 @@ export const useLegacyDiffs = defineStore('legacyDiffs', {
   state() {
     return {
       isLoading: true,
-      isTreeLoaded: false,
       batchLoadingState: null,
       retrievingBatches: false,
       addedLines: null,
@@ -29,21 +28,16 @@ export const useLegacyDiffs = defineStore('legacyDiffs', {
       mergeRequestDiffs: [],
       mergeRequestDiff: null,
       diffViewType: INLINE_DIFF_VIEW_TYPE,
-      tree: [],
-      treeEntries: {},
       currentDiffFileId: '',
       projectPath: '',
-      viewedDiffFileIds: {},
       commentForms: [],
       highlightedRow: null,
-      renderTreeList: true,
       showWhitespace: true,
       viewDiffsFileByFile: false,
       fileFinderVisible: false,
       dismissEndpoint: '',
       showSuggestPopover: true,
       defaultSuggestionCommitMessage: '',
-      mrReviews: {},
       latestDiff: true,
       virtualScrollerDisabled: false,
       linkedFileHash: null,
