@@ -1,5 +1,6 @@
 const WORK_ITEM_TYPE_INCIDENT = 'incident';
 const WORK_ITEM_TYPE_ISSUE = 'issue';
+const WORK_ITEM_TYPE_TICKET = 'ticket';
 
 export const SUPPORT_BOT_USERNAME = 'support-bot';
 
@@ -19,7 +20,10 @@ const isIssuableIncident = (data) => {
 };
 
 const isIssuableServiceDeskIssue = (data) => {
-  return data?.issueType === WORK_ITEM_TYPE_ISSUE && data?.authorUsername === SUPPORT_BOT_USERNAME;
+  return (
+    data?.issueType === WORK_ITEM_TYPE_TICKET ||
+    (data?.issueType === WORK_ITEM_TYPE_ISSUE && data?.authorUsername === SUPPORT_BOT_USERNAME)
+  );
 };
 
 export const isLegacyIssueType = (issuableData) => {
