@@ -1,48 +1,9 @@
 import $ from 'jquery';
-import { defer, memoize } from 'lodash';
+import { defer } from 'lodash';
+import { NO_SCROLL_TO_HASH_CLASS } from '~/lib/utils/constants';
+import { getScrollingElement } from '~/lib/utils/panels';
 import { contentTop } from './common_utils';
 
-const DEFAULT_PANEL_SCROLL_CONTAINER_SELECTOR = '.js-static-panel-inner';
-const DYNAMIC_PANEL_SCROLL_CONTAINER_SELECTOR = '.js-dynamic-panel-inner';
-
-export const getPanelElement = (contextElement) => {
-  if (!contextElement) return null;
-  return (
-    contextElement.closest(
-      [DEFAULT_PANEL_SCROLL_CONTAINER_SELECTOR, DYNAMIC_PANEL_SCROLL_CONTAINER_SELECTOR].join(','),
-    ) || null
-  );
-};
-
-const getPanelScrollingElement = (contextElement) => {
-  return (
-    getPanelElement(contextElement) ||
-    document.querySelector(DEFAULT_PANEL_SCROLL_CONTAINER_SELECTOR) ||
-    document.scrollingElement
-  );
-};
-
-const getApplicationScrollingElement = (contextElement) => {
-  if (window.gon?.features?.projectStudioEnabled) {
-    // We still return `document.scrollingElement` for pages that don't have panels, like login or error pages
-    return getPanelScrollingElement(contextElement) || document.scrollingElement;
-  }
-  return document.scrollingElement;
-};
-
-/**
- * Finds a known scrolling element according to the element provided.
- * If the element is not provided, it defaults to the default panel.
- *
- * If no panel is found, it returns document.scrollingElement.
- * If `projectStudioEnabled` is disabled, it returns the document.scrollingElement.
- *
- * It is memoized for results with the same element.
- *
- * @param {Element} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is used.
- */
-export const getScrollingElement = memoize(getApplicationScrollingElement);
-
 const getScrollBehavior = (behavior = 'smooth') => {
   if (behavior === 'smooth' && window.matchMedia(`(prefers-reduced-motion: reduce)`).matches) {
     // Check if user prefers reduced motion, return 'auto' if true, otherwise return 'smooth'.
@@ -56,7 +17,7 @@ const getScrollBehavior = (behavior = 'smooth') => {
  * Checks if container (or document if container is not found) is scrolled
  * down all the way to the bottom.
  *
- * @param {Element} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is used.
+ * @param {HTMLElement} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is used.
  * @returns {Boolean}
  */
 export const isScrolledToBottom = (contextElement) => {
@@ -70,7 +31,7 @@ export const isScrolledToBottom = (contextElement) => {
 /**
  * Checks if container (or document if container is not found) is scrolled to the top
  *
- * @param {Element} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is used.
+ * @param {HTMLElement} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is used.
  * @returns {Boolean}
  */
 export const isScrolledToTop = (contextElement) => {
@@ -82,7 +43,7 @@ export const isScrolledToTop = (contextElement) => {
 /**
  * Scroll to the bottom of the scrolling element.
  *
- * @param {Element} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is scrolled.
+ * @param {HTMLElement} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is scrolled.
  */
 export const scrollDown = (contextElement) => {
   const scrollingElement = getScrollingElement(contextElement);
@@ -94,7 +55,7 @@ export const scrollDown = (contextElement) => {
 /**
  * Scroll to the bottom of the scrolling element.
  *
- * @param {Element} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is scrolled.
+ * @param {HTMLElement} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is scrolled.
  */
 export const scrollUp = (contextElement) => {
   getScrollingElement(contextElement).scrollTo({ top: 0 });
@@ -103,7 +64,7 @@ export const scrollUp = (contextElement) => {
 /**
  * Scrolls to the top  of the scrolling element with smooth behavior, respecting user's motion preferences.
  *
- * @param {Element} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is scrolled.
+ * @param {HTMLElement} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is scrolled.
  */
 export const smoothScrollTop = (contextElement) => {
   getScrollingElement(contextElement).scrollTo({ top: 0, behavior: getScrollBehavior() });
@@ -113,7 +74,7 @@ export const smoothScrollTop = (contextElement) => {
  * Scrolls to the provided location.
  *
  * @param {ScrollToOptions} options The options to pass to Element.scrollTo
- * @param {Element} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is scrolled.
+ * @param {HTMLElement} [contextElement] The element to find the scrolling element. If not provided, the default panel or document.scrollingElement is scrolled.
  */
 export const scrollTo = (options, contextElement) => {
   getScrollingElement(contextElement).scrollTo(options);
@@ -156,3 +117,22 @@ export const scrollToElement = (element, options = {}) => {
     });
   }
 };
+
+/**
+ * Prevents scrolling to an element when clicking links with the URL fragment (a[href="#foo"])
+ *
+ * @param {PointerEvent} event Link click event
+ */
+export const preventScrollToFragment = (event) => {
+  const link = event.target.closest('a[href]');
+  if (!link) return;
+  event.preventDefault();
+  const hash = link.href.split('#')[1];
+  const target = document.getElementById(hash);
+  if (!target) return;
+  target.classList.add(NO_SCROLL_TO_HASH_CLASS);
+  const { scrollLeft, scrollTop } = getScrollingElement(link);
+  // replaceHistory won't highlight the element
+  window.location.hash = hash;
+  scrollTo({ top: scrollTop, left: scrollLeft }, target);
+};
