@@ -4,16 +4,13 @@ import initSettingsPipelinesTriggers from '~/ci_settings_pipeline_triggers';
 import initVariableList from '~/ci/ci_variable_list';
 import initInheritedGroupCiVariables from '~/ci/inherited_ci_variables';
 import initDeployFreeze from '~/deploy_freeze';
-import { initInstanceRunnersToggle } from '~/projects/settings/init_instance_runners_toggle';
 import initRefSwitcherBadges from '~/projects/settings/mount_ref_switcher_badges';
 import initSettingsPanels from '~/settings_panels';
 import { initTokenAccess } from '~/token_access';
 import { initCiSecureFiles } from '~/ci_secure_files';
 import initDeployTokens from '~/deploy_tokens';
-import { initProjectRunnersRegistrationDropdown } from '~/ci/runner/project_runners/register';
 import { initProjectRunnersSettings } from '~/ci/runner/project_runners_settings/index';
 import { initGeneralPipelinesOptions } from '~/ci_settings_general_pipeline';
-import { renderGFM } from '~/behaviors/markdown/render_gfm';
 
 // Initialize expandable settings panels
 initSettingsPanels();
@@ -38,12 +35,8 @@ initSettingsPipelinesTriggers();
 initArtifactsSettings();
 initVariablesMinimumOverrideRole();
 
-initProjectRunnersRegistrationDropdown();
-initInstanceRunnersToggle();
 initRefSwitcherBadges();
 initTokenAccess();
 initCiSecureFiles();
 initGeneralPipelinesOptions();
 initProjectRunnersSettings();
-
-renderGFM(document.getElementById('js-shared-runners-markdown'));
