@@ -51,14 +51,11 @@ export const modelExperimentsHelpPath = helpPagePath(
 
 export const modelRegistryHelpPath = helpPagePath('user/project/ml/model_registry/_index.md');
 
-export const extendedPratExpiryWebhooksExecuteHelpPath = helpPagePath(
-  'user/project/settings/_index.md',
-  { anchor: 'add-additional-webhook-triggers-for-project-access-token-expiration' },
-);
-
 export const duoHelpPath = helpPagePath('user/gitlab_duo/_index');
 export const amazonQHelpPath = helpPagePath('user/duo_amazon_q/_index.md');
-export const duoContextExclusionHelpPath = helpPagePath('user/gitlab_duo/context_exclusion');
+export const duoContextExclusionHelpPath = helpPagePath('user/gitlab_duo/context', {
+  anchor: 'exclude-context-from-gitlab-duo',
+});
 export const duoFlowHelpPath = helpPagePath('user/duo_agent_platform/flows/_index.md');
 
 export const pipelineExecutionPoliciesHelpPath = helpPagePath(
