@@ -1,6 +1,6 @@
 import Vue from 'vue';
 import { parseBoolean } from '~/lib/utils/common_utils';
-import ProjectDeleteButton from './components/project_delete_button.vue';
+import DeleteButton from './components/shared/delete_button.vue';
 
 export default (selector = '#js-project-delete-button') => {
   const el = document.querySelector(selector);
@@ -17,13 +17,15 @@ export default (selector = '#js-project-delete-button') => {
     forksCount,
     starsCount,
     buttonText,
+    markedForDeletion,
+    permanentDeletionDate,
   } = el.dataset;
 
   // eslint-disable-next-line no-new
   new Vue({
     el,
     render(createElement) {
-      return createElement(ProjectDeleteButton, {
+      return createElement(DeleteButton, {
         props: {
           confirmPhrase,
           nameWithNamespace,
@@ -34,6 +36,8 @@ export default (selector = '#js-project-delete-button') => {
           forksCount: parseInt(forksCount, 10),
           starsCount: parseInt(starsCount, 10),
           buttonText,
+          markedForDeletion: parseBoolean(markedForDeletion),
+          permanentDeletionDate,
         },
       });
     },
