@@ -76,7 +76,7 @@ export default function initHeaderApp({ router, isReadmeView = false, isBlobView
       showEditButton,
       showWebIdeButton,
       showGitpodButton,
-      showPipelineEditorUrl,
+      showPipelineEditorButton,
       webIdeUrl,
       editUrl,
       pipelineEditorUrl,
@@ -116,7 +116,7 @@ export default function initHeaderApp({ router, isReadmeView = false, isBlobView
         showEditButton: parseBoolean(showEditButton),
         showWebIdeButton: parseBoolean(showWebIdeButton),
         isGitpodEnabledForInstance: parseBoolean(showGitpodButton),
-        showPipelineEditorUrl: parseBoolean(showPipelineEditorUrl),
+        showPipelineEditorButton: parseBoolean(showPipelineEditorButton),
         webIdeUrl,
         editUrl,
         pipelineEditorUrl,
