@@ -169,7 +169,18 @@ module Ci
     end
 
     def process_build(build, params, queue_size:, queue_depth:)
-      return remove_from_queue!(build) unless build.pending?
+      unless build.pending?
+        build = refresh_build(build)
+
+        # If refreshed_build is nil, that means the primary no longer has the
+        # record of the build ID. We have a foreign key constraint that ensures
+        # the queue entry has been removed, so let's just return here.
+        return ResultFactory.invalid unless build.present?
+
+        # Recheck the status to ensure that the build is pending because we refreshed
+        # from the primary. Otherwise remove it from the pending list.
+        return remove_from_queue!(build) unless build.pending?
+      end
 
       if runner_matched?(build)
         @metrics.increment_queue_operation(:build_can_pick)
@@ -218,6 +229,27 @@ module Ci
       nil
     end
 
+    def refresh_build(build)
+      # Check the primary to be absolutely sure the build state isn't
+      # stale before removing from queue. ::Ci::Runner.sticking.find_caught_up_replica
+      # should have picked an up-to-date replica for the build, but if that's not
+      # working properly this is a defensive measure.
+      refreshed_build = ::Gitlab::Database::LoadBalancing::SessionMap
+        .with_sessions.use_primary do
+        Ci::Build.in_partition(build).find_by_id(build.id)
+      end
+
+      if refreshed_build.present?
+        ::Gitlab::AppJsonLogger.info(message: "build refreshed from primary",
+          original_status: build.status,
+          refreshed_status: refreshed_build.status,
+          build_id: build.id,
+          class: self.class.to_s)
+      end
+
+      refreshed_build
+    end
+
     def max_queue_depth
       MAX_QUEUE_DEPTH
     end
@@ -225,22 +257,6 @@ module Ci
     def remove_from_queue!(build)
       @metrics.increment_queue_operation(:build_not_pending)
 
-      ##
-      # If the replica is not caught up, we should not remove the build from the queue.
-      # The build might actually be pending on the primary database, and removing it
-      # could cause it to be lost. Instead, we return an invalid result to signal
-      # the runner to retry.
-      #
-      unless @replica_caught_up
-        ::Gitlab::AppJsonLogger.info(message: "build left on pending queue because replica not caught up",
-          build_status: build.status,
-          build_id: build.id,
-          runner_id: runner.id,
-          runner_type: runner.runner_type)
-        @metrics.increment_queue_operation(:build_status_stale)
-        return ResultFactory.invalid
-      end
-
       ##
       # If this build can not be picked because we had stale data in
       # `ci_pending_builds` table, we need to respond with 409 to retry
@@ -252,7 +268,8 @@ module Ci
         build_status: build.status,
         build_id: build.id,
         runner_id: runner.id,
-        runner_type: runner.runner_type)
+        runner_type: runner.runner_type,
+        class: self.class.to_s)
       ResultFactory.invalid
     end
 
