@@ -5,13 +5,19 @@ module Gitlab
     module Models
       class Tag
         def self.normalize_tag_name(tag_name)
-          name = tag_name.split('_').map(&:capitalize).join(' ')
+          name = tag_name.split('_').join(' ').capitalize
+          apply_overrides(name)
+        end
+
+        def self.apply_overrides(text)
           overrides = Gitlab::GrapeOpenapi.configuration.tag_overrides
 
-          return name if overrides.nil? || overrides.empty?
+          return text if overrides.nil? || overrides.empty?
 
           pattern = Regexp.union(overrides.keys.map { |key| /\b#{Regexp.escape(key)}\b/i })
-          name.gsub(pattern) { |match| overrides[match] || overrides[match.downcase] || match }
+          text.gsub(pattern) do |match|
+            overrides[match] || overrides[match.downcase] || overrides[match.capitalize] || match
+          end
         end
 
         attr_reader :name
@@ -28,7 +34,9 @@ module Gitlab
         end
 
         def description
-          "Operations concerning #{name}"
+          desc_name = name.downcase
+          desc_adjusted = self.class.apply_overrides(desc_name)
+          "Operations related to #{desc_adjusted}."
         end
       end
     end
