@@ -6,8 +6,8 @@ module API
       include ::API::Helpers::Presentable
 
       expose :stats, using: Entities::CommitStats, if: :include_stats
-      expose :status_for, as: :status, documentation: { type: 'string', example: 'success' }
-      expose :project_id, documentation: { type: 'integer', example: 1 }
+      expose :status_for, as: :status, documentation: { type: 'String', example: 'success' }
+      expose :project_id, documentation: { type: 'Integer', example: 1 }
 
       expose :last_pipeline, documentation: { type: ::API::Entities::Ci::PipelineBasic.to_s } do |commit, options|
         pipeline = commit.lazy_latest_pipeline if can_read_pipeline?
