@@ -4,7 +4,10 @@ module Authn
   module Tokens
     class DeployToken
       def self.prefix?(plaintext)
-        plaintext.start_with?(::DeployToken::DEPLOY_TOKEN_PREFIX)
+        deploy_token_prefixes = [::DeployToken.prefix_for_deploy_token,
+          ::DeployToken::DEPLOY_TOKEN_PREFIX].uniq
+
+        plaintext.start_with?(*deploy_token_prefixes)
       end
 
       attr_reader :revocable, :source
