@@ -17,13 +17,15 @@ module Gitlab
     CREATE_RUNNER_SCOPE = :create_runner
     MANAGE_RUNNER_SCOPE = :manage_runner
     MCP_SCOPE = :mcp
+    GRANULAR_SCOPE = :granular
     API_SCOPES = [
       API_SCOPE, READ_API_SCOPE,
       READ_USER_SCOPE,
       CREATE_RUNNER_SCOPE, MANAGE_RUNNER_SCOPE,
       K8S_PROXY_SCOPE,
       SELF_ROTATE_SCOPE,
-      MCP_SCOPE
+      MCP_SCOPE,
+      GRANULAR_SCOPE
     ].freeze
 
     # Scopes for Duo
@@ -131,7 +133,7 @@ module Gitlab
           oauth_access_token_check(password) ||
           personal_access_token_check(password, project) ||
           deploy_token_check(login, password, project) ||
-          user_with_password_for_git(login, password) ||
+          user_with_password_for_git(login, password, request: request) ||
           Gitlab::Auth::Result::EMPTY
 
         rate_limit!(rate_limiter, success: result.success?, login: login, request: request)
@@ -152,7 +154,7 @@ module Gitlab
       # different mechanisms, as in `.find_for_git_client`. This may lead to
       # unwanted access locks when the value provided for `password` was actually
       # a PAT, deploy token, etc.
-      def find_with_user_password(login, password, increment_failed_attempts: false)
+      def find_with_user_password(login, password, increment_failed_attempts: false, request: nil)
         # Avoid resource intensive checks if login credentials are not provided
         return unless login.present? && password.present?
 
@@ -165,31 +167,26 @@ module Gitlab
 
           break if user && !user.can_log_in_with_non_expired_password?
 
-          authenticators = []
-
-          if user
-            authenticators << Gitlab::Auth::OAuth::Provider.authentication(user, 'database')
-
-            # Add authenticators for all identities if user is not nil
-            user&.identities&.each do |identity|
-              authenticators << Gitlab::Auth::OAuth::Provider.authentication(user, identity.provider)
-            end
-          else
-            # If no user is provided, try LDAP.
-            #   LDAP users are only authenticated via LDAP
-            authenticators << Gitlab::Auth::Ldap::Authentication
-          end
-
-          authenticators.compact!
+          authenticators = password_authenticators_for_user(user)
 
           # return found user that was authenticated first for given login credentials
-          authenticated_user = authenticators.find do |auth|
-            authenticated_user = auth.login(login, password)
-            break authenticated_user if authenticated_user
+          authenticated_user, authenticator = authenticators.find do |authenticator|
+            authenticated_user = authenticator.login(login, password)
+            break authenticated_user, authenticator if authenticated_user
           end
 
           user_auth_attempt!(user, success: !!authenticated_user) if increment_failed_attempts
 
+          # Increase our visibility of authentication methods
+          if !!authenticated_user
+            # To mitigate the risk of large log volume we will log
+            # only when request is present, and use a Feature Flag with
+            # the request actor.
+            if request.present? && Feature.enabled?(:log_find_with_user_password, Feature.current_request)
+              log_authentication('Gitlab::Auth find_with_user_password succeeded', authenticated_user, authenticator, request: request)
+            end
+          end
+
           authenticated_user
         end
       end
@@ -255,11 +252,11 @@ module Gitlab
         Gitlab::Auth::Result.new(nil, project, :ci, build_authentication_abilities)
       end
 
-      def user_with_password_for_git(login, password)
+      def user_with_password_for_git(login, password, request: nil)
         # Prevent LDAP and database authentication attempts when password is a token
         return if password.present? && Authn::AgnosticTokenIdentifier.token?(password)
 
-        user = find_with_user_password(login, password)
+        user = find_with_user_password(login, password, request: request)
         return unless user
 
         if user.ldap_user? &&
@@ -272,7 +269,7 @@ module Gitlab
           )
         end
 
-        verifier = TwoFactorAuthVerifier.new(user)
+        verifier = TwoFactorAuthVerifier.new(user, treat_email_otp_as_2fa: true)
 
         if user.two_factor_enabled? || verifier.two_factor_authentication_enforced?
           raise Gitlab::Auth::MissingPersonalAccessTokenError
@@ -289,9 +286,8 @@ module Gitlab
             identity = ::Gitlab::Auth::Identity.link_from_oauth_token(token)
             return if identity && !identity.valid?
 
-            resource_owner_id = identity&.composite? ? identity.scoped_user.id : token.resource_owner_id
-            user = User.id_in(resource_owner_id).first
-            return unless user && user.can_log_in_with_non_expired_password?
+            user = User.id_in(token.resource_owner_id).first
+            return unless user && (user.can_log_in_with_non_expired_password? || valid_composite_identity?(user))
 
             Gitlab::Auth::Result.new(user, nil, :oauth, abilities_for_scopes(token.scopes))
           end
@@ -484,7 +480,8 @@ module Gitlab
 
       # Other available scopes
       def optional_scopes
-        all_available_scopes + OPENID_SCOPES + PROFILE_SCOPES + AI_WORKFLOW_SCOPES + DYNAMIC_SCOPES - DEFAULT_SCOPES
+        all_available_scopes + OPENID_SCOPES + PROFILE_SCOPES + AI_WORKFLOW_SCOPES + DYNAMIC_SCOPES - DEFAULT_SCOPES -
+          [GRANULAR_SCOPE]
       end
 
       def registry_scopes
@@ -529,11 +526,12 @@ module Gitlab
       def unavailable_scopes_for_resource(resource)
         unavailable_ai_features_scopes +
           unavailable_observability_scopes_for_resource(resource) +
-          unavailable_virtual_registry_scopes_for_resource(resource)
+          unavailable_virtual_registry_scopes_for_resource(resource) +
+          [GRANULAR_SCOPE]
       end
 
       def unavailable_ai_features_scopes
-        AI_WORKFLOW_SCOPES
+        AI_WORKFLOW_SCOPES + [MCP_SCOPE]
       end
 
       def unavailable_observability_scopes_for_resource(resource)
@@ -560,12 +558,51 @@ module Gitlab
         end
       end
 
+      def password_authenticators_for_user(user)
+        authenticators = []
+
+        if user
+          authenticators << Gitlab::Auth::OAuth::Provider.authentication(user, 'database')
+
+          # Add authenticators for all identities if user is not nil
+          user&.identities&.each do |identity|
+            authenticators << Gitlab::Auth::OAuth::Provider.authentication(user, identity.provider)
+          end
+        else
+          # If no user is provided, try LDAP.
+          #   LDAP users are only authenticated via LDAP
+          authenticators << Gitlab::Auth::Ldap::Authentication
+        end
+
+        authenticators.compact
+      end
+
       def user_auth_attempt!(user, success:)
         return unless user && Gitlab::Database.read_write?
         return user.unlock_access! if success
 
         user.increment_failed_attempts!
       end
+
+      def valid_composite_identity?(user)
+        user.composite_identity_enforced? && user.service_account?
+      end
+
+      def log_authentication(message, user, authenticator, request: nil)
+        # `authenticator` can be an instance or a class
+        authenticator_class_name = authenticator.is_a?(Class) ? authenticator.to_s : authenticator.class.to_s
+
+        Gitlab::AuthLogger.info(
+          message: message,
+          user_id: user.id,
+          username: user.username,
+          authenticator: authenticator_class_name,
+          remote_ip: request&.remote_ip,
+          request_method: request&.request_method,
+          path: request&.filtered_path,
+          ua: request&.user_agent
+        )
+      end
     end
   end
 end
