@@ -12,6 +12,17 @@ module Gitlab
       UPDATE_REFERENCES_SQL = "UPDATE %{ref_table} SET %{ref_column} = %{good_id} WHERE %{ref_column} IN (%{bad_ids})"
       DELETE_DUPLICATES_SQL = "DELETE FROM %{table_name} WHERE id IN (%{bad_ids})"
 
+      # Bulk update SQL with truncation handling
+      BULK_UPDATE_DUPLICATES_SQL = <<~SQL
+        UPDATE %{table_name}
+        SET %{column} = CASE
+          WHEN LENGTH(%{column}) + LENGTH('-dup-' || id::text) > %{max_length}
+          THEN LEFT(%{column}, %{max_length} - LENGTH('-dup-' || id::text)) || '-dup-' || id::text
+          ELSE %{column} || '-dup-' || id::text
+        END
+        WHERE id IN (%{bad_ids})
+      SQL
+
       FIND_DUPLICATE_SETS_SQL = <<~SQL
         SELECT ARRAY_AGG(id ORDER BY id ASC) as ids
         FROM %{table_name}
@@ -236,10 +247,29 @@ module Gitlab
             'references' => [
               {
                 'table' => 'container_repository_states',
-                'column' => 'container_repository_id'
+                'column' => 'container_repository_id',
+                'delete_orphaned' => true
               }
             ]
           }
+        },
+        'audit_events_group_external_streaming_destinations' => {
+          'unique_idx_group_destinations_on_name_category_group' => {
+            'columns' => %w[group_id category name],
+            'unique' => true,
+            'action' => 'update',
+            'column_to_update' => 'name',
+            'max_length' => 72
+          }
+        },
+        'audit_events_instance_external_streaming_destinations' => {
+          'unique_idx_instance_destinations_on_name_category' => {
+            'columns' => %w[category name],
+            'unique' => true,
+            'action' => 'update',
+            'column_to_update' => 'name',
+            'max_length' => 72
+          }
         }
       }.freeze
 
@@ -274,7 +304,14 @@ module Gitlab
 
             if index_config['unique']
               logger.info("Index is unique. Checking for duplicate data...")
-              deduplicate_data(table_name, index_config['columns'], index_config['references'])
+              deduplicate_data(
+                table_name,
+                index_config['columns'],
+                index_config['references'],
+                action: index_config['action'],
+                column_to_update: index_config['column_to_update'],
+                max_length: index_config['max_length']
+              )
             end
 
             if index_exists?(table_name, index_name)
@@ -296,13 +333,29 @@ module Gitlab
         connection.execute(sql) # rubocop:disable Database/AvoidUsingConnectionExecute -- Required for TimeoutHelpers
       end
 
-      def execute_local(sql, read_only: false)
+      def execute_local(sql, read_only: false, disable_index_scans: false)
         logger.info("SQL: #{sql}")
 
         return if dry_run && !read_only
 
         disable_statement_timeout do
-          yield
+          with_index_scans_disabled(disable_index_scans) do
+            yield
+          end
+        end
+      end
+
+      def with_index_scans_disabled(disable)
+        if disable
+          execute('SET enable_indexscan = OFF')
+          execute('SET enable_bitmapscan = OFF')
+        end
+
+        yield
+      ensure
+        if disable
+          execute('RESET enable_indexscan')
+          execute('RESET enable_bitmapscan')
         end
       end
 
@@ -317,12 +370,12 @@ module Gitlab
           index_name: connection.quote(index_name)
         )
 
-        execute_local(sql, read_only: true) do
+        execute_local(sql, read_only: true, disable_index_scans: true) do
           connection.select_value(sql)
         end.present?
       end
 
-      def deduplicate_data(table_name, columns, references)
+      def deduplicate_data(table_name, columns, references, action: nil, column_to_update: nil, max_length: nil)
         duplicate_sets = find_duplicate_sets(table_name, columns)
 
         unless duplicate_sets&.any?
@@ -332,6 +385,14 @@ module Gitlab
 
         logger.warn("Found #{duplicate_sets.count} duplicates in '#{table_name}' for columns: #{columns.join(',')}")
 
+        if action == 'update'
+          raise ArgumentError, "column_to_update must be specified when action is 'update'" unless column_to_update
+
+          deduplicate_data_with_updates(table_name, duplicate_sets, column_to_update, max_length)
+          return
+        end
+
+        # Default action: delete duplicates
         bad_id_to_good_id_mapping = generate_id_mapping(duplicate_sets)
         process_references(references, bad_id_to_good_id_mapping)
         delete_duplicates(table_name, bad_id_to_good_id_mapping)
@@ -361,6 +422,7 @@ module Gitlab
           ref_column = ref['column']
           column_type = ref['type']
           deduplication_column = ref['deduplication_column']
+          delete_orphaned = ref['delete_orphaned']
 
           unless table_exists?(ref_table)
             logger.info("Reference table '#{ref_table}' does not exist in database #{database_name}. Skipping.")
@@ -369,6 +431,8 @@ module Gitlab
 
           if column_type == 'array'
             handle_array_references(ref_table, ref_column, id_mapping)
+          elsif delete_orphaned
+            delete_orphaned_references(ref_table, ref_column, id_mapping)
           elsif deduplication_column.present?
             handle_duplicate_references(ref_table, ref_column, deduplication_column, id_mapping)
           else
@@ -377,6 +441,22 @@ module Gitlab
         end
       end
 
+      def delete_orphaned_references(ref_table, ref_column, id_mapping)
+        logger.info("Deleting orphaned references in '#{ref_table}' for column '#{ref_column}'...")
+
+        id_mapping.keys.each_slice(BATCH_SIZE) do |bad_ids_batch|
+          bad_ids_quoted = bad_ids_batch.map { |id| connection.quote(id) }.join(',')
+
+          sql = "DELETE FROM #{connection.quote_table_name(ref_table)} WHERE " \
+            "#{connection.quote_column_name(ref_column)} IN (#{bad_ids_quoted})"
+
+          execute_local(sql) do
+            deleted_count = connection.delete(sql)
+            logger.info("Deleted #{deleted_count} orphaned references in '#{ref_table}'")
+          end
+        end
+      end
+
       def handle_array_references(ref_table, ref_column, id_mapping)
         logger.info("Processing array references in '#{ref_table}.#{ref_column}'...")
 
@@ -390,7 +470,7 @@ module Gitlab
             bad_ids: bad_ids_quoted
           )
 
-          records = execute_local(sql, read_only: true) do
+          records = execute_local(sql, read_only: true, disable_index_scans: true) do
             connection.select_all(sql)
           end
 
@@ -435,7 +515,7 @@ module Gitlab
             bad_id: connection.quote(bad_id)
           )
 
-          records_with_both = execute_local(sql, read_only: true) do
+          records_with_both = execute_local(sql, read_only: true, disable_index_scans: true) do
             connection.select_values(sql)
           end
 
@@ -496,7 +576,7 @@ module Gitlab
           not_null_conditions: not_null_conditions
         )
 
-        execute_local(sql, read_only: true) do
+        execute_local(sql, read_only: true, disable_index_scans: true) do
           connection.select_all(sql)
         end
       end
@@ -520,6 +600,42 @@ module Gitlab
         end
       end
 
+      def deduplicate_data_with_updates(table_name, duplicate_sets, column_to_update, max_length)
+        logger.info("
+          Deduplicating by updating '#{column_to_update}' column in '#{table_name}' to preserve all configurations...
+        ")
+
+        duplicate_sets.each do |set|
+          ids = parse_pg_array(set['ids'])
+          good_id = ids.first
+          bad_ids = ids[1..]
+
+          original_value = connection.select_value(
+            "SELECT #{connection.quote_column_name(column_to_update)}
+            FROM #{connection.quote_table_name(table_name)}
+            WHERE id = #{good_id}"
+          )
+
+          logger.info("Keeping ID #{good_id} with #{column_to_update}='#{original_value}'")
+
+          # Bulk update all bad_ids in a single query
+          bad_ids.each_slice(BATCH_SIZE) do |bad_ids_batch|
+            sql = format(
+              BULK_UPDATE_DUPLICATES_SQL,
+              table_name: connection.quote_table_name(table_name),
+              column: connection.quote_column_name(column_to_update),
+              max_length: max_length || 255,
+              bad_ids: bad_ids_batch.join(',')
+            )
+
+            execute_local(sql) do
+              affected_rows = connection.update(sql)
+              logger.info("Bulk updated #{affected_rows} duplicate records in '#{table_name}'")
+            end
+          end
+        end
+      end
+
       def reindex_index(index_name)
         logger.info("Reindexing index '#{index_name}'...")
 
