@@ -6,6 +6,8 @@ module Gitlab
   module Orchestrator
     module Helpers
       module Utils
+        METRICS_FILENAME = "metrics.json"
+
         # Global tmp dir for file operations
         #
         # @return [String]
@@ -19,6 +21,13 @@ module Gitlab
         def self.config_dir
           @config_dir ||= File.join(Dir.home, ".gitlab-orchestrator").tap { |dir| FileUtils.mkdir_p(dir) }
         end
+
+        # Background process PID file for metrics collector
+        #
+        # @return [String]
+        def self.metrics_pid_file
+          @metrics_pid_file ||= File.join(config_dir, "collector.pid")
+        end
       end
     end
   end
