@@ -10,42 +10,38 @@ module QA
           super
 
           base.class_eval do
-            view 'app/assets/javascripts/design_management/components/design_notes/design_discussion.vue' do
-              element 'design-discussion-content'
+            view 'app/assets/javascripts/work_items/components/design_management/archive_design_button.vue' do
+              element 'confirm-archiving-button'
             end
 
-            view 'app/assets/javascripts/design_management/components/design_notes/design_note.vue' do
-              element 'note-text'
-            end
-
-            view 'app/assets/javascripts/design_management/components/design_notes/design_reply_form.vue' do
-              element 'note-textarea'
-              element 'save-comment-button'
-            end
-
-            view 'app/assets/javascripts/design_management/components/design_overlay.vue' do
-              element 'design-image-button'
-            end
-
-            view 'app/assets/javascripts/design_management/components/list/item.vue' do
+            view 'app/assets/javascripts/work_items/components/design_management/design_item.vue' do
               element 'design-file-name'
               element 'design-image'
               element 'design-status-icon'
             end
 
-            view 'app/assets/javascripts/design_management/pages/index.vue' do
+            view 'app/assets/javascripts/work_items/components/design_management/design_management_widget.vue' do
               element 'archive-button'
               element 'design-checkbox'
-              element 'design-dropzone-content'
-            end
-
-            view 'app/assets/javascripts/design_management/components/delete_button.vue' do
-              element 'confirm-archiving-button'
-            end
-
-            view 'app/assets/javascripts/work_items/components/design_management/design_management_widget.vue' do
               element 'design-item'
             end
+
+            view 'app/assets/javascripts/work_items/components/design_management/design_notes/design_discussion.vue' do
+              element 'design-discussion-content'
+            end
+
+            view 'app/assets/javascripts/work_items/components/design_management/design_notes/design_note.vue' do
+              element 'note-text'
+            end
+
+            view 'app/assets/javascripts/work_items/components/design_management/design_notes/design_reply_form.vue' do
+              element 'note-textarea'
+              element 'save-comment-button'
+            end
+
+            view 'app/assets/javascripts/work_items/components/design_management/design_preview/design_overlay.vue' do
+              element 'design-image-button'
+            end
           end
         end
 
@@ -69,15 +65,7 @@ module QA
           # It accepts a `class:` option, but that only works for class attributes
           # It doesn't work as a CSS selector.
           # So instead we use the name attribute as a locator
-
-          if work_item_enabled?
-            page.attach_file("design_file", design_file_path, make_visible: { display: 'block' }, match: :first)
-
-          else
-            within_element('design-dropzone-content') do
-              page.attach_file("upload_file", design_file_path, make_visible: { display: 'block' })
-            end
-          end
+          page.attach_file("design_file", design_file_path, make_visible: { display: 'block' }, match: :first)
 
           filename = ::File.basename(design_file_path)
 
@@ -113,15 +101,11 @@ module QA
         end
 
         def has_design?(filename)
-          if work_item_enabled?
-            has_element?('design-item', text: filename)
-          else
-            has_element?('design-file-name', text: filename)
-          end
+          has_element?('design-item', text: filename)
         end
 
         def has_no_design?(filename)
-          has_no_element?('design-file-name', text: filename)
+          has_no_element?('design-item', text: filename)
         end
 
         def has_created_icon?
