@@ -14,7 +14,7 @@ module QA
 
           pipeline_mappings test_on_cng: %w[cng-instance],
             test_on_gdk: %w[gdk-instance gdk-instance-gitaly-transactions gdk-instance-ff-inverse],
-            test_on_omnibus: %w[instance git-sha256-repositories relative-url]
+            test_on_omnibus: %w[git-sha256-repositories]
         end
       end
     end
