@@ -7,7 +7,7 @@ module QA
         class Create < All
           spec_glob_pattern "qa/specs/features/**/3_create/**/*_spec.rb"
 
-          pipeline_mappings test_on_omnibus: %w[praefect gitaly-transactions gitaly-reftables-backend]
+          pipeline_mappings test_on_omnibus: %w[praefect gitaly-reftables-backend]
         end
       end
     end
