@@ -7,7 +7,7 @@ module QA
         class Registry < Test::Instance::All
           tags :registry
 
-          pipeline_mappings test_on_cng: %w[cng-registry], test_on_omnibus: %w[registry]
+          pipeline_mappings test_on_cng: %w[cng-registry]
         end
       end
     end
