@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
 module QA
-  RSpec.describe 'Create' do
-    describe 'Create a new project from a template', product_group: :source_code do
+  RSpec.describe 'Create', feature_category: :source_code_management do
+    describe 'Create a new project from a template' do
       let(:project) { create(:project, name: 'templated-project', template_name: 'dotnetcore') }
 
       it 'commits via the api',
