@@ -22,7 +22,7 @@ module QA
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347822' do
         issue.visit!
 
-        Page::Project::Issue::Show.perform do |issue|
+        Page::Project::WorkItem::Show.perform do |issue|
           issue.add_design(design)
           issue.click_design(design_filename)
           issue.add_annotation(annotation)
