@@ -10,19 +10,6 @@ module QA
         load_web_ide
       end
 
-      context 'when a file with the same name already exists' do
-        let(:file_name) { 'README.md' }
-
-        it 'throws an error', testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/432899' do
-          Page::Project::WebIDE::VSCode.perform do |ide|
-            ide.create_new_file(file_name)
-
-            expect(ide)
-              .to have_message("A file or folder README.md already exists at this location")
-          end
-        end
-      end
-
       context 'when user adds a new file' do
         let(:file_name) { 'first_file.txt' }
 
