@@ -12,7 +12,7 @@ module QA
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/412799',
         quarantine: {
           type: :test_environment,
-          issue: "https://gitlab.com/gitlab-org/gitlab/-/issues/435585"
+          issue: "https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/24026"
         } do
         project = build(:project, path_with_namespace: 'gitlab-qa/container-registry-sanity').reload!
         project.visit!
