@@ -4,7 +4,8 @@ module QA
   RSpec.describe 'Package', :object_storage, :skip_fips_env, :external_api_calls, feature_category: :package_registry,
     quarantine: {
       only: {
-        job: /object_storage|cng-instance|release-environments-qa|qa_gke.*|qa_eks.*|debug_review_gke125/,
+        job:
+          /object_storage|cng-instance|cng-relative-url|release-environments-qa|qa_gke.*|qa_eks.*|debug_review_gke125/,
         condition: -> { QA::Support::FIPS.enabled? }
       },
       issue: 'https://gitlab.com/gitlab-org/gitlab/-/issues/417584',
@@ -37,7 +38,7 @@ module QA
       end
 
       it 'publishes, installs, and deletes a Conan package',
-        testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/348014' do
+        testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/562430' do
         conan_yaml = ERB.new(read_fixture('package_managers/conan',
           'conan_upload_install_package.yaml.erb')).result(binding)
 
