@@ -3,7 +3,10 @@
 module QA
   RSpec.describe 'Package', feature_category: :package_registry do
     describe 'npm Registry project level endpoint', :object_storage, :external_api_calls,
-      feature_category: :package_registry do
+      feature_category: :package_registry, quarantine: {
+        issue: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/14567',
+        type: :flaky
+      } do
       using RSpec::Parameterized::TableSyntax
       include Runtime::Fixtures
       include Support::Helpers::MaskToken
@@ -44,9 +47,9 @@ module QA
       end
 
       where(:case_name, :authentication_token_type, :token_name, :testcase) do
-        'using personal access token' | :personal_access_token | 'Personal access token' | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347592'
-        'using ci job token'          | :ci_job_token          | 'CI Job Token'          | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347594'
-        'using project deploy token'  | :project_deploy_token  | 'Deploy Token'          | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347593'
+        'using personal access token' | :personal_access_token | 'Personal access token' | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/485903'
+        'using ci job token'          | :ci_job_token          | 'CI Job Token'          | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/485904'
+        'using project deploy token'  | :project_deploy_token  | 'Deploy Token'          | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/579715'
       end
 
       with_them do
