@@ -26,14 +26,9 @@ module QA
 
           issue.visit!
 
-          work_item_enabled = Page::Project::Issue::Show.perform(&:work_item_enabled?)
+          Page::Project::WorkItem::Show.perform(&:delete_issue)
 
-          page_type_show = work_item_enabled ? Page::Project::WorkItem::Show : Page::Project::Issue::Show
-          page_type_index = Page::Project::Issue::Index
-
-          page_type_show.perform(&:delete_issue)
-
-          page_type_index.perform do |index|
+          Page::Project::WorkItem::Index.perform do |index|
             expect(index).not_to have_issue(issue)
           end
         end
@@ -58,11 +53,7 @@ module QA
 
           issue.visit!
 
-          work_item_enabled = Page::Project::Issue::Show.perform(&:work_item_enabled?)
-
-          page_type = work_item_enabled ? Page::Project::WorkItem::Show : Page::Project::Issue::Show
-
-          page_type.perform do |issue|
+          Page::Project::WorkItem::Show.perform do |issue|
             expect(issue).not_to have_delete_issue_button
           end
         end
