@@ -11,6 +11,84 @@ RSpec.describe Projects::CommitsController, feature_category: :source_code_manag
     project.add_maintainer(user)
   end
 
+  context 'unauthenticated user' do
+    let_it_be(:project) { create(:project, :repository, :public) }
+
+    context 'GET show' do
+      context 'without path' do
+        let(:id) { "master" }
+
+        it 'is successful' do
+          get :show, params: { namespace_id: project.namespace, project_id: project, id: id }
+
+          expect(assigns(:commits)).to be_present
+          expect(response).to have_gitlab_http_status(:ok)
+        end
+      end
+
+      context "with path provided" do
+        let(:id) { "master/README.md" }
+
+        it "requires authentication" do
+          get :show, params: { namespace_id: project.namespace, project_id: project, id: id }
+
+          expect(assigns(:commits)).to be_nil
+          expect(response).to redirect_to(new_user_session_path)
+        end
+
+        context 'when "require_login_for_commit_tree" FF is disabled' do
+          before do
+            stub_feature_flags(require_login_for_commit_tree: false)
+          end
+
+          it 'is successful' do
+            get :show, params: { namespace_id: project.namespace, project_id: project, id: id }
+
+            expect(assigns(:commits)).to be_present
+            expect(response).to have_gitlab_http_status(:ok)
+          end
+        end
+      end
+    end
+
+    context 'GET signatures' do
+      context 'without path' do
+        let(:id) { "master" }
+
+        it 'is successful' do
+          get :signatures, params: { namespace_id: project.namespace, project_id: project, id: id, format: :json }
+
+          expect(assigns(:commits)).to be_present
+          expect(response).to have_gitlab_http_status(:ok)
+        end
+      end
+
+      context "with path provided" do
+        let(:id) { "master/README.md" }
+
+        it "requires authentication" do
+          get :signatures, params: { namespace_id: project.namespace, project_id: project, id: id, format: :json }
+
+          expect(assigns(:commits)).to be_nil
+          expect(response).to have_gitlab_http_status(:unauthorized)
+        end
+
+        context 'when "require_login_for_commit_tree" FF is disabled' do
+          before do
+            stub_feature_flags(require_login_for_commit_tree: false)
+          end
+
+          it 'is successful' do
+            get :signatures, params: { namespace_id: project.namespace, project_id: project, id: id, format: :json }
+
+            expect(assigns(:commits)).to be_present
+            expect(response).to have_gitlab_http_status(:ok)
+          end
+        end
+      end
+    end
+  end
+
   context 'signed in' do
     before do
       sign_in(user)
@@ -171,7 +249,9 @@ RSpec.describe Projects::CommitsController, feature_category: :source_code_manag
             let(:request_params) { base_request_params.merge(committed_before: '2020-01-01') }
             let(:repository_params) { base_repository_params.merge(before: 1577836800) }
 
-            it_behaves_like 'repository commits call'
+            Time.use_zone('America/Los_Angeles') do
+              it_behaves_like 'repository commits call'
+            end
           end
 
           context 'is invalid' do
@@ -194,7 +274,9 @@ RSpec.describe Projects::CommitsController, feature_category: :source_code_manag
             let(:request_params) { base_request_params.merge(committed_after: '2020-01-01') }
             let(:repository_params) { base_repository_params.merge(after: 1577836800) }
 
-            it_behaves_like 'repository commits call'
+            Time.use_zone('America/Los_Angeles') do
+              it_behaves_like 'repository commits call'
+            end
           end
 
           context 'is invalid' do
