@@ -55,6 +55,10 @@ FactoryBot.define do
       end
     end
 
+    trait :tag do
+      tag { true }
+    end
+
     trait :created do
       status { :created }
     end
@@ -260,8 +264,8 @@ FactoryBot.define do
       end
 
       trait :with_job do
-        after(:build) do |pipeline, evaluator|
-          pipeline.builds << build(:ci_build, pipeline: pipeline, project: pipeline.project)
+        after(:create) do |pipeline, evaluator|
+          pipeline.builds << create(:ci_build, pipeline: pipeline, project: pipeline.project)
         end
       end
 
