@@ -267,7 +267,8 @@ RSpec.describe 'Admin Groups', :with_current_organization, feature_category: :gr
 
   describe 'add user into a group', :js do
     context 'when membership is set to expire' do
-      it 'renders relative time', quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/460029' do
+      it 'renders relative time',
+        quarantine: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/16767' do
         expire_time = Time.current + 2.days
         current_user.update!(time_display_relative: true)
         group.add_member(user, Gitlab::Access::REPORTER, expires_at: expire_time)
