@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-RSpec.describe 'Dashboard Groups page', :js, :with_organization_url_helpers, feature_category: :groups_and_projects do
+RSpec.describe 'Dashboard Groups page', :js, feature_category: :groups_and_projects do
   include ListboxHelpers
 
   let_it_be(:user) { create(:user) }
@@ -21,7 +21,7 @@ RSpec.describe 'Dashboard Groups page', :js, :with_organization_url_helpers, fea
 
   def click_options_menu(group)
     within_testid("groups-list-item-#{group.id}") do
-      find_by_testid('groups-projects-more-actions-dropdown').click
+      find_by_testid('groups-list-item-actions').click
     end
   end
 
@@ -224,8 +224,10 @@ RSpec.describe 'Dashboard Groups page', :js, :with_organization_url_helpers, fea
       end
 
       it 'cannot remove parent group' do
+        click_options_menu(group)
+
         within_testid("groups-list-item-#{group.id}") do
-          expect(has_testid?('groups-projects-more-actions-dropdown')).to be false
+          expect(page).not_to have_button('Delete')
         end
       end
     end
