@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-RSpec.describe 'Group variables', :js, feature_category: :ci_variables do
+RSpec.describe 'Group variables', :js, feature_category: :pipeline_composition do
   let(:user) { create(:user) }
   let(:group) { create(:group) }
   let!(:variable) { create(:ci_group_variable, key: 'test_key', value: 'test_value', masked: true, group: group) }
@@ -10,7 +10,7 @@ RSpec.describe 'Group variables', :js, feature_category: :ci_variables do
 
   before do
     group.add_owner(user)
-    gitlab_sign_in(user)
+    sign_in(user)
 
     visit page_path
     wait_for_requests
