@@ -3,8 +3,20 @@
 require 'spec_helper'
 
 RSpec.describe 'Group empty states', feature_category: :groups_and_projects do
-  let(:group) { create(:group) }
-  let(:user) { create(:group_member, :developer, user: create(:user), group: group).user }
+  let_it_be(:user) { create(:user) }
+
+  let_it_be(:group_without_projects) { create(:group) }
+  let_it_be(:subgroup) { create(:group, parent: group_without_projects) }
+  let_it_be(:subgroup_project) { create(:project, namespace: subgroup) }
+
+  let_it_be(:group) { create(:group) }
+  let_it_be(:project) { create(:project, namespace: group) }
+
+  before_all do
+    create(:group_member, :developer, user: user, group: group)
+    create(:group_member, :developer, user: user, group: group_without_projects)
+    project.add_maintainer(user)
+  end
 
   before do
     # TODO: When removing the feature flag,
@@ -23,12 +35,6 @@ RSpec.describe 'Group empty states', feature_category: :groups_and_projects do
       let(:path) { public_send(:"#{issuable}s_group_path", group) }
 
       context 'group has a project' do
-        let(:project) { create(:project, namespace: group) }
-
-        before do
-          project.add_maintainer(user)
-        end
-
         context "the project has #{issuable_name}s" do
           it 'does not display an empty state' do
             create(issuable, project_relation => project)
@@ -46,7 +52,8 @@ RSpec.describe 'Group empty states', feature_category: :groups_and_projects do
             wait_for_all_requests
 
             within_testid('issuable-empty-state') do
-              expect(page).to have_content(/There are no open #{issuable.to_s.humanize.downcase}/)
+              empty_state_copy_start = issuable == :issue ? 'No open' : 'There are no open'
+              expect(page).to have_content("#{empty_state_copy_start} #{issuable.to_s.humanize.downcase}")
               new_issuable_path = issuable == :issue ? 'new_project_issue_path' : 'project_new_merge_request_path'
 
               path = public_send(new_issuable_path, project)
@@ -77,7 +84,8 @@ RSpec.describe 'Group empty states', feature_category: :groups_and_projects do
             wait_for_all_requests
 
             within_testid('issuable-empty-state') do
-              expect(page).to have_content(/There are no closed #{issuable.to_s.humanize.downcase}/)
+              empty_state_copy_start = issuable == :issue ? 'No closed' : 'There are no closed'
+              expect(page).to have_content("#{empty_state_copy_start} #{issuable.to_s.humanize.downcase}")
             end
           end
         end
@@ -116,10 +124,9 @@ RSpec.describe 'Group empty states', feature_category: :groups_and_projects do
       end
 
       context 'group without a project' do
-        context 'group has a subgroup' do
-          let(:subgroup) { create(:group, parent: group) }
-          let(:subgroup_project) { create(:project, namespace: subgroup) }
+        let(:path) { public_send(:"#{issuable}s_group_path", group_without_projects) }
 
+        context 'group has a subgroup' do
           context "the project has #{issuable_name}s" do
             before do
               create(issuable, project_relation => subgroup_project)
