@@ -28,7 +28,7 @@ RSpec.describe 'Merge request > User approves', :js, feature_category: :code_rev
   def verify_approvals_count_on_index!
     visit(project_merge_requests_path(project, state: :all))
     expect(
-      page.all('[data-testid="mr-appovals"]').any? do |item|
+      page.all('[data-testid="mr-approvals"]').any? do |item|
         item["aria-label"] == "1 approval"
       end
     ).to be true
