@@ -150,7 +150,7 @@ RSpec.describe 'Merge request > User sees merge widget', :js, feature_category:
       expect(page).to have_selector('[data-testid="merge-failed-pipeline-confirmation-dialog"]', visible: true)
     end
 
-    it 'allows me to merge with a failed pipeline', quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/449599' do
+    it 'allows me to merge with a failed pipeline', quarantine: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/16779' do
       wait_for_requests
 
       click_button 'Merge…'
@@ -412,7 +412,7 @@ RSpec.describe 'Merge request > User sees merge widget', :js, feature_category:
 
       click_button 'Expand merge checks'
 
-      expect(page).not_to have_content('Merge request must be rebased, because a fast-forward merge is not possible.')
+      expect(page).not_to have_content('Fast forward merge is not possible. Please rebase.')
     end
 
     context 'when ff is off' do
@@ -424,7 +424,7 @@ RSpec.describe 'Merge request > User sees merge widget', :js, feature_category:
 
         click_button 'Expand merge checks'
 
-        expect(page).to have_content('Merge request must be rebased, because a fast-forward merge is not possible.')
+        expect(page).to have_content('Fast forward merge is not possible. Please rebase.')
       end
     end
   end
@@ -435,7 +435,7 @@ RSpec.describe 'Merge request > User sees merge widget', :js, feature_category:
       visit project_merge_request_path(project, merge_request)
     end
 
-    it 'updates the MR widget', :sidekiq_might_not_need_inline, quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/449626' do
+    it 'updates the MR widget', :sidekiq_might_not_need_inline, quarantine: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/16798' do
       page.within('.mr-state-widget') do
         click_button 'Merge'
       end
