@@ -102,6 +102,27 @@ RSpec.describe 'Projects > Files > User edits files', :js, feature_category: :so
       expect(page).to have_content('New commit message')
     end
 
+    it 'commits a renamed file' do
+      click_link('.gitignore')
+      edit_in_single_file_editor
+      find('.file-editor', match: :first)
+
+      fill_in('File path', with: '.gitignore-v1')
+      click_button('Commit changes')
+
+      within_testid('commit-change-modal') do
+        fill_in(:commit_message, with: 'New commit message', visible: true)
+        click_button('Commit changes')
+      end
+
+      expect(page).to have_current_path(project_blob_path(project, 'master/.gitignore-v1'), ignore_query: true)
+
+      wait_for_requests
+
+      expect(page).to have_content('.gitignore-v1')
+      expect(page).to have_content('New commit message')
+    end
+
     it 'displays a flash message with a link when an edited file was committed' do
       click_link('.gitignore')
       edit_in_single_file_editor
@@ -163,6 +184,7 @@ RSpec.describe 'Projects > Files > User edits files', :js, feature_category: :so
 
   context 'when an user does not have write access', :js do
     before do
+      stub_feature_flags(blob_edit_refactor: false)
       project2.add_reporter(user)
       visit(project2_tree_path_root_ref)
       wait_for_requests
@@ -262,6 +284,7 @@ RSpec.describe 'Projects > Files > User edits files', :js, feature_category: :so
       let!(:forked_project) { fork_project(project2, user, namespace: user.namespace, repository: true) }
 
       before do
+        stub_feature_flags(blob_edit_refactor: false)
         visit(project2_tree_path_root_ref)
         wait_for_requests
       end
