@@ -4,6 +4,7 @@ require 'spec_helper'
 
 RSpec.describe 'Work items list filters', :js, feature_category: :team_planning do
   include FilteredSearchHelpers
+  include WorkItemFeedbackHelpers
 
   let_it_be(:user1) { create(:user) }
   let_it_be(:user2) { create(:user) }
@@ -52,6 +53,7 @@ RSpec.describe 'Work items list filters', :js, feature_category: :team_planning
     before do
       sign_in(user1)
       visit group_work_items_path(group)
+      close_work_item_feedback_popover_if_present
     end
 
     describe 'assignee' do
@@ -379,6 +381,7 @@ RSpec.describe 'Work items list filters', :js, feature_category: :team_planning
       context 'when user is on group work items page' do
         before do
           visit group_work_items_path(group)
+          close_work_item_feedback_popover_if_present
         end
 
         include_examples 'filters by CRM organization'
