@@ -5,9 +5,9 @@ import VueApollo from 'vue-apollo';
 import createMockApollo from 'helpers/mock_apollo_helper';
 import waitForPromises from 'helpers/wait_for_promises';
 import { TEST_HOST } from 'spec/test_constants';
-import { createAlert } from '~/alert';
 import getJobsQuery from '~/ci/jobs_page/graphql/queries/get_jobs.query.graphql';
 import getJobsCountQuery from '~/ci/jobs_page/graphql/queries/get_jobs_count.query.graphql';
+import jobProcessedSubscription from '~/ci/jobs_page/graphql/subscriptions/ci_job_processed.subscription.graphql';
 import JobsTable from '~/ci/jobs_page/components/jobs_table.vue';
 import JobsTableApp from '~/ci/jobs_page/jobs_page_app.vue';
 import JobsTableTabs from '~/ci/jobs_page/components/jobs_table_tabs.vue';
@@ -23,14 +23,11 @@ import {
   mockBridgeKindToken,
   mockBuildKindToken,
 } from 'jest/ci/jobs_mock_data';
-import { RAW_TEXT_WARNING, DEFAULT_PAGINATION, JOBS_PER_PAGE } from '~/ci/jobs_page/constants';
+import { DEFAULT_PAGINATION, JOBS_PER_PAGE } from '~/ci/jobs_page/constants';
 
 const projectPath = 'gitlab-org/gitlab';
 Vue.use(VueApollo);
 
-jest.mock('~/alert');
-jest.mock('~/graphql_shared/utils');
-
 const mockJobName = 'rspec-job';
 const mockJobSource = mockPushSourceToken.value.data;
 
@@ -40,6 +37,9 @@ describe('Job table app', () => {
   const successHandler = jest.fn().mockResolvedValue(mockJobsResponsePaginated);
   const failedHandler = jest.fn().mockRejectedValue(new Error('GraphQL error'));
   const emptyHandler = jest.fn().mockResolvedValue(mockJobsResponseEmpty);
+  const emptySubHandler = jest.fn().mockImplementation(() => {
+    return new Promise(() => {});
+  });
 
   const countSuccessHandler = jest.fn().mockResolvedValue(mockJobsCountResponse);
 
@@ -51,10 +51,11 @@ describe('Job table app', () => {
   const findFilteredSearch = () => wrapper.findComponent(JobsFilteredSearch);
   const findPagination = () => wrapper.findComponent(GlKeysetPagination);
 
-  const createMockApolloProvider = (handler, countHandler) => {
+  const createMockApolloProvider = (handler, countHandler, subHandler) => {
     const requestHandlers = [
       [getJobsQuery, handler],
       [getJobsCountQuery, countHandler],
+      [jobProcessedSubscription, subHandler],
     ];
 
     return createMockApollo(requestHandlers);
@@ -63,17 +64,19 @@ describe('Job table app', () => {
   const createComponent = ({
     handler = successHandler,
     countHandler = countSuccessHandler,
+    subHandler = emptySubHandler,
     mountFn = shallowMount,
-    feSearchBuildByName = false,
+    realtimeEnabled = true,
   } = {}) => {
     wrapper = mountFn(JobsTableApp, {
       provide: {
         fullPath: projectPath,
         glFeatures: {
-          feSearchBuildByName,
+          ciJobCreatedSubscription: realtimeEnabled,
         },
+        projectId: '100',
       },
-      apolloProvider: createMockApolloProvider(handler, countHandler),
+      apolloProvider: createMockApolloProvider(handler, countHandler, subHandler),
     });
   };
 
@@ -232,6 +235,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         statuses: 'FAILED',
         sources: null,
+        name: null,
         kind: 'BUILD',
         ...DEFAULT_PAGINATION,
       });
@@ -239,6 +243,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         statuses: 'FAILED',
         sources: null,
+        name: null,
         kind: 'BUILD',
       });
     });
@@ -263,17 +268,19 @@ describe('Job table app', () => {
       expect(countSuccessHandler).toHaveBeenCalledTimes(2);
     });
 
-    it('shows raw text warning when user inputs raw text', async () => {
-      const expectedWarning = {
-        message: RAW_TEXT_WARNING,
-        variant: 'warning',
-      };
-
+    it('filters jobs by name when user inputs raw text', async () => {
       createComponent();
 
-      await findFilteredSearch().vm.$emit('filterJobsBySearch', ['raw text']);
+      await findFilteredSearch().vm.$emit('filterJobsBySearch', ['rspec-job']);
 
-      expect(createAlert).toHaveBeenCalledWith(expectedWarning);
+      expect(successHandler).toHaveBeenCalledWith({
+        fullPath: 'gitlab-org/gitlab',
+        name: 'rspec-job',
+        statuses: null,
+        sources: null,
+        kind: 'BUILD',
+        ...DEFAULT_PAGINATION,
+      });
     });
 
     it('updates URL query string when filtering jobs by status', async () => {
@@ -302,6 +309,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         statuses: 'FAILED',
         sources: mockJobSource,
+        name: null,
         kind: 'BUILD',
         ...DEFAULT_PAGINATION,
       });
@@ -309,6 +317,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         statuses: 'FAILED',
         sources: mockJobSource,
+        name: null,
         kind: 'BUILD',
       });
       expect(urlUtils.updateHistory).toHaveBeenCalledWith({
@@ -325,6 +334,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         statuses: null,
         sources: null,
+        name: null,
         kind: 'BUILD',
         ...DEFAULT_PAGINATION,
       });
@@ -332,6 +342,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         statuses: null,
         sources: null,
+        name: null,
         kind: 'BUILD',
       });
     });
@@ -345,6 +356,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         sources: mockJobSource,
         statuses: null,
+        name: null,
         kind: 'BUILD',
         ...DEFAULT_PAGINATION,
       });
@@ -352,6 +364,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         sources: mockJobSource,
         statuses: null,
+        name: null,
         kind: 'BUILD',
       });
     });
@@ -368,6 +381,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         sources: mockJobSource,
         statuses: 'FAILED',
+        name: null,
         kind: 'BUILD',
         ...DEFAULT_PAGINATION,
       });
@@ -375,6 +389,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         sources: mockJobSource,
         statuses: 'FAILED',
+        name: null,
         kind: 'BUILD',
       });
 
@@ -384,6 +399,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         sources: mockJobSource,
         statuses: null,
+        name: null,
         kind: 'BUILD',
         ...DEFAULT_PAGINATION,
       });
@@ -391,6 +407,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         sources: mockJobSource,
         statuses: null,
+        name: null,
         kind: 'BUILD',
       });
     });
@@ -422,9 +439,9 @@ describe('Job table app', () => {
       });
     });
 
-    describe('with feature flag feSearchBuildByName enabled', () => {
+    describe('job name filtering', () => {
       beforeEach(() => {
-        createComponent({ feSearchBuildByName: true });
+        createComponent();
       });
 
       it('filters jobs by name', async () => {
@@ -578,6 +595,7 @@ describe('Job table app', () => {
           fullPath: 'gitlab-org/gitlab',
           statuses: null,
           sources: null,
+          name: null,
           kind: 'BRIDGE',
           ...DEFAULT_PAGINATION,
         });
@@ -585,6 +603,7 @@ describe('Job table app', () => {
           fullPath: 'gitlab-org/gitlab',
           statuses: null,
           sources: null,
+          name: null,
           kind: 'BRIDGE',
         });
         expect(urlUtils.updateHistory).toHaveBeenCalledWith({
@@ -601,6 +620,7 @@ describe('Job table app', () => {
           fullPath: 'gitlab-org/gitlab',
           statuses: null,
           sources: null,
+          name: null,
           kind: 'BUILD',
           ...DEFAULT_PAGINATION,
         });
@@ -608,6 +628,7 @@ describe('Job table app', () => {
           fullPath: 'gitlab-org/gitlab',
           statuses: null,
           sources: null,
+          name: null,
           kind: 'BUILD',
         });
         expect(urlUtils.updateHistory).toHaveBeenCalledWith({
@@ -716,6 +737,7 @@ describe('Job table app', () => {
         fullPath: 'gitlab-org/gitlab',
         statuses: 'FAILED',
         sources: null,
+        name: null,
         kind: 'BUILD',
         ...DEFAULT_PAGINATION,
       });
@@ -740,4 +762,32 @@ describe('Job table app', () => {
       });
     });
   });
+
+  describe('subscription', () => {
+    it('calls subscription with correct variables', async () => {
+      createComponent();
+
+      await waitForPromises();
+
+      expect(emptySubHandler).toHaveBeenCalledWith({ projectId: 'gid://gitlab/Project/100' });
+    });
+
+    it('does not make redundant subscription calls', async () => {
+      createComponent();
+
+      await waitForPromises();
+
+      expect(emptySubHandler).toHaveBeenCalledTimes(1);
+    });
+
+    describe('with the feature flag turned off', () => {
+      it('does not call the subscription', async () => {
+        createComponent({ realtimeEnabled: false });
+
+        await waitForPromises();
+
+        expect(emptySubHandler).not.toHaveBeenCalled();
+      });
+    });
+  });
 });
