@@ -1,5 +1,5 @@
 import { updatePipelineNodes } from '~/ci/pipelines_page/utils';
-import { mockPipelineUpdateResponse, mockPipelines, mockNewPipeline } from './mock_data';
+import { mockPipelineUpdateResponse, mockPipelines } from './mock_data';
 
 describe('Pipelines utility functions', () => {
   describe('updatePipelineNodes', () => {
@@ -17,14 +17,5 @@ describe('Pipelines utility functions', () => {
       expect(updatedPipelines[0].detailedStatus.icon).toBe('status_running');
       expect(updatedPipelines[1]).toEqual(unchangedPipeline);
     });
-
-    it('merges a new pipeline if it does not previously exist', () => {
-      const initialLength = mockPipelines.length;
-      const updatedPipelines = updatePipelineNodes(mockPipelines, mockNewPipeline);
-
-      expect(updatedPipelines).toHaveLength(initialLength + 1);
-      expect(updatedPipelines[0]).toEqual(mockNewPipeline);
-      expect(updatedPipelines.slice(1)).toEqual(mockPipelines);
-    });
   });
 });
