@@ -40,20 +40,6 @@ jest.mock('fuzzaldrin-plus', () => ({
   filter: jest.fn((items) => items),
 }));
 
-describe('escape', () => {
-  it.each`
-    xssPayload                                           | escapedPayload
-    ${'<script>alert(1)</script>'}                       | ${'&lt;script&gt;alert(1)&lt;/script&gt;'}
-    ${'%3Cscript%3E alert(1) %3C%2Fscript%3E'}           | ${'&lt;script&gt; alert(1) &lt;/script&gt;'}
-    ${'%253Cscript%253E alert(1) %253C%252Fscript%253E'} | ${'&lt;script&gt; alert(1) &lt;/script&gt;'}
-  `(
-    'escapes the input string correctly accounting for multiple encoding',
-    ({ xssPayload, escapedPayload }) => {
-      expect(escape(xssPayload)).toBe(escapedPayload);
-    },
-  );
-});
-
 describe('GfmAutoComplete', () => {
   const fetchDataMock = { fetchData: jest.fn() };
   let gfmAutoCompleteCallbacks = GfmAutoComplete.prototype.getDefaultCallbacks.call(fetchDataMock);
@@ -579,6 +565,30 @@ describe('GfmAutoComplete', () => {
       mentionsDisabled: false,
     };
 
+    const defaultUser = {
+      username: 'my-user',
+      name: 'My User',
+      avatar_url: './users.jpg',
+      type: 'User',
+    };
+
+    const defaultExpectedOutput = {
+      username: 'my-group',
+      avatarTag:
+        '<img src="./group.jpg" alt="my-group" class="avatar rect-avatar avatar-inline s24 gl-mr-2"/>',
+      title: 'My Group (2)',
+      search: 'MyGroup my-group',
+      icon: '',
+    };
+
+    const userDefaultOutput = {
+      username: 'my-user',
+      avatarTag: '<img src="./users.jpg" alt="my-user" class="avatar  avatar-inline s24 gl-mr-2"/>',
+      title: 'My User',
+      search: 'MyUser my-user',
+      icon: '',
+    };
+
     it('should return the original object when username is null', () => {
       expect(membersBeforeSave([{ ...mockGroup, username: null }])).toEqual([
         { ...mockGroup, username: null },
@@ -588,81 +598,67 @@ describe('GfmAutoComplete', () => {
     it('should set the text avatar if avatar_url is null', () => {
       expect(membersBeforeSave([{ ...mockGroup, avatar_url: null }])).toEqual([
         {
-          username: 'my-group',
+          ...defaultExpectedOutput,
           avatarTag: '<div class="avatar rect-avatar avatar-inline s24 gl-mr-2">M</div>',
-          title: 'My Group (2)',
-          search: 'MyGroup my-group',
-          icon: '',
         },
       ]);
     });
 
     it('should set the image avatar if avatar_url is given', () => {
-      expect(membersBeforeSave([mockGroup])).toEqual([
-        {
-          username: 'my-group',
-          avatarTag:
-            '<img src="./group.jpg" alt="my-group" class="avatar rect-avatar avatar-inline s24 gl-mr-2"/>',
-          title: 'My Group (2)',
-          search: 'MyGroup my-group',
-          icon: '',
-        },
-      ]);
+      expect(membersBeforeSave([mockGroup])).toEqual([defaultExpectedOutput]);
     });
 
     it('should set mentions disabled icon if mentionsDisabled is set', () => {
       expect(membersBeforeSave([{ ...mockGroup, mentionsDisabled: true }])).toEqual([
         {
-          username: 'my-group',
-          avatarTag:
-            '<img src="./group.jpg" alt="my-group" class="avatar rect-avatar avatar-inline s24 gl-mr-2"/>',
+          ...defaultExpectedOutput,
           title: 'My Group',
-          search: 'MyGroup my-group',
           icon: '<svg class="s16 vertical-align-middle gl-ml-2"><use xlink:href="/icons.svg#notifications-off" /></svg>',
         },
       ]);
     });
 
     it('should set the right image classes for User type members', () => {
-      expect(
-        membersBeforeSave([
-          { username: 'my-user', name: 'My User', avatar_url: './users.jpg', type: 'User' },
-        ]),
-      ).toEqual([
-        {
-          username: 'my-user',
-          avatarTag:
-            '<img src="./users.jpg" alt="my-user" class="avatar  avatar-inline s24 gl-mr-2"/>',
-          title: 'My User',
-          search: 'MyUser my-user',
-          icon: '',
-        },
-      ]);
+      expect(membersBeforeSave([defaultUser])).toEqual([userDefaultOutput]);
     });
 
     it('should include composite_identity_enforced field', () => {
       expect(
         membersBeforeSave([
           {
-            username: 'my-user',
-            name: 'My User',
-            avatar_url: './users.jpg',
-            type: 'User',
+            ...defaultUser,
             composite_identity_enforced: true,
           },
         ]),
       ).toEqual([
         {
-          username: 'my-user',
-          avatarTag:
-            '<img src="./users.jpg" alt="my-user" class="avatar  avatar-inline s24 gl-mr-2"/>',
-          title: 'My User',
-          search: 'MyUser my-user',
-          icon: '',
+          ...userDefaultOutput,
           compositeIdentityEnforced: true,
         },
       ]);
     });
+
+    describe('when disabled field is present', () => {
+      it.each`
+        disabled | description
+        ${true}  | ${'disabled is true'}
+        ${false} | ${'disabled is false'}
+      `('should include disabled field when $description', ({ disabled }) => {
+        expect(
+          membersBeforeSave([
+            {
+              ...defaultUser,
+              disabled,
+            },
+          ]),
+        ).toEqual([
+          {
+            ...userDefaultOutput,
+            disabled,
+          },
+        ]);
+      });
+    });
   });
 
   describe('Issues.insertTemplateFunction', () => {
@@ -793,7 +789,7 @@ describe('GfmAutoComplete', () => {
             compositeIdentityEnforced: true,
           });
           expect(result).toContain('IMG my-user');
-          expect(result).toContain('Agent');
+          expect(result).toContain('AI');
           expect(result).toContain('gl-badge');
         });
       });
@@ -1498,6 +1494,50 @@ describe('GfmAutoComplete', () => {
           expect(currentAssignees).toHaveBeenCalled();
         });
       });
+
+      describe('with disabled members', () => {
+        const disabledMember = {
+          ...mockAssignees[0],
+          disabled: true,
+        };
+        const enabledMembers = mockAssignees.slice(1);
+
+        beforeEach(() => {
+          currentAssignees.mockImplementation(() => ({
+            [`${mockWorkItemId}`]: [],
+          }));
+
+          // This looks odd but that's how GFMAutoComplete
+          // caches issues data internally.
+          autocomplete.cachedData['@'] = {
+            '': [disabledMember, ...enabledMembers],
+          };
+        });
+
+        describe('typing @', () => {
+          beforeEach(() => {
+            triggerDropdown($textarea, '@');
+          });
+
+          it('filters out disabled users', () => {
+            expect(getDropdownItems()).toHaveLength(enabledMembers.length);
+            expect(getDropdownItems()[0]).not.toContain(disabledMember.name);
+            expect(getDropdownItems()[1]).not.toContain(disabledMember.name);
+          });
+
+          it('renders non-disabled users', () => {
+            expect(getDropdownItems()).toHaveLength(enabledMembers.length);
+            expect(getDropdownItems()[0]).toContain(enabledMembers[0].name);
+            expect(getDropdownItems()[1]).toContain(enabledMembers[1].name);
+          });
+        });
+
+        it('using "/assign @" filters out disabled members', () => {
+          triggerDropdown($textarea, '/assign @');
+
+          expect(getDropdownItems()).toHaveLength(enabledMembers.length);
+        });
+      });
     });
   });
 
@@ -1619,4 +1659,18 @@ describe('GfmAutoComplete', () => {
       defaultSorterSpy.mockRestore();
     });
   });
+
+  describe('escape', () => {
+    it.each`
+      xssPayload                                           | escapedPayload
+      ${'<script>alert(1)</script>'}                       | ${'&lt;script&gt;alert(1)&lt;/script&gt;'}
+      ${'%3Cscript%3E alert(1) %3C%2Fscript%3E'}           | ${'&lt;script&gt; alert(1) &lt;/script&gt;'}
+      ${'%253Cscript%253E alert(1) %253C%252Fscript%253E'} | ${'&lt;script&gt; alert(1) &lt;/script&gt;'}
+    `(
+      'escapes the input string correctly accounting for multiple encoding',
+      ({ xssPayload, escapedPayload }) => {
+        expect(escape(xssPayload)).toBe(escapedPayload);
+      },
+    );
+  });
 });
