@@ -2,7 +2,10 @@ import { setHTMLFixture, resetHTMLFixture } from 'helpers/fixtures';
 import { contentTop } from '~/lib/utils/common_utils';
 import { scrollToTargetOnResize } from '~/lib/utils/resize_observer';
 
-jest.mock('~/lib/utils/common_utils');
+jest.mock('~/lib/utils/common_utils', () => ({
+  ...jest.requireActual('~/lib/utils/common_utils'),
+  contentTop: jest.fn(),
+}));
 
 function mockStickyHeaderSize(val) {
   contentTop.mockReturnValue(val);
@@ -29,20 +32,18 @@ describe('scrollToTargetOnResize', () => {
 
     mockStickyHeaderSize(mockHeaderSize);
 
-    Object.defineProperty(document, 'scrollingElement', {
-      value: {
-        scrollTo: jest.fn(),
-        scrollTop: 0,
-        scrollHeight: 1000,
-      },
-      writable: true,
-    });
+    jest.spyOn(document.documentElement, 'scrollTop', 'get').mockReturnValue(0);
+    jest.spyOn(document.documentElement, 'scrollHeight', 'get').mockReturnValue(1000);
 
     setHTMLFixture(
-      `<div id="content-body">
-        <div id="target-element">Target content</div>
-        <div id="other-content">Other content</div>
-      </div>`,
+      `<div>
+        <header class="js-super-topbar"></header>
+        <div id="content-body">
+          <div id="target-element">Target content</div>
+          <div id="other-content">Other content</div>
+        </div>
+      </div>
+      `,
     );
   });
 
@@ -146,6 +147,23 @@ describe('scrollToTargetOnResize', () => {
       expect(document.scrollingElement.scrollTo).not.toHaveBeenCalled();
     });
 
+    it('does scroll when the super topbar is focused', () => {
+      const otherElement = document.querySelector('.js-super-topbar');
+      jest.spyOn(document, 'activeElement', 'get').mockReturnValue(otherElement);
+
+      cleanup = scrollToTargetOnResize({
+        targetId: 'target-element',
+        container: '#content-body',
+      });
+
+      resizeObserverCallback([{ target: document.querySelector('#content-body') }]);
+
+      expect(document.scrollingElement.scrollTo).toHaveBeenCalledWith({
+        top: 200 - 0 - mockHeaderSize,
+        behavior: 'instant',
+      });
+    });
+
     it('does nothing if target element does not exist', () => {
       cleanup = scrollToTargetOnResize({
         targetId: 'non-existent-id',
@@ -170,13 +188,13 @@ describe('scrollToTargetOnResize', () => {
         behavior: 'instant',
       });
 
-      document.scrollingElement.scrollTop = 100;
+      jest.spyOn(document.documentElement, 'scrollTop', 'get').mockReturnValue(100);
 
       jest
         .spyOn(document.getElementById('target-element'), 'getBoundingClientRect')
         .mockReturnValue({ top: 100 });
 
-      window.dispatchEvent(new Event('scroll'));
+      document.scrollingElement.dispatchEvent(new Event('scroll'));
 
       jest
         .spyOn(document.getElementById('target-element'), 'getBoundingClientRect')
@@ -189,6 +207,62 @@ describe('scrollToTargetOnResize', () => {
         behavior: 'instant',
       });
     });
+
+    describe('when project studio is enabled', () => {
+      beforeEach(() => {
+        window.gon = {
+          features: {
+            projectStudioEnabled: true,
+          },
+        };
+      });
+
+      it('scrolls the static panel', () => {
+        setHTMLFixture(
+          `<div class="js-static-panel">
+            <div class="js-static-panel-inner">
+              <div id="target-element">Target content</div>
+              <div id="other-content">Other content</div>
+            </div>
+          </div>`,
+        );
+
+        const panelScroller = document.querySelector('.js-static-panel-inner');
+
+        cleanup = scrollToTargetOnResize({
+          targetId: 'target-element',
+          container: '#content-body',
+        });
+
+        resizeObserverCallback([{ target: panelScroller }]);
+
+        expect(panelScroller.scrollTo).toHaveBeenCalled();
+      });
+
+      it('scrolls the dynamic panel', () => {
+        setHTMLFixture(
+          `<div class="js-dynamic-panel">
+            <div class="js-dynamic-panel-inner">
+              <div id="content-other-body">
+                <div id="target-element">Target content</div>
+              </div>
+              <div id="other-content">Other content</div>
+            </div>
+          </div>`,
+        );
+
+        const panelScroller = document.querySelector('.js-dynamic-panel-inner');
+
+        cleanup = scrollToTargetOnResize({
+          targetId: 'target-element',
+          container: '#content-other-body',
+        });
+
+        resizeObserverCallback([{ target: panelScroller }]);
+
+        expect(panelScroller.scrollTo).toHaveBeenCalled();
+      });
+    });
   });
 
   describe('intersection observer', () => {
@@ -269,7 +343,7 @@ describe('scrollToTargetOnResize', () => {
 
     document.scrollingElement.scrollTo.mockClear();
 
-    document.scrollingElement.scrollHeight = 1200;
+    jest.spyOn(document.documentElement, 'scrollHeight', 'get').mockReturnValue(1200);
 
     window.dispatchEvent(new Event('scroll'));
 
