@@ -1,7 +1,7 @@
-import Vue from 'vue';
+import Vue, { nextTick } from 'vue';
 import VueApollo from 'vue-apollo';
 import { GlCollapsibleListbox } from '@gitlab/ui';
-import { shallowMount } from '@vue/test-utils';
+import { shallowMount, mount } from '@vue/test-utils';
 import createMockApollo from 'helpers/mock_apollo_helper';
 import waitForPromises from 'helpers/wait_for_promises';
 import { mockTracking, triggerEvent } from 'helpers/tracking_helper';
@@ -20,14 +20,26 @@ let setReviewersMutationMock;
 
 Vue.use(VueApollo);
 
-const createMockUser = ({ id = 1, name = 'Administrator', username = 'root' } = {}) => ({
+const createMockUser = ({
+  id = 1,
+  name = 'Administrator',
+  username = 'root',
+  compositeIdentityEnforced = false,
+  status = {},
+} = {}) => ({
   __typename: 'UserCore',
   id: `gid://gitlab/User/${id}`,
   avatarUrl:
     'https://www.gravatar.com/avatar/e64c7d89f26bd1972efa854d13d7dd61?s=80\u0026d=identicon',
   webUrl: `/${username}`,
   webPath: `/${username}`,
-  status: null,
+  status: {
+    availability: 'NOT_SET',
+    disabledForDuoUsage: false,
+    disabledForDuoUsageReason: null,
+    ...status,
+  },
+  compositeIdentityEnforced,
   mergeRequestInteraction: {
     canMerge: true,
     applicableApprovalRules: [],
@@ -36,18 +48,19 @@ const createMockUser = ({ id = 1, name = 'Administrator', username = 'root' } =
   name,
 });
 
-function createComponent(
+function createComponent({
   adminMergeRequest = true,
   propsData = { selectedReviewers: [createMockUser()] },
   customUsers = null,
-) {
+  mountFn = shallowMount,
+} = {}) {
   const defaultUsers = [
     createMockUser(),
     createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
   ];
   autocompleteUsersMock = jest.fn().mockResolvedValue({
     data: {
-      workspace: {
+      namespace: {
         id: 1,
         users: customUsers || defaultUsers,
       },
@@ -83,7 +96,7 @@ function createComponent(
     },
   );
 
-  wrapper = shallowMount(ReviewerDropdown, {
+  wrapper = mountFn(ReviewerDropdown, {
     apolloProvider,
     propsData,
     provide: {
@@ -100,7 +113,7 @@ const findDropdown = () => wrapper.findComponent(GlCollapsibleListbox);
 describe('Reviewer dropdown component', () => {
   describe('when user does not have permission', () => {
     beforeEach(async () => {
-      createComponent(false);
+      createComponent({ adminMergeRequest: false });
 
       await waitForPromises();
     });
@@ -112,7 +125,7 @@ describe('Reviewer dropdown component', () => {
 
   describe('when user has permission', () => {
     beforeEach(async () => {
-      createComponent(true);
+      createComponent({ adminMergeRequest: true });
 
       await waitForPromises();
     });
@@ -176,7 +189,7 @@ describe('Reviewer dropdown component', () => {
 
     describe('with the user not already selected', () => {
       beforeEach(async () => {
-        createComponent(true, {});
+        createComponent({ adminMergeRequest: true, propsData: {} });
 
         await waitForPromises();
       });
@@ -225,11 +238,15 @@ describe('Reviewer dropdown component', () => {
       describe('when current user is not selected', () => {
         describe('when current user is in the first page of query results', () => {
           beforeEach(async () => {
-            createComponent(true, { selectedReviewers: [] }, [
-              createMockUser(),
-              createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
-              createMockUser({ id: 3, name: 'Current User', username: 'currentuser' }),
-            ]);
+            createComponent({
+              adminMergeRequest: true,
+              propsData: { selectedReviewers: [] },
+              customUsers: [
+                createMockUser(),
+                createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+                createMockUser({ id: 3, name: 'Current User', username: 'currentuser' }),
+              ],
+            });
             await waitForPromises();
 
             findDropdown().vm.$emit('shown');
@@ -250,10 +267,14 @@ describe('Reviewer dropdown component', () => {
 
         describe('when current user is not in the first page of query results', () => {
           beforeEach(async () => {
-            createComponent(true, { selectedReviewers: [] }, [
-              createMockUser(),
-              createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
-            ]);
+            createComponent({
+              adminMergeRequest: true,
+              propsData: { selectedReviewers: [] },
+              customUsers: [
+                createMockUser(),
+                createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+              ],
+            });
             await waitForPromises();
 
             findDropdown().vm.$emit('shown');
@@ -281,18 +302,18 @@ describe('Reviewer dropdown component', () => {
             username: 'currentuser',
           });
 
-          createComponent(
-            true,
-            {
+          createComponent({
+            adminMergeRequest: true,
+            propsData: {
               selectedReviewers: [currentUser],
               eligibleReviewers: [currentUser],
             },
-            [
+            customUsers: [
               createMockUser(),
               createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
               currentUser,
             ],
-          );
+          });
           await waitForPromises();
 
           findDropdown().vm.$emit('shown');
@@ -316,15 +337,19 @@ describe('Reviewer dropdown component', () => {
 
       describe('when searching', () => {
         beforeEach(async () => {
-          createComponent(true, { selectedReviewers: [] }, [
-            createMockUser(),
-            createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
-          ]);
+          createComponent({
+            adminMergeRequest: true,
+            propsData: { selectedReviewers: [] },
+            customUsers: [
+              createMockUser(),
+              createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+            ],
+          });
           await waitForPromises();
 
           autocompleteUsersMock.mockResolvedValueOnce({
             data: {
-              workspace: {
+              namespace: {
                 id: 1,
                 users: [
                   createMockUser({ id: 3, name: 'Current User', username: 'currentuser' }),
@@ -349,11 +374,15 @@ describe('Reviewer dropdown component', () => {
 
       describe('when current user is already first', () => {
         beforeEach(async () => {
-          createComponent(true, { selectedReviewers: [] }, [
-            createMockUser({ id: 3, name: 'Current User', username: 'currentuser' }),
-            createMockUser(),
-            createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
-          ]);
+          createComponent({
+            adminMergeRequest: true,
+            propsData: { selectedReviewers: [] },
+            customUsers: [
+              createMockUser({ id: 3, name: 'Current User', username: 'currentuser' }),
+              createMockUser(),
+              createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+            ],
+          });
           await waitForPromises();
 
           findDropdown().vm.$emit('shown');
@@ -390,8 +419,11 @@ describe('Reviewer dropdown component', () => {
       let trackEventSpy;
 
       beforeEach(async () => {
-        createComponent(true, {
-          users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
+        createComponent({
+          adminMergeRequest: true,
+          propsData: {
+            users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
+          },
         });
 
         await waitForPromises();
@@ -400,7 +432,7 @@ describe('Reviewer dropdown component', () => {
       });
 
       it('tracks which position any selected users were in as a telemetry event', async () => {
-        findDropdown().vm.$emit('select', ['root']);
+        findDropdown().vm.$emit('select', 'root');
         findDropdown().vm.$emit('hidden');
 
         await waitForPromises();
@@ -417,14 +449,17 @@ describe('Reviewer dropdown component', () => {
       });
 
       it('tracks which position any selected users were in - discounting already selected reviewers - as a telemetry event', async () => {
-        createComponent(true, {
-          users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
-          selectedReviewers: [createMockUser()],
+        createComponent({
+          adminMergeRequest: true,
+          propsData: {
+            users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
+            selectedReviewers: [createMockUser()],
+          },
         });
 
         await waitForPromises();
 
-        findDropdown().vm.$emit('select', ['bob']);
+        findDropdown().vm.$emit('select', 'bob');
         findDropdown().vm.$emit('hidden');
 
         await waitForPromises();
@@ -442,7 +477,7 @@ describe('Reviewer dropdown component', () => {
 
       it('tracks which position any selected users were in after a search as a telemetry event', async () => {
         findDropdown().vm.$emit('search', 'bob');
-        findDropdown().vm.$emit('select', ['bob']);
+        findDropdown().vm.$emit('select', 'bob');
         findDropdown().vm.$emit('hidden');
 
         await waitForPromises();
@@ -459,7 +494,7 @@ describe('Reviewer dropdown component', () => {
       });
 
       it('does not send the "simple sidebar" tracking event when used "normally" (in complex mode)', async () => {
-        findDropdown().vm.$emit('select', ['bob']);
+        findDropdown().vm.$emit('select', 'bob');
         findDropdown().vm.$emit('hidden');
 
         await waitForPromises();
@@ -473,14 +508,20 @@ describe('Reviewer dropdown component', () => {
 
       describe('simple sidebar usage (without using the reviewers panel)', () => {
         it('sends the "simple sidebar" tracking event when reviewers are added', async () => {
-          createComponent(true, {
-            users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
-            usage: 'simple',
+          createComponent({
+            adminMergeRequest: true,
+            propsData: {
+              users: [
+                createMockUser(),
+                createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+              ],
+              usage: 'simple',
+            },
           });
 
           await waitForPromises();
 
-          findDropdown().vm.$emit('select', ['bob']);
+          findDropdown().vm.$emit('select', 'bob');
           findDropdown().vm.$emit('hidden');
 
           await waitForPromises();
@@ -493,10 +534,16 @@ describe('Reviewer dropdown component', () => {
         });
 
         it('does not send the "simple sidebar" tracking event when reviewers are removed', async () => {
-          createComponent(true, {
-            users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
-            selectedReviewers: [createMockUser()],
-            usage: 'simple',
+          createComponent({
+            adminMergeRequest: true,
+            propsData: {
+              users: [
+                createMockUser(),
+                createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+              ],
+              selectedReviewers: [createMockUser()],
+              usage: 'simple',
+            },
           });
 
           await waitForPromises();
@@ -514,13 +561,19 @@ describe('Reviewer dropdown component', () => {
         });
 
         it('tracks reviewer removal', async () => {
-          createComponent(true, {
-            users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
-            selectedReviewers: [
-              createMockUser(),
-              createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
-            ],
-            usage: 'simple',
+          createComponent({
+            adminMergeRequest: true,
+            propsData: {
+              users: [
+                createMockUser(),
+                createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+              ],
+              selectedReviewers: [
+                createMockUser(),
+                createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+              ],
+              usage: 'simple',
+            },
           });
 
           await waitForPromises();
@@ -541,12 +594,15 @@ describe('Reviewer dropdown component', () => {
       });
 
       it('tracks reviewer removal events', async () => {
-        createComponent(true, {
-          users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
-          selectedReviewers: [
-            createMockUser(),
-            createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
-          ],
+        createComponent({
+          adminMergeRequest: true,
+          propsData: {
+            users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
+            selectedReviewers: [
+              createMockUser(),
+              createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+            ],
+          },
         });
 
         await waitForPromises();
@@ -566,12 +622,15 @@ describe('Reviewer dropdown component', () => {
       });
 
       it('tracks multiple reviewer removals', async () => {
-        createComponent(true, {
-          users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
-          selectedReviewers: [
-            createMockUser(),
-            createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
-          ],
+        createComponent({
+          adminMergeRequest: true,
+          propsData: {
+            users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
+            selectedReviewers: [
+              createMockUser(),
+              createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' }),
+            ],
+          },
         });
 
         await waitForPromises();
@@ -592,9 +651,12 @@ describe('Reviewer dropdown component', () => {
       });
 
       it('does not track removal events when no reviewers are removed', async () => {
-        createComponent(true, {
-          users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
-          selectedReviewers: [createMockUser()],
+        createComponent({
+          adminMergeRequest: true,
+          propsData: {
+            users: [createMockUser(), createMockUser({ id: 2, name: 'Nonadmin', username: 'bob' })],
+            selectedReviewers: [createMockUser()],
+          },
         });
 
         await waitForPromises();
@@ -613,8 +675,11 @@ describe('Reviewer dropdown component', () => {
 
       describe('"suggested" historical position', () => {
         it('reports the correct prior suggested position', async () => {
-          createComponent(true, {
-            selectedReviewers: [],
+          createComponent({
+            adminMergeRequest: true,
+            propsData: {
+              selectedReviewers: [],
+            },
           });
 
           await waitForPromises();
@@ -640,8 +705,11 @@ describe('Reviewer dropdown component', () => {
         });
 
         it('reports the correct prior suggested position - discounting already selected reviewers', async () => {
-          createComponent(true, {
-            selectedReviewers: [createMockUser()],
+          createComponent({
+            adminMergeRequest: true,
+            propsData: {
+              selectedReviewers: [createMockUser()],
+            },
           });
 
           await waitForPromises();
@@ -667,8 +735,11 @@ describe('Reviewer dropdown component', () => {
         });
 
         it("reports 0 as the prior suggested position of the reviewer if they weren't in the initial suggested list", async () => {
-          createComponent(true, {
-            selectedReviewers: [],
+          createComponent({
+            adminMergeRequest: true,
+            propsData: {
+              selectedReviewers: [],
+            },
           });
 
           await waitForPromises();
@@ -679,7 +750,7 @@ describe('Reviewer dropdown component', () => {
           autocompleteUsersMock.mockReset();
           autocompleteUsersMock.mockResolvedValue({
             data: {
-              workspace: {
+              namespace: {
                 id: 1,
                 users: [createMockUser({ id: 3, name: 'Friend', username: 'coolguy' })],
               },
@@ -710,7 +781,10 @@ describe('Reviewer dropdown component', () => {
     describe('multipleSelectionEnabled prop', () => {
       describe('when multipleSelectionEnabled is false (default)', () => {
         beforeEach(async () => {
-          createComponent(true, { selectedReviewers: [createMockUser()] });
+          createComponent({
+            adminMergeRequest: true,
+            propsData: { selectedReviewers: [createMockUser()] },
+          });
           await waitForPromises();
         });
 
@@ -729,9 +803,12 @@ describe('Reviewer dropdown component', () => {
 
       describe('when multipleSelectionEnabled is true', () => {
         beforeEach(async () => {
-          createComponent(true, {
-            selectedReviewers: [createMockUser()],
-            multipleSelectionEnabled: true,
+          createComponent({
+            adminMergeRequest: true,
+            propsData: {
+              selectedReviewers: [createMockUser()],
+              multipleSelectionEnabled: true,
+            },
           });
           await waitForPromises();
         });
@@ -749,11 +826,50 @@ describe('Reviewer dropdown component', () => {
         });
       });
     });
+
+    describe('compositeIdentityEnforced badge', () => {
+      it('renders AI badge for users with compositeIdentityEnforced', async () => {
+        createComponent({
+          adminMergeRequest: true,
+          propsData: {},
+          customUsers: [
+            createMockUser({ id: 1, compositeIdentityEnforced: true }),
+            createMockUser({
+              id: 2,
+              name: 'Test User',
+              username: 'testuser',
+              compositeIdentityEnforced: false,
+            }),
+          ],
+          mountFn: (component, options) =>
+            mount(component, {
+              ...options,
+              stubs: {
+                'gl-emoji': true,
+              },
+            }),
+        });
+
+        await waitForPromises();
+
+        findDropdown().vm.$emit('shown');
+        await waitForPromises();
+        await nextTick();
+
+        // Find the badge in the rendered list of reviewers
+        const badges = wrapper.findAll('[data-testid="reviewer-agent-badge"]');
+        expect(badges).toHaveLength(1);
+        expect(badges.at(0).text()).toBe('AI');
+      });
+    });
   });
 
   describe('when users are passed as a prop', () => {
     beforeEach(async () => {
-      createComponent(true, { users: [createMockUser()] });
+      createComponent({
+        adminMergeRequest: true,
+        propsData: { users: [createMockUser()] },
+      });
 
       await waitForPromises();
     });
@@ -776,7 +892,7 @@ describe('Reviewer dropdown component', () => {
     });
 
     it('updates reviewers from selected user', async () => {
-      findDropdown().vm.$emit('select', ['root']);
+      findDropdown().vm.$emit('select', 'root');
 
       findDropdown().vm.$emit('hidden');
 
@@ -791,4 +907,95 @@ describe('Reviewer dropdown component', () => {
       );
     });
   });
+
+  describe('when reviewer is disabled', () => {
+    describe('and reviewer is not selected', () => {
+      beforeEach(async () => {
+        const disabledUser = createMockUser({
+          id: 2,
+          name: 'Disabled User',
+          username: 'disabled',
+          status: {
+            disabledForDuoUsage: true,
+            disabledForDuoUsageReason: 'Out of credits',
+          },
+        });
+
+        createComponent({
+          adminMergeRequest: true,
+          propsData: {
+            selectedReviewers: [],
+            multipleSelectionEnabled: true,
+            users: [createMockUser(), disabledUser],
+          },
+        });
+        await waitForPromises();
+      });
+
+      it('renders disabled reviewer with disabledReason instead of username', () => {
+        const items = findDropdown().props('items');
+        const usersGroup = items.find((group) => group.text === 'Users');
+        const disabledReviewer = usersGroup.options.find((u) => u.username === 'disabled');
+
+        expect(disabledReviewer).toMatchObject({
+          isDisabled: true,
+          disabledReason: 'Out of credits',
+        });
+      });
+
+      it('prevents disabled reviewer from being selected', async () => {
+        findDropdown().vm.$emit('select', ['disabled']);
+        findDropdown().vm.$emit('hidden');
+
+        await waitForPromises();
+
+        expect(setReviewersMutationMock).toHaveBeenCalledWith(
+          expect.objectContaining({
+            reviewerUsernames: [],
+            projectPath: 'gitlab-org/gitlab',
+            iid: '1',
+          }),
+        );
+      });
+    });
+
+    describe('and reviewer is already selected', () => {
+      beforeEach(async () => {
+        const disabledUser = createMockUser({
+          id: 2,
+          name: 'Disabled User',
+          username: 'disabled',
+          status: {
+            disabledForDuoUsage: true,
+            disabledForDuoUsageReason: 'Out of credits',
+          },
+        });
+
+        createComponent({
+          adminMergeRequest: true,
+          propsData: {
+            selectedReviewers: [disabledUser],
+            eligibleReviewers: [disabledUser],
+          },
+          customUsers: [createMockUser(), disabledUser],
+        });
+        await waitForPromises();
+      });
+
+      it('allows disabled reviewer to be removed', async () => {
+        findDropdown().vm.$emit('select', []);
+        findDropdown().vm.$emit('hidden');
+
+        await waitForPromises();
+
+        expect(setReviewersMutationMock).toHaveBeenCalledWith(
+          expect.objectContaining({
+            reviewerUsernames: [],
+            projectPath: 'gitlab-org/gitlab',
+            iid: '1',
+          }),
+        );
+      });
+    });
+  });
 });
