@@ -933,7 +933,7 @@ describe.skip('Old Notes (~/deprecated_notes.js)', () => {
 
       expect($tempNote.find('.timeline-icon .avatar').attr('src')).toEqual(currentUserAvatar);
       expect($tempNote.find('.timeline-content').hasClass('discussion')).toBe(false);
-      expect($tempNoteHeader.find('.gl-hidden.sm:gl-inline-block').text().trim()).toEqual(
+      expect($tempNoteHeader.find('.gl-hidden.@sm/panel:gl-inline-block').text().trim()).toEqual(
         currentUserFullname,
       );
 
@@ -969,7 +969,7 @@ describe.skip('Old Notes (~/deprecated_notes.js)', () => {
       });
       const $tempNoteHeader = $tempNote.find('.note-header');
 
-      expect($tempNoteHeader.find('.gl-hidden.sm:gl-inline-block').text().trim()).toEqual(
+      expect($tempNoteHeader.find('.gl-hidden.@sm/panel:gl-inline-block').text().trim()).toEqual(
         'Foo &lt;script&gt;alert(&quot;XSS&quot;)&lt;/script&gt;',
       );
     });
