@@ -6,7 +6,6 @@ import {
   VISIBILITY_LEVEL_PRIVATE_INTEGER,
   ORGANIZATION_VISIBILITY_LEVEL_DESCRIPTIONS,
 } from '~/visibility_level/constants';
-import HelpPageLink from '~/vue_shared/components/help_page_link/help_page_link.vue';
 
 describe('VisibilityLevel', () => {
   let wrapper;
@@ -41,7 +40,6 @@ describe('VisibilityLevel', () => {
 
   const findSettingsBlock = () => wrapper.findComponent(SettingsBlock);
   const findVisibilityLevelRadioButtons = () => wrapper.findComponent(VisibilityLevelRadioButtons);
-  const findHelpPageLink = () => wrapper.findComponent(HelpPageLink);
 
   beforeEach(() => {
     createComponent();
@@ -69,13 +67,4 @@ describe('VisibilityLevel', () => {
       visibilityLevelDescriptions: ORGANIZATION_VISIBILITY_LEVEL_DESCRIPTIONS,
     });
   });
-
-  it('renders label description with link to docs', () => {
-    expect(wrapper.text()).toContain('Who can see this organization?');
-    expect(findHelpPageLink().props()).toEqual({
-      href: 'user/organization/_index',
-      anchor: 'view-an-organizations-visibility-level',
-    });
-    expect(findHelpPageLink().text()).toBe('Learn more about visibility levels');
-  });
 });
