@@ -277,6 +277,36 @@ describe('Settings Panel', () => {
         settingsPanel.i18n.cve_request_toggle_label,
       );
     });
+
+    describe('work_item_planning_view feature flag', () => {
+      it('shows "Work items" label when feature flag is enabled', () => {
+        wrapper = mountComponent({ glFeatures: { workItemPlanningView: true } });
+
+        expect(findIssuesSettingsRow().props('label')).toBe('Work items');
+      });
+
+      it('shows "Issues" label when feature flag is disabled', () => {
+        wrapper = mountComponent({ glFeatures: { workItemPlanningView: false } });
+
+        expect(findIssuesSettingsRow().props('label')).toBe('Issues');
+      });
+
+      it('shows work items help text when feature flag is enabled', () => {
+        wrapper = mountComponent({ glFeatures: { workItemPlanningView: true } });
+
+        expect(findIssuesSettingsRow().props('helpText')).toBe(
+          'Plan and track work with flexible objects and views.',
+        );
+      });
+
+      it('shows issues help text when feature flag is disabled', () => {
+        wrapper = mountComponent({ glFeatures: { workItemPlanningView: false } });
+
+        expect(findIssuesSettingsRow().props('helpText')).toBe(
+          'Flexible tool to collaboratively develop ideas and plan work in this project.',
+        );
+      });
+    });
   });
 
   describe('Repository', () => {
