@@ -10,7 +10,10 @@ import ImportByUrlForm from '~/projects/new_v2/components/import_by_url_form.vue
 import SharedProjectCreationFields from '~/projects/new_v2/components/shared_project_creation_fields.vue';
 import MultiStepFormTemplate from '~/vue_shared/components/multi_step_form_template.vue';
 
-jest.mock('~/lib/utils/url_utility');
+jest.mock('~/lib/utils/url_utility', () => ({
+  ...jest.requireActual('~/lib/utils/url_utility'),
+  visitUrl: jest.fn(),
+}));
 
 const $toast = {
   show: jest.fn(),
@@ -70,6 +73,7 @@ describe('Import Project by URL Form', () => {
   const findNextButton = () => wrapper.findByTestId('import-project-by-url-next-button');
   const findBackButton = () => wrapper.findByTestId('import-project-by-url-back-button');
   const findUrlInput = () => wrapper.findByTestId('repository-url');
+  const findUrlInputWrapper = () => wrapper.findByTestId('repository-url-form-group');
   const findUsernameInput = () => wrapper.findByTestId('repository-username');
   const findPasswordInput = () => wrapper.findByTestId('repository-password');
   const findCheckConnectionButton = () => wrapper.findByTestId('check-connection');
@@ -121,13 +125,6 @@ describe('Import Project by URL Form', () => {
       expect(nextButton.attributes('type')).toBe('submit');
     });
 
-    it('disables "Create project" button when repository URL is empty', async () => {
-      await findUrlInput().vm.$emit('input', '   ');
-
-      const nextButton = findNextButton();
-      expect(nextButton.props('disabled')).toBe(true);
-    });
-
     it('navigates to `new project` page when back button is clicked', () => {
       findBackButton().vm.$emit('click');
       expect(visitUrl).toHaveBeenCalledWith(mockNewProjectPath);
@@ -160,6 +157,18 @@ describe('Import Project by URL Form', () => {
       expect(findCheckConnectionButton().props('loading')).toBe(false);
     });
 
+    it('prevents connection if url field is empty', async () => {
+      mockAxios.onPost(mockImportByUrlValidatePath).reply(HTTP_STATUS_OK, { success: true });
+
+      findUrlInput().vm.$emit('input', '');
+
+      findCheckConnectionButton().vm.$emit('click');
+      await waitForPromises();
+
+      expect(mockAxios.history.post).toHaveLength(0);
+      expect(findUrlInputWrapper().attributes('invalid-feedback')).toBe('Enter a valid URL');
+    });
+
     describe('when connection is successful', () => {
       beforeEach(async () => {
         mockAxios.onPost(mockImportByUrlValidatePath).reply(HTTP_STATUS_OK, { success: true });
@@ -207,26 +216,6 @@ describe('Import Project by URL Form', () => {
         expect($toast.show).toHaveBeenCalledWith(expect.stringContaining('Connection failed'));
       });
     });
-
-    // TODO: To be addressed in follow up before FF rollout https://gitlab.com/gitlab-org/gitlab/-/issues/562799
-    it('handles connection check with empty fields', async () => {
-      mockAxios.onPost(mockImportByUrlValidatePath).reply(HTTP_STATUS_OK, { success: true });
-
-      findUrlInput().vm.$emit('input', '');
-      findUsernameInput().vm.$emit('input', '');
-      findPasswordInput().vm.$emit('input', '');
-
-      findCheckConnectionButton().vm.$emit('click');
-      await waitForPromises();
-
-      expect(mockAxios.history.post[0].data).toBe(
-        JSON.stringify({
-          url: '',
-          user: '',
-          password: '',
-        }),
-      );
-    });
   });
 
   it('emits onSelectNamespace event when shared fields emits it', () => {
