@@ -80,6 +80,20 @@ describe('BlobDeleteFileGroup component', () => {
       expect(showDeleteBlobModalMock).toHaveBeenCalled();
     });
 
+    describe('when user cannot create merge requests', () => {
+      it('disables the button item', async () => {
+        await createComponent({
+          props: {
+            userPermissions: { pushCode: false, createMergeRequestIn: false, forkProject: true },
+          },
+        });
+
+        expect(findDeleteItem().props('item')).toMatchObject({
+          extraAttrs: { disabled: true },
+        });
+      });
+    });
+
     describe('when user cannot modify blob', () => {
       beforeEach(async () => {
         await createComponent({
