@@ -17,6 +17,11 @@ export const mockUser1 = createMockUser({
   username: 'root',
   webUrl: '/root',
   webPath: '/root',
+  status: {
+    availability: 'NOT_SET',
+    disabledForDuoUsage: false,
+    disabledForDuoUsageReason: null,
+  },
   compositeIdentityEnforced: false,
 });
 
@@ -32,6 +37,26 @@ export const mockUser2 = createMockUser({
   username: 'rookie',
   webUrl: 'rookie',
   webPath: '/rookie',
+  status: {
+    availability: 'NOT_SET',
+    disabledForDuoUsage: false,
+    disabledForDuoUsageReason: null,
+  },
+  compositeIdentityEnforced: false,
+});
+
+export const mockDisabledUser = createMockUser({
+  id: 'gid://gitlab/User/42',
+  name: 'Disabled',
+  username: 'disabled',
+  webUrl: '/disabled',
+  webPath: '/disabled',
+  avatarUrl: 'https://www.gravatar.com/avatar/e64c7d89f26bd1972efa854d13d7dd61?s=80&d=identicon',
+  status: {
+    availability: 'NOT_SET',
+    disabledForDuoUsage: true,
+    disabledForDuoUsageReason: 'Out of credits',
+  },
   compositeIdentityEnforced: false,
 });
 
@@ -290,7 +315,7 @@ const mockData = {
 
 export const issueConfidentialityResponse = (confidential = false) => ({
   data: {
-    workspace: {
+    namespace: {
       id: '1',
       __typename: 'Project',
       issuable: {
@@ -347,7 +372,7 @@ export const issuableStartDateResponse = (startDate = null) => ({
 
 export const epicParticipantsResponse = () => ({
   data: {
-    workspace: {
+    namespace: {
       id: '1',
       __typename: 'Group',
       issuable: {
@@ -374,7 +399,7 @@ export const epicParticipantsResponse = () => ({
 
 export const issueReferenceResponse = (reference) => ({
   data: {
-    workspace: {
+    namespace: {
       id: '1',
       __typename: 'Project',
       issuable: {
@@ -432,6 +457,7 @@ export const issuableQueryResponse = {
           webPath: '/root',
           status: null,
           type: userTypes.human,
+          compositeIdentityEnforced: false,
         },
         assignees: {
           nodes: [
@@ -446,6 +472,7 @@ export const issuableQueryResponse = {
               webPath: '/franc',
               status: null,
               type: userTypes.human,
+              compositeIdentityEnforced: false,
             },
           ],
         },
@@ -519,7 +546,7 @@ export const searchQueryResponse = {
 
 export const searchAutocompleteQueryResponse = {
   data: {
-    workspace: {
+    namespace: {
       __typename: 'Project',
       id: '',
       users: [
@@ -577,6 +604,7 @@ export const updateIssueAssigneesMutationResponse = {
               webPath: '/root',
               status: null,
               type: userTypes.human,
+              compositeIdentityEnforced: false,
             },
           ],
           __typename: 'UserConnection',
@@ -609,6 +637,7 @@ export const subscriptionResponse = {
             webUrl: '/root',
             webPath: '/root',
             status: null,
+            compositeIdentityEnforced: false,
           },
         ],
       },
@@ -671,7 +700,7 @@ export const searchResponseOnMR = {
 
 export const searchAutocompleteResponseOnMR = {
   data: {
-    workspace: {
+    namespace: {
       __typename: 'Project',
       id: '1',
       users: [
@@ -687,6 +716,25 @@ export const searchAutocompleteResponseOnMR = {
             canMerge: false,
           },
         },
+        {
+          __typename: 'UserCore',
+          id: 'gid://gitlab/User/2',
+          avatarUrl:
+            'https://www.gravatar.com/avatar/a95e5b71488f4b9d69ce5ff58bfd28d6?s=80\u0026d=identicon',
+          name: 'Jacki Kub',
+          username: 'francina.skiles',
+          webUrl: '/franc',
+          webPath: '/franc',
+          status: {
+            availability: 'BUSY',
+            disabledForDuoUsage: false,
+            disabledForDuoUsageReason: null,
+          },
+          compositeIdentityEnforced: false,
+          mergeRequestInteraction: {
+            canMerge: false,
+          },
+        },
       ],
     },
   },
@@ -711,6 +759,8 @@ export const projectMembersResponse = {
           webPath: '/franc',
           status: {
             availability: 'BUSY',
+            disabledForDuoUsage: false,
+            disabledForDuoUsageReason: null,
           },
         },
       ],
@@ -718,9 +768,26 @@ export const projectMembersResponse = {
   },
 };
 
+export const projectAutocompleteCustomResponse = {
+  data: {
+    namespace: {
+      id: '1',
+      projectMembers: {
+        nodes: [
+          { id: 0, user: { ...mockUser1 } },
+          {
+            id: 2,
+            user: { ...mockUser2 },
+          },
+        ],
+      },
+    },
+  },
+};
+
 export const projectAutocompleteMembersResponse = {
   data: {
-    workspace: {
+    namespace: {
       id: '1',
       __typename: 'Project',
       users: [
@@ -728,9 +795,36 @@ export const projectAutocompleteMembersResponse = {
         null,
         null,
         // Remove duplicated entry https://gitlab.com/gitlab-org/gitlab/-/issues/327822
-        { ...mockUser1, compositeIdentityEnforced: false },
-        { ...mockUser1, compositeIdentityEnforced: false },
-        { ...mockUser2, compositeIdentityEnforced: false },
+        {
+          ...mockUser1,
+          compositeIdentityEnforced: false,
+
+          status: {
+            availability: 'NOT_SET',
+            disabledForDuoUsage: false,
+            disabledForDuoUsageReason: null,
+          },
+        },
+        {
+          ...mockUser1,
+          compositeIdentityEnforced: false,
+
+          status: {
+            availability: 'NOT_SET',
+            disabledForDuoUsage: false,
+            disabledForDuoUsageReason: null,
+          },
+        },
+        {
+          ...mockUser2,
+          compositeIdentityEnforced: false,
+
+          status: {
+            availability: 'NOT_SET',
+            disabledForDuoUsage: false,
+            disabledForDuoUsageReason: null,
+          },
+        },
         {
           __typename: 'UserCore',
           id: 'gid://gitlab/User/2',
@@ -742,6 +836,8 @@ export const projectAutocompleteMembersResponse = {
           webPath: '/franc',
           status: {
             availability: 'BUSY',
+            disabledForDuoUsage: false,
+            disabledForDuoUsageReason: null,
           },
           compositeIdentityEnforced: false,
         },
@@ -768,6 +864,8 @@ export const groupMembersResponse = {
           webPath: '/franc',
           status: {
             availability: 'BUSY',
+            disabledForDuoUsage: false,
+            disabledForDuoUsageReason: null,
           },
         },
       ],
@@ -777,7 +875,7 @@ export const groupMembersResponse = {
 
 export const participantsQueryResponse = {
   data: {
-    workspace: {
+    namespace: {
       __typename: 'Project',
       id: '1',
       issuable: {
@@ -790,6 +888,7 @@ export const participantsQueryResponse = {
             // Remove duplicated entry https://gitlab.com/gitlab-org/gitlab/-/issues/327822
             mockUser1,
             mockUser1,
+            mockUser2,
             {
               __typename: 'UserCore',
               id: 'gid://gitlab/User/2',
@@ -801,6 +900,8 @@ export const participantsQueryResponse = {
               webPath: '/franc',
               status: {
                 availability: 'BUSY',
+                disabledForDuoUsage: false,
+                disabledForDuoUsageReason: null,
               },
             },
             {
@@ -838,6 +939,7 @@ export const mrAssigneesQueryResponse = {
           webPath: '/root',
           status: null,
           type: userTypes.human,
+          compositeIdentityEnforced: false,
           mergeRequestInteraction: {
             canMerge: true,
           },
@@ -886,7 +988,7 @@ export const mockMilestone2 = {
 
 export const mockProjectMilestonesResponse = {
   data: {
-    workspace: {
+    namespace: {
       id: 'gid://gitlab/Project/1',
       attributes: {
         nodes: [mockMilestone1, mockMilestone2],
@@ -899,7 +1001,7 @@ export const mockProjectMilestonesResponse = {
 
 export const mockGroupMilestonesResponse = {
   data: {
-    workspace: {
+    namespace: {
       id: 'gid://gitlab/Group/1',
       attributes: {
         nodes: [mockMilestone1, mockMilestone2],
