@@ -11,7 +11,6 @@ import {
   TRACKING_UNKNOWN_ID,
   TRACKING_UNKNOWN_PANEL,
 } from '~/super_sidebar/constants';
-import eventHub from '~/super_sidebar/event_hub';
 
 describe('NavItem component', () => {
   let wrapper;
@@ -74,39 +73,6 @@ describe('NavItem component', () => {
       expect(findPill().exists()).toBe(false);
     });
 
-    describe('updating pill value', () => {
-      const initialPillValue = '20%';
-      const updatedPillValue = '50%';
-      const itemIdForUpdate = '_some_item_id_';
-      const triggerPillValueUpdate = async ({
-        value = updatedPillValue,
-        itemId = itemIdForUpdate,
-      } = {}) => {
-        eventHub.$emit('updatePillValue', { value, itemId });
-        await nextTick();
-      };
-
-      it('updates the pill count', async () => {
-        createWrapper({
-          item: { id: itemIdForUpdate, pill_count: initialPillValue, pill_count_dynamic: true },
-        });
-
-        await triggerPillValueUpdate();
-
-        expect(findPill().text()).toBe(updatedPillValue);
-      });
-
-      it('does not update the pill count for non matching item id', async () => {
-        createWrapper({
-          item: { id: '_non_matching_id_', pill_count: initialPillValue, pill_count_dynamic: true },
-        });
-
-        await triggerPillValueUpdate();
-
-        expect(findPill().text()).toBe(initialPillValue);
-      });
-    });
-
     describe('async updating pill prop', () => {
       it('re-renders item with when prop pill_count changes', async () => {
         createWrapper({ item: { title: 'Foo', pill_count: 0 } });
@@ -177,17 +143,6 @@ describe('NavItem component', () => {
     });
   });
 
-  describe('destroyed', () => {
-    it('should unbind event listeners on eventHub', async () => {
-      jest.spyOn(eventHub, '$off');
-
-      createWrapper({ item: {} });
-      await wrapper.destroy();
-
-      expect(eventHub.$off).toHaveBeenCalledWith('updatePillValue', expect.any(Function));
-    });
-  });
-
   describe('pins', () => {
     describe('when pins are not supported', () => {
       it('does not render pin button', () => {
@@ -350,6 +305,16 @@ describe('NavItem component', () => {
     });
   });
 
+  describe('when `item.is_active` is true but item is inside a flyout menu', () => {
+    it('scrolls not into view', () => {
+      createWrapper({
+        item: { is_active: true },
+        props: { isFlyout: true },
+      });
+      expect(wrapper.element.scrollIntoView).not.toHaveBeenCalled();
+    });
+  });
+
   describe('when `item.is_active` is false', () => {
     it('scrolls not into view', () => {
       createWrapper({
