@@ -12,6 +12,7 @@ import {
   TOKEN_TITLE_ORGANIZATION,
   TOKEN_TITLE_RELEASE,
   TOKEN_TITLE_SOURCE_BRANCH,
+  TOKEN_TITLE_GROUP,
   TOKEN_TYPE_AUTHOR,
   TOKEN_TYPE_CONFIDENTIAL,
   TOKEN_TYPE_CONTACT,
@@ -21,6 +22,7 @@ import {
   TOKEN_TYPE_ORGANIZATION,
   TOKEN_TYPE_RELEASE,
   TOKEN_TYPE_SOURCE_BRANCH,
+  TOKEN_TYPE_GROUP,
 } from '~/vue_shared/components/filtered_search_bar/constants';
 import { EMOJI_THUMBS_UP } from '~/emoji/constants';
 import UserToken from '~/vue_shared/components/filtered_search_bar/tokens/user_token.vue';
@@ -29,6 +31,7 @@ import EmojiToken from '~/vue_shared/components/filtered_search_bar/tokens/emoji
 import LabelToken from '~/vue_shared/components/filtered_search_bar/tokens/label_token.vue';
 import MilestoneToken from '~/vue_shared/components/filtered_search_bar/tokens/milestone_token.vue';
 import ReleaseToken from '~/vue_shared/components/filtered_search_bar/tokens/release_token.vue';
+import GroupToken from '~/vue_shared/components/filtered_search_bar/tokens/group_token.vue';
 import CrmContactToken from '~/vue_shared/components/filtered_search_bar/tokens/crm_contact_token.vue';
 import CrmOrganizationToken from '~/vue_shared/components/filtered_search_bar/tokens/crm_organization_token.vue';
 
@@ -394,6 +397,14 @@ export const mockReleaseToken = {
   fetchReleases: () => Promise.resolve(),
 };
 
+export const mockGroupToken = {
+  icon: 'group',
+  title: TOKEN_TYPE_GROUP,
+  type: TOKEN_TITLE_GROUP,
+  token: GroupToken,
+  operators: OPERATORS_IS,
+};
+
 export const mockReactionEmojiToken = {
   type: TOKEN_TYPE_MY_REACTION,
   icon: 'thumb-up',
@@ -515,3 +526,61 @@ export const mockSortOptions = [
     },
   },
 ];
+
+export const mockGroups = [
+  {
+    id: 'gid://gitlab/Group/102',
+    name: 'box',
+    fullPath: 'toolbox/drawer/box',
+    fullName: 'toolbox/drawer/box',
+    avatarUrl: null,
+    __typename: 'Group',
+  },
+  {
+    id: 'gid://gitlab/Group/29',
+    name: 'Commit451',
+    fullPath: 'Commit451',
+    fullName: 'Commit451',
+    avatarUrl: null,
+    __typename: 'Group',
+  },
+];
+
+export const mockGroupResponse = {
+  data: {
+    groups: {
+      nodes: mockGroups,
+    },
+  },
+};
+
+export const mockSubGroups = {
+  data: {
+    group: {
+      id: 'gid://gitlab/Group/95',
+      name: 'Code Suggestions Group',
+      fullName: 'Code Suggestions Group',
+      fullPath: 'code-suggestions-group',
+      __typename: 'Group',
+      descendantGroups: {
+        nodes: [
+          {
+            id: 'gid://gitlab/Group/99',
+            name: 'Code Suggestions Subgroup',
+            fullName: 'Code Suggestions Group / Code Suggestions Subgroup',
+            fullPath: 'code-suggestions-group/code-suggestions-subgroup',
+            __typename: 'Group',
+          },
+        ],
+        pageInfo: {
+          hasNextPage: false,
+          hasPreviousPage: false,
+          startCursor: null,
+          endCursor: null,
+          __typename: 'PageInfo',
+        },
+        __typename: 'GroupConnection',
+      },
+    },
+  },
+};
