@@ -230,7 +230,12 @@ describe('BaseToken', () => {
             const props = { defaultSuggestions: [], suggestions: mockSuggestions };
 
             getRecentlyUsedSuggestions.mockReturnValue([]);
-            wrapper = createComponent({ props, mountFn: shallowMountExtended, stubs: {} });
+            wrapper = createComponent({
+              props,
+              mountFn: shallowMountExtended,
+              stubs: {},
+              data: { isFetching: true },
+            });
             findGlFilteredSearchToken().vm.$emit('input', { data: searchKey });
 
             await nextTick();
@@ -254,7 +259,12 @@ describe('BaseToken', () => {
         const props = { defaultSuggestions: [], suggestions: mockSuggestions, config };
 
         getRecentlyUsedSuggestions.mockReturnValue([]);
-        wrapper = createComponent({ props, mountFn: shallowMountExtended, stubs: {} });
+        wrapper = createComponent({
+          props,
+          data: { isFetching: true },
+          mountFn: shallowMountExtended,
+          stubs: {},
+        });
 
         expect(findMockSuggestionList().exists()).toBe(true);
         expect(getMockSuggestionListSuggestions()).toHaveLength(maxSuggestions);
@@ -384,9 +394,9 @@ describe('BaseToken', () => {
 
     describe('with no suggestions', () => {
       it.each`
-        data                       | expected
-        ${{ searchKey: 'search' }} | ${'No matches found'}
-        ${{ hasFetched: true }}    | ${'No suggestions found'}
+        data                                         | expected
+        ${{ searchKey: 'search', isFetching: true }} | ${'No matches found'}
+        ${{ isFetching: true }}                      | ${'No suggestions found'}
       `('shows $expected text', ({ data, expected }) => {
         wrapper = createComponent({
           props: {
@@ -453,6 +463,7 @@ describe('BaseToken', () => {
           config: mockLabelToken,
           suggestionsLoading: true,
         },
+        data: { isFetching: false },
         stubs: { Portal: true },
       });
 
