@@ -1,14 +1,12 @@
 import { nextTick } from 'vue';
-import { GlAvatarLabeled, GlIcon, GlTooltip } from '@gitlab/ui';
+import { GlAvatar, GlAvatarLabeled, GlIcon, GlTooltip } from '@gitlab/ui';
 import { stubComponent } from 'helpers/stub_component';
 import { mountExtended } from 'helpers/vue_test_utils_helper';
-import ListItemDescription from '~/vue_shared/components/resource_lists/list_item_description.vue';
 import ProjectListItemActions from '~/vue_shared/components/projects_list/project_list_item_actions.vue';
 import ListItemInactiveBadge from '~/vue_shared/components/resource_lists/list_item_inactive_badge.vue';
+import CiCatalogBadge from '~/vue_shared/components/projects_list/ci_catalog_badge.vue';
 import ProjectsListItem from '~/vue_shared/components/projects_list/projects_list_item.vue';
-import ProjectListItemDelayedDeletionModalFooter from '~/vue_shared/components/projects_list/project_list_item_delayed_deletion_modal_footer.vue';
 import { ACTION_DELETE, ACTION_EDIT } from '~/vue_shared/components/list_actions/constants';
-import waitForPromises from 'helpers/wait_for_promises';
 import {
   PROJECT_VISIBILITY_TYPE,
   VISIBILITY_LEVEL_PRIVATE_STRING,
@@ -18,30 +16,14 @@ import { ACCESS_LEVEL_LABELS, ACCESS_LEVEL_NO_ACCESS_INTEGER } from '~/access_le
 import { FEATURABLE_DISABLED, FEATURABLE_ENABLED } from '~/featurable/constants';
 import TimeAgoTooltip from '~/vue_shared/components/time_ago_tooltip.vue';
 import TopicBadges from '~/vue_shared/components/topic_badges.vue';
-import DeleteModal from '~/projects/components/shared/delete_modal.vue';
 import {
   TIMESTAMP_TYPE_CREATED_AT,
   TIMESTAMP_TYPE_UPDATED_AT,
 } from '~/vue_shared/components/resource_lists/constants';
-import {
-  deleteParams,
-  renderDeleteSuccessToast,
-} from '~/vue_shared/components/projects_list/utils';
-import { deleteProject } from '~/api/projects_api';
-import { createAlert } from '~/alert';
 import CiIcon from '~/vue_shared/components/ci_icon/ci_icon.vue';
 import ListItem from '~/vue_shared/components/resource_lists/list_item.vue';
 import { projects } from './mock_data';
 
-const MOCK_DELETE_PARAMS = {
-  testParam: true,
-};
-
-jest.mock('~/vue_shared/components/projects_list/utils', () => ({
-  ...jest.requireActual('~/vue_shared/components/projects_list/utils'),
-  renderDeleteSuccessToast: jest.fn(),
-  deleteParams: jest.fn(() => MOCK_DELETE_PARAMS),
-}));
 jest.mock('~/alert');
 jest.mock('~/api/projects_api');
 
@@ -70,18 +52,12 @@ describe('ProjectsListItem', () => {
   const findListActions = () => wrapper.findComponent(ProjectListItemActions);
   const findAccessLevelBadge = () => wrapper.findByTestId('user-access-role');
   const findStorageSizeBadge = () => wrapper.findByTestId('storage-size');
-  const findCiCatalogBadge = () => wrapper.findByTestId('ci-catalog-badge');
-  const findProjectDescription = () => wrapper.findComponent(ListItemDescription);
+  const findCiCatalogBadge = () => wrapper.findComponent(CiCatalogBadge);
+  const findProjectDescription = () => wrapper.findByTestId('description-html');
   const findInactiveBadge = () => wrapper.findComponent(ListItemInactiveBadge);
   const findTimeAgoTooltip = () => wrapper.findComponent(TimeAgoTooltip);
   const findTopicBadges = () => wrapper.findComponent(TopicBadges);
-  const findDeleteModal = () => wrapper.findComponent(DeleteModal);
-  const findDelayedDeletionModalFooter = () =>
-    wrapper.findComponent(ProjectListItemDelayedDeletionModalFooter);
-  const deleteModalFirePrimaryEvent = async () => {
-    findDeleteModal().vm.$emit('primary');
-    await nextTick();
-  };
+
   const findTooltipByTarget = (target) =>
     wrapper
       .findAllComponents(GlTooltip)
@@ -98,6 +74,36 @@ describe('ProjectsListItem', () => {
     });
   });
 
+  describe('when includeMicrodata prop is true', () => {
+    beforeEach(() => {
+      createComponent({ propsData: { includeMicrodata: true } });
+    });
+
+    it('adds microdata attributes to list element', () => {
+      expect(wrapper.attributes()).toMatchObject({
+        itemtype: 'https://schema.org/SoftwareSourceCode',
+        itemprop: 'owns',
+        itemscope: expect.any(String),
+      });
+    });
+
+    it('adds microdata attributes to avatar', () => {
+      const avatarLabeled = findAvatarLabeled();
+
+      expect(avatarLabeled.props()).toMatchObject({
+        labelLinkAttrs: { itemprop: 'name' },
+      });
+
+      expect(avatarLabeled.findComponent(GlAvatar).attributes()).toMatchObject({
+        itemprop: 'image',
+      });
+    });
+
+    it('adds microdata to description', () => {
+      expect(findProjectDescription().attributes()).toMatchObject({ itemprop: 'description' });
+    });
+  });
+
   it('renders project avatar', () => {
     createComponent();
 
@@ -106,11 +112,8 @@ describe('ProjectsListItem', () => {
     expect(avatarLabeled.props()).toMatchObject({
       label: project.nameWithNamespace,
       labelLink: project.relativeWebUrl,
-    });
-
-    expect(avatarLabeled.attributes()).toMatchObject({
-      'entity-id': project.id.toString(),
-      'entity-name': project.nameWithNamespace,
+      entityId: project.id,
+      entityName: project.nameWithNamespace,
       src: project.avatarUrl,
       shape: 'rect',
     });
@@ -535,72 +538,7 @@ describe('ProjectsListItem', () => {
     });
 
     it('displays actions dropdown', () => {
-      expect(findListActions().exists()).toBe(true);
-    });
-
-    describe('when delete action is fired', () => {
-      beforeEach(() => {
-        findListActions().vm.$emit('delete');
-      });
-
-      it('displays confirmation modal with correct props', () => {
-        expect(wrapper.findComponent(DeleteModal).props()).toMatchObject({
-          visible: true,
-          confirmPhrase: project.fullPath,
-          nameWithNamespace: project.nameWithNamespace,
-          isFork: true,
-          issuesCount: '0',
-          forksCount: '0',
-          starsCount: '0',
-          confirmLoading: false,
-        });
-      });
-
-      describe('when deletion is confirmed', () => {
-        describe('when API call is successful', () => {
-          it('calls deleteProject, properly sets loading state, and emits refetch event', async () => {
-            deleteProject.mockResolvedValueOnce();
-
-            await deleteModalFirePrimaryEvent();
-            expect(deleteParams).toHaveBeenCalledWith(projectWithActions);
-            expect(deleteProject).toHaveBeenCalledWith(projectWithActions.id, MOCK_DELETE_PARAMS);
-            expect(findDeleteModal().props('confirmLoading')).toBe(true);
-
-            await waitForPromises();
-
-            expect(findDeleteModal().props('confirmLoading')).toBe(false);
-            expect(wrapper.emitted('refetch')).toEqual([[]]);
-            expect(renderDeleteSuccessToast).toHaveBeenCalledWith(projectWithActions, 'Project');
-            expect(createAlert).not.toHaveBeenCalled();
-          });
-        });
-
-        describe('when API call is not successful', () => {
-          const error = new Error();
-
-          it('calls deleteProject, properly sets loading state, and shows error alert', async () => {
-            deleteProject.mockRejectedValue(error);
-            await deleteModalFirePrimaryEvent();
-
-            expect(deleteParams).toHaveBeenCalledWith(projectWithActions);
-            expect(deleteProject).toHaveBeenCalledWith(projectWithActions.id, MOCK_DELETE_PARAMS);
-            expect(findDeleteModal().props('confirmLoading')).toBe(true);
-
-            await waitForPromises();
-
-            expect(findDeleteModal().props('confirmLoading')).toBe(false);
-
-            expect(wrapper.emitted('refetch')).toBeUndefined();
-            expect(createAlert).toHaveBeenCalledWith({
-              message:
-                'An error occurred deleting the project. Please refresh the page to try again.',
-              error,
-              captureError: true,
-            });
-            expect(renderDeleteSuccessToast).not.toHaveBeenCalled();
-          });
-        });
-      });
+      expect(findListActions().props('project')).toBe(projectWithActions);
     });
   });
 
@@ -615,23 +553,46 @@ describe('ProjectsListItem', () => {
       });
     });
 
-    describe('when project is in the CI Catalog', () => {
+    describe('when project is not published in the CI Catalog', () => {
       beforeEach(() => {
         createComponent({
           propsData: {
             project: {
               ...project,
               isCatalogResource: true,
-              exploreCatalogPath: `/catalog/${project.pathWithNamespace}`,
+              isPublished: false,
             },
           },
         });
       });
 
-      it('renders badge with correct link', () => {
-        expect(findCiCatalogBadge().exists()).toBe(true);
-        expect(findCiCatalogBadge().text()).toBe('CI/CD Catalog project');
-        expect(findCiCatalogBadge().props('href')).toBe(`/catalog/${project.pathWithNamespace}`);
+      it('renders badge without a link', () => {
+        expect(findCiCatalogBadge().props()).toEqual({
+          isPublished: false,
+          exploreCatalogPath: null,
+        });
+      });
+    });
+  });
+
+  describe('when project is published in the CI Catalog', () => {
+    beforeEach(() => {
+      createComponent({
+        propsData: {
+          project: {
+            ...project,
+            isCatalogResource: true,
+            isPublished: true,
+            exploreCatalogPath: `/catalog/${project.pathWithNamespace}`,
+          },
+        },
+      });
+    });
+
+    it('renders badge with correct link', () => {
+      expect(findCiCatalogBadge().props()).toEqual({
+        isPublished: true,
+        exploreCatalogPath: `/catalog/${project.pathWithNamespace}`,
       });
     });
   });
@@ -683,22 +644,4 @@ describe('ProjectsListItem', () => {
 
     expect(wrapper.element.firstChild.classList).toContain('foo');
   });
-
-  describe('ProjectListItemDelayedDeletionModalFooter', () => {
-    const deleteProps = {
-      project: {
-        ...project,
-        availableActions: [ACTION_DELETE],
-        actionLoadingStates: { [ACTION_DELETE]: false },
-      },
-    };
-
-    it('renders modal footer', () => {
-      createComponent({ propsData: deleteProps });
-      findListActions().vm.$emit('delete');
-
-      expect(findDeleteModal().exists()).toBe(true);
-      expect(findDelayedDeletionModalFooter().exists()).toBe(false);
-    });
-  });
 });
