@@ -18,7 +18,7 @@ import {
 import { WIDGET_TYPE_NOTES } from '~/work_items/constants';
 
 const mockWorkItemNotesWidgetResponseWithComments =
-  mockWorkItemNotesResponseWithComments().data.workspace.workItem.widgets.find(
+  mockWorkItemNotesResponseWithComments().data.namespace.workItem.widgets.find(
     (widget) => widget.type === WIDGET_TYPE_NOTES,
   );
 
