@@ -57,7 +57,7 @@ describe('WorkItemTokenInput', () => {
           workItemType: {
             id: 'gid://gitlab/WorkItems::Type/5',
             name: 'Task',
-            iconName: 'issue-type-task',
+            iconName: 'work-item-task',
             __typename: 'WorkItemType',
           },
           __typename: 'WorkItem',
@@ -76,7 +76,7 @@ describe('WorkItemTokenInput', () => {
           workItemType: {
             id: 'gid://gitlab/WorkItems::Type/5',
             name: 'Task',
-            iconName: 'issue-type-task',
+            iconName: 'work-item-task',
             __typename: 'WorkItemType',
           },
           __typename: 'WorkItem',
@@ -95,7 +95,7 @@ describe('WorkItemTokenInput', () => {
           workItemType: {
             id: 'gid://gitlab/WorkItems::Type/5',
             name: 'Task',
-            iconName: 'issue-type-task',
+            iconName: 'work-item-task',
             __typename: 'WorkItemType',
           },
           __typename: 'WorkItem',
@@ -202,7 +202,7 @@ describe('WorkItemTokenInput', () => {
     workItemType: {
       id: 'gid://gitlab/WorkItems::Type/5',
       name: 'Task',
-      iconName: 'issue-type-task',
+      iconName: 'work-item-task',
       __typename: 'WorkItemType',
     },
     __typename: 'WorkItem',
@@ -222,7 +222,7 @@ describe('WorkItemTokenInput', () => {
     workItemType: {
       id: 'gid://gitlab/WorkItems::Type/5',
       name: 'Task',
-      iconName: 'issue-type-task',
+      iconName: 'work-item-task',
       __typename: 'WorkItemType',
     },
     __typename: 'WorkItem',
@@ -367,7 +367,7 @@ describe('WorkItemTokenInput', () => {
       workItemType: {
         id: 'gid://gitlab/WorkItems::Type/5',
         name: 'Task',
-        iconName: 'issue-type-task',
+        iconName: 'work-item-task',
         __typename: 'WorkItemType',
       },
       __typename: 'WorkItem',
@@ -386,7 +386,7 @@ describe('WorkItemTokenInput', () => {
       workItemType: {
         id: 'gid://gitlab/WorkItems::Type/5',
         name: 'Task',
-        iconName: 'issue-type-task',
+        iconName: 'work-item-task',
         __typename: 'WorkItemType',
       },
       __typename: 'WorkItem',
@@ -405,7 +405,7 @@ describe('WorkItemTokenInput', () => {
       workItemType: {
         id: 'gid://gitlab/WorkItems::Type/5',
         name: 'Task',
-        iconName: 'issue-type-task',
+        iconName: 'work-item-task',
         __typename: 'WorkItemType',
       },
       __typename: 'WorkItem',
