@@ -44,11 +44,28 @@ RSpec.describe Resolvers::Users::ParticipantsResolver do
     let_it_be(:public_reply_emoji_author) { create(:award_emoji, name: AwardEmoji::THUMBS_UP, awardable: public_reply).user }
     let_it_be(:internal_reply_emoji_author) { create(:award_emoji, name: AwardEmoji::THUMBS_UP, awardable: internal_reply).user }
 
+    let_it_be(:expected_participants) do
+      [
+        issue.author,
+        issue_emoji_author,
+        public_note_author,
+        public_note_emoji_author,
+        public_reply_author,
+        internal_note_author,
+        internal_note_emoji_author,
+        internal_reply_author,
+        public_reply_emoji_author,
+        internal_reply_emoji_author,
+        system_note_author,
+        internal_system_note_author
+      ]
+    end
+
     subject(:resolved_items) do
       resolve(described_class, args: {}, ctx: { current_user: current_user }, obj: issue)&.items
     end
 
-    before_all do
+    before do
       create(:system_note, project: project, noteable: issue, author: system_note_author)
       create(
         :system_note,
@@ -61,59 +78,74 @@ RSpec.describe Resolvers::Users::ParticipantsResolver do
     context 'when current user is not set' do
       let(:current_user) { nil }
 
-      it 'returns only publicly visible participants for this user' do
-        is_expected.to match_array(
-          [
-            issue.author,
-            issue_emoji_author,
-            public_note_author,
-            public_note_emoji_author,
-            public_reply_author,
-            public_reply_emoji_author,
-            system_note_author
-          ]
-        )
+      it 'returns all participants who have group/project access' do
+        is_expected.to match_array(expected_participants)
+      end
+
+      context 'with remove_per_source_permission_from_participants disabled' do
+        before do
+          stub_feature_flags(remove_per_source_permission_from_participants: false)
+        end
+
+        it 'returns only publicly visible participants for this user' do
+          is_expected.to match_array(
+            [
+              issue.author,
+              issue_emoji_author,
+              public_note_author,
+              public_note_emoji_author,
+              public_reply_author,
+              public_reply_emoji_author,
+              system_note_author
+            ]
+          )
+        end
       end
     end
 
     context 'when current user does not have enough permissions' do
       let(:current_user) { guest }
 
-      it 'returns only publicly visible participants for this user' do
-        is_expected.to match_array(
-          [
-            issue.author,
-            issue_emoji_author,
-            public_note_author,
-            public_note_emoji_author,
-            public_reply_author,
-            public_reply_emoji_author,
-            system_note_author
-          ]
-        )
+      it 'returns all participants who have group/project access' do
+        is_expected.to match_array(expected_participants)
+      end
+
+      context 'with remove_per_source_permission_from_participants disabled' do
+        before do
+          stub_feature_flags(remove_per_source_permission_from_participants: false)
+        end
+
+        it 'returns only publicly visible participants for this user' do
+          is_expected.to match_array(
+            [
+              issue.author,
+              issue_emoji_author,
+              public_note_author,
+              public_note_emoji_author,
+              public_reply_author,
+              public_reply_emoji_author,
+              system_note_author
+            ]
+          )
+        end
       end
     end
 
     context 'when current user has access to internal notes' do
       let(:current_user) { user }
 
-      it 'returns all participants for this user' do
-        is_expected.to match_array(
-          [
-            issue.author,
-            issue_emoji_author,
-            public_note_author,
-            public_note_emoji_author,
-            public_reply_author,
-            internal_note_author,
-            internal_note_emoji_author,
-            internal_reply_author,
-            public_reply_emoji_author,
-            internal_reply_emoji_author,
-            system_note_author,
-            internal_system_note_author
-          ]
-        )
+      it 'returns all participants who have group/project access' do
+        is_expected.to match_array(expected_participants)
+      end
+
+      context 'with remove_per_source_permission_from_participants disabled' do
+        before do
+          stub_feature_flags(remove_per_source_permission_from_participants: false)
+        end
+
+        it 'returns all participants who have group/project access' do
+          is_expected.to match_array(expected_participants)
+        end
       end
 
       context 'N+1 queries' do
@@ -126,7 +158,7 @@ RSpec.describe Resolvers::Users::ParticipantsResolver do
           query.call
         end
 
-        it 'does not execute N+1 for project relation', :request_store do
+        it 'does not execute N+1 queries when adding participants', :request_store do
           control_count = ActiveRecord::QueryRecorder.new { query.call }
 
           create(:award_emoji, :upvote, awardable: issue)
@@ -135,11 +167,7 @@ RSpec.describe Resolvers::Users::ParticipantsResolver do
           public_note = create(:note, project: project, noteable: issue, author: create(:user))
           create(:award_emoji, name: AwardEmoji::THUMBS_UP, awardable: public_note)
 
-          # 1 extra query per source (3 emojis + 2 notes) to fetch participables collection
-          # 2 extra queries to load work item widgets collection
-          # 1 extra query to load the project creator to check if they are banned
-          # 1 extra query to load the invited groups to see if the user is banned from any of them
-          expect { query.call }.not_to exceed_query_limit(control_count).with_threshold(9)
+          expect { query.call }.not_to exceed_query_limit(control_count)
         end
 
         it 'does not execute N+1 for system note metadata relation' do
@@ -150,6 +178,28 @@ RSpec.describe Resolvers::Users::ParticipantsResolver do
 
           expect { query.call }.not_to exceed_query_limit(control_count)
         end
+
+        context 'with remove_per_source_permission_from_participants disabled' do
+          before do
+            stub_feature_flags(remove_per_source_permission_from_participants: false)
+          end
+
+          it 'does not execute N+1 for project relation', :request_store do
+            control_count = ActiveRecord::QueryRecorder.new { query.call }
+
+            create(:award_emoji, :upvote, awardable: issue)
+            internal_note = create(:note, :confidential, project: project, noteable: issue, author: create(:user))
+            create(:award_emoji, name: AwardEmoji::THUMBS_UP, awardable: internal_note)
+            public_note = create(:note, project: project, noteable: issue, author: create(:user))
+            create(:award_emoji, name: AwardEmoji::THUMBS_UP, awardable: public_note)
+
+            # 1 extra query per source (3 emojis + 2 notes) to fetch participables collection
+            # 2 extra queries to load work item widgets collection
+            # 1 extra query to load the project creator to check if they are banned
+            # 1 extra query to load the invited groups to see if the user is banned from any of them
+            expect { query.call }.not_to exceed_query_limit(control_count).with_threshold(9)
+          end
+        end
       end
     end
   end
