@@ -10,7 +10,7 @@ RSpec.describe Types::Ci::CiCdSettingType, feature_category: :continuous_integra
       group_runners_enabled inbound_job_token_scope_enabled job_token_scope_enabled
       keep_latest_artifact merge_pipelines_enabled project
       push_repository_for_job_token_allowed
-      pipeline_variables_minimum_override_role
+      pipeline_variables_minimum_override_role resource_group_default_process_mode
       display_pipeline_variables
     ]
 
