@@ -36,7 +36,7 @@ RSpec.describe Types::Ci::Inputs::SpecType, feature_category: :pipeline_composit
 
     let(:spec_type) { described_class.authorized_new(input_hash, query_context) }
 
-    context 'when the feature flag is disabled' do
+    context 'when rules are present' do
       let(:spec) do
         {
           type: 'string',
@@ -49,55 +49,27 @@ RSpec.describe Types::Ci::Inputs::SpecType, feature_category: :pipeline_composit
         }
       end
 
-      before do
-        stub_feature_flags(ci_dynamic_pipeline_inputs: false)
+      it 'returns the rules' do
+        rules = spec_type.rules
+
+        expect(rules).to be_an(Array)
+        expect(rules.size).to eq(1)
+        expect(rules.first['if']).to eq('$[[ inputs.environment ]] == "production"')
+        expect(rules.first['options']).to eq(%w[opt1 opt2])
+      end
+    end
+
+    context 'when rules are not present' do
+      let(:spec) do
+        {
+          type: 'string',
+          default: 'value'
+        }
       end
 
       it 'returns nil' do
         expect(spec_type.rules).to be_nil
       end
     end
-
-    context 'when the feature flag is enabled' do
-      before do
-        stub_feature_flags(ci_dynamic_pipeline_inputs: project)
-      end
-
-      context 'when rules are present' do
-        let(:spec) do
-          {
-            type: 'string',
-            rules: [
-              {
-                'if' => '$[[ inputs.environment ]] == "production"',
-                'options' => %w[opt1 opt2]
-              }
-            ]
-          }
-        end
-
-        it 'returns the rules' do
-          rules = spec_type.rules
-
-          expect(rules).to be_an(Array)
-          expect(rules.size).to eq(1)
-          expect(rules.first['if']).to eq('$[[ inputs.environment ]] == "production"')
-          expect(rules.first['options']).to eq(%w[opt1 opt2])
-        end
-      end
-
-      context 'when rules are not present' do
-        let(:spec) do
-          {
-            type: 'string',
-            default: 'value'
-          }
-        end
-
-        it 'returns nil' do
-          expect(spec_type.rules).to be_nil
-        end
-      end
-    end
   end
 end
