@@ -21,4 +21,10 @@ RSpec.describe GitlabSchema.types['Discussion'] do
   end
 
   specify { expect(described_class).to require_graphql_authorizations(:read_note) }
+
+  describe '.authorization_scopes' do
+    it 'allows ai_workflows scope token' do
+      expect(described_class.authorization_scopes).to include(:ai_workflows)
+    end
+  end
 end
