@@ -14,6 +14,6 @@ RSpec.describe Types::UserStatusType do
       clear_status_at
     ]
 
-    expect(described_class).to have_graphql_fields(*expected_fields)
+    expect(described_class).to have_graphql_fields(*expected_fields).at_least
   end
 end
