@@ -657,7 +657,9 @@ RSpec.describe BlobHelper, feature_category: :source_code_management do
         ssh_url: ssh_clone_url_to_repo(project),
         http_url: http_clone_url_to_repo(project),
         xcode_url: 'xcode://example.com/project.git',
-        download_links: helper.send(:archive_download_links, project, ref, "#{project.path}-#{ref.tr('/', '-')}").to_json
+        download_links: helper.send(:archive_download_links, project, ref, "#{project.path}-#{ref.tr('/', '-')}").to_json,
+        web_ide_button_options: helper.web_ide_button_data({ blob: blob }).merge(helper.fork_modal_options(project, blob)).to_json,
+        web_ide_button_default_branch: project.default_branch_or_main
       })
     end
 
