@@ -337,8 +337,7 @@ RSpec.describe MergeRequestsHelper, feature_category: :code_review_workflow do
         rss_url: '/rss-url',
         releases_endpoint: project_releases_path(project, format: :json),
         can_bulk_update: 'true',
-        environment_names_path: unfoldered_environment_names_project_path(project, format: :json),
-        default_branch: project.default_branch
+        environment_names_path: unfoldered_environment_names_project_path(project, format: :json)
       }
 
       expect(subject).to include(expected_data)
