@@ -72,11 +72,10 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
       if user
         allow(user).to receive(:assigned_open_issues_count).and_return(1)
         allow(user).to receive(:assigned_open_merge_requests_count).and_return(4)
+        allow(user).to receive(:returned_to_you_merge_requests_count).and_return(0)
         allow(user).to receive(:review_requested_open_merge_requests_count).and_return(0)
         allow(user).to receive(:todos_pending_count).and_return(3)
         allow(user).to receive(:pinned_nav_items).and_return({ panel_type => %w[foo bar], 'another_panel' => %w[baz] })
-        allow(user).to receive(:review_requested_open_merge_requests_count_in_cache?).and_return(true)
-        allow(user).to receive(:assigned_open_merge_requests_count_in_cache?).and_return(true)
       end
     end
 
@@ -90,7 +89,7 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
     it 'returns terms if defined' do
       stub_application_setting(terms: "My custom Terms of Use")
 
-      is_expected.to include({ terms: "/-/users/terms" })
+      is_expected.to include({ terms: terms_path })
     end
 
     it 'does not return terms if not set' do
@@ -103,7 +102,7 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
         is_admin: false,
         name: user.name,
         username: user.username,
-        admin_url: admin_root_url,
+        admin_url: admin_root_path,
         admin_mode: {
           admin_mode_feature_enabled: true,
           admin_mode_active: false,
@@ -144,12 +143,13 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
         groups_path: dashboard_groups_path,
         gitlab_com_but_not_canary: Gitlab.com_but_not_canary?,
         gitlab_com_and_canary: Gitlab.com_and_canary?,
-        canary_toggle_com_url: Gitlab::Saas.canary_toggle_com_url,
+        canary_toggle_com_url: Gitlab.canary_toggle_com_url,
         pinned_items: %w[foo bar],
         update_pins_url: pins_path,
         shortcut_links: global_shortcut_links,
         track_visits_path: track_namespace_visits_path,
-        work_items: nil
+        work_items: nil,
+        has_multiple_organizations: false
       })
     end
 
@@ -287,50 +287,6 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
       end
     end
 
-    it 'returns "Merge requests" menu', :use_clean_rails_memory_store_caching do
-      expect(subject[:merge_request_menu]).to eq([
-        {
-          name: _('Merge requests'),
-          items: [
-            {
-              text: _('Assigned'),
-              href: merge_requests_dashboard_path(assignee_username: user.username),
-              count: 4,
-              userCount: 'assigned_merge_requests',
-              extraAttrs: {
-                'data-track-action': 'click_link',
-                'data-track-label': 'merge_requests_assigned',
-                'data-track-property': 'nav_core_menu',
-                class: 'dashboard-shortcuts-merge_requests'
-              }
-            },
-            {
-              text: _('Review requests'),
-              href: merge_requests_dashboard_path(reviewer_username: user.username),
-              count: 0,
-              userCount: 'review_requested_merge_requests',
-              extraAttrs: {
-                'data-track-action': 'click_link',
-                'data-track-label': 'merge_requests_to_review',
-                'data-track-property': 'nav_core_menu',
-                class: 'dashboard-shortcuts-review_requests'
-              }
-            }
-          ]
-        }
-      ])
-    end
-
-    context 'when merge_request_dashboard feature flag is enabled' do
-      before do
-        stub_feature_flags(merge_request_dashboard: true)
-      end
-
-      it 'returns nil for merge_request_menu' do
-        expect(subject[:merge_request_menu]).to be_nil
-      end
-    end
-
     describe '"Create new" menu groups', :use_clean_rails_memory_store_caching do
       def menu_item(href:, text:, id:, component: nil)
         {
@@ -359,190 +315,92 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
           end
         end
 
-        context 'when current Organization has scoped paths' do
-          let(:expected_menu_item_groups) do
-            [
-              menu_item(
-                href: "/o/#{current_organization.path}/projects/new",
-                text: "New project/repository",
-                id: "general_new_project"
-              ),
-              menu_item(
-                href: "/o/#{current_organization.path}/groups/new",
-                text: "New group",
-                id: "general_new_group"
-              ),
-              menu_item(
-                href: "/-/organizations/new",
-                text: s_('Organization|New organization'),
-                id: "general_new_organization"
-              ),
-              menu_item(
-                href: "/-/snippets/new",
-                text: "New snippet",
-                id: "general_new_snippet"
-              )
-            ]
-          end
-
-          before do
-            allow(current_organization).to receive(:scoped_paths?).and_return(true)
-          end
-
-          include_examples '"Create new" menu groups without headers'
+        let(:expected_menu_item_groups) do
+          [
+            menu_item(
+              href: new_project_path,
+              text: "New project/repository",
+              id: "general_new_project"
+            ),
+            menu_item(
+              href: new_group_path,
+              text: "New group",
+              id: "general_new_group"
+            ),
+            menu_item(
+              href: new_organization_path,
+              text: s_('Organization|New organization'),
+              id: "general_new_organization"
+            ),
+            menu_item(
+              href: new_snippet_path,
+              text: "New snippet",
+              id: "general_new_snippet"
+            )
+          ]
         end
 
-        context 'when current Organization does not have scoped paths' do
-          let(:expected_menu_item_groups) do
-            [
-              menu_item(
-                href: "/projects/new",
-                text: "New project/repository",
-                id: "general_new_project"
-              ),
-              menu_item(
-                href: "/groups/new",
-                text: "New group",
-                id: "general_new_group"
-              ),
-              menu_item(
-                href: "/-/organizations/new",
-                text: s_('Organization|New organization'),
-                id: "general_new_organization"
-              ),
-              menu_item(
-                href: "/-/snippets/new",
-                text: "New snippet",
-                id: "general_new_snippet"
-              )
-            ]
-          end
-
-          before do
-            allow(current_organization).to receive(:scoped_paths?).and_return(false)
-          end
-
-          include_examples '"Create new" menu groups without headers'
-        end
+        include_examples '"Create new" menu groups without headers'
       end
 
       context 'with headers' do
+        let(:in_this_group_menu_items) do
+          [
+            menu_item(
+              href: new_project_path,
+              text: "New project/repository",
+              id: "new_project"
+            ),
+            menu_item(
+              href: new_group_path(anchor: 'create-group-pane'),
+              text: "New subgroup",
+              id: "new_subgroup"
+            ),
+            menu_item(
+              href: nil,
+              text: "Invite members",
+              component: 'invite_members',
+              id: "invite"
+            )
+          ]
+        end
+
+        let(:in_gitlab_menu_items) do
+          [
+            menu_item(
+              href: new_project_path,
+              text: "New project/repository",
+              id: "general_new_project"
+            ),
+            menu_item(
+              href: new_group_path,
+              text: "New group",
+              id: "general_new_group"
+            ),
+            menu_item(
+              href: new_snippet_path,
+              text: "New snippet",
+              id: "general_new_snippet"
+            )
+          ]
+        end
+
         before do
           allow(group).to receive(:persisted?).and_return(true)
           allow(helper).to receive(:can?).and_return(true)
         end
 
-        shared_examples '"Create new" menu groups with headers' do
-          it 'returns "Create new" menu groups with headers' do
-            expect(subject[:create_new_menu_groups]).to contain_exactly(
-              a_hash_including(
-                name: "In this group",
-                items: array_including(*in_this_group_menu_items)
-              ),
-              a_hash_including(
-                name: "In GitLab",
-                items: array_including(*in_gitlab_menu_items)
-              )
+        it 'returns "Create new" menu groups with headers' do
+          expect(subject[:create_new_menu_groups]).to contain_exactly(
+            a_hash_including(
+              name: "In this group",
+              items: array_including(*in_this_group_menu_items)
+            ),
+            a_hash_including(
+              name: "In GitLab",
+              items: array_including(*in_gitlab_menu_items)
             )
-          end
-        end
-
-        context 'when current Organization has scoped paths' do
-          let(:in_this_group_menu_items) do
-            [
-              menu_item(
-                href: "/o/#{current_organization.path}/projects/new",
-                text: "New project/repository",
-                id: "new_project"
-              ),
-              menu_item(
-                href: "/o/#{current_organization.path}/groups/new#create-group-pane",
-                text: "New subgroup",
-                id: "new_subgroup"
-              ),
-              menu_item(
-                href: nil,
-                text: "Invite members",
-                component: 'invite_members',
-                id: "invite"
-              )
-            ]
-          end
-
-          let(:in_gitlab_menu_items) do
-            [
-              menu_item(
-                href: "/o/#{current_organization.path}/projects/new",
-                text: "New project/repository",
-                id: "general_new_project"
-              ),
-              menu_item(
-                href: "/o/#{current_organization.path}/groups/new",
-                text: "New group",
-                id: "general_new_group"
-              ),
-              menu_item(
-                href: "/-/snippets/new",
-                text: "New snippet",
-                id: "general_new_snippet"
-              )
-            ]
-          end
-
-          before do
-            allow(current_organization).to receive(:scoped_paths?).and_return(true)
-          end
-
-          include_examples '"Create new" menu groups with headers'
-        end
-
-        context 'when current Organization does not have scoped paths' do
-          let(:in_this_group_menu_items) do
-            [
-              menu_item(
-                href: "/projects/new",
-                text: "New project/repository",
-                id: "new_project"
-              ),
-              menu_item(
-                href: "/groups/new#create-group-pane",
-                text: "New subgroup",
-                id: "new_subgroup"
-              ),
-              menu_item(
-                href: nil,
-                text: "Invite members",
-                component: 'invite_members',
-                id: "invite"
-              )
-            ]
-          end
-
-          let(:in_gitlab_menu_items) do
-            [
-              menu_item(
-                href: "/projects/new",
-                text: "New project/repository",
-                id: "general_new_project"
-              ),
-              menu_item(
-                href: "/groups/new",
-                text: "New group",
-                id: "general_new_group"
-              ),
-              menu_item(
-                href: "/-/snippets/new",
-                text: "New snippet",
-                id: "general_new_snippet"
-              )
-            ]
-          end
-
-          before do
-            allow(current_organization).to receive(:scoped_paths?).and_return(false)
-          end
-
-          include_examples '"Create new" menu groups with headers'
+          )
         end
       end
     end
@@ -611,27 +469,23 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
 
     describe 'Context switcher persistent links' do
       shared_examples 'context switcher with persistent links' do
-        let_it_be(:public_link) do
-          { title: s_('Navigation|Explore'), link: '/explore', icon: 'compass' }
+        let(:public_link) do
+          { title: s_('Navigation|Explore'), link: explore_root_path, icon: 'compass' }
         end
 
         let(:public_links_for_user) do
-          your_work_link = if current_organization&.scoped_paths?
-                             "/o/#{current_organization.path}"
-                           else
-                             '/'
-                           end
+          your_work_link = root_path
 
           [
             { title: s_('Navigation|Your work'), link: your_work_link, icon: 'work' },
             public_link,
-            { title: s_('Navigation|Profile'), link: '/-/user_settings/profile', icon: 'profile' },
-            { title: s_('Navigation|Preferences'), link: '/-/profile/preferences', icon: 'preferences' }
+            { title: s_('Navigation|Profile'), link: user_settings_profile_path, icon: 'profile' },
+            { title: s_('Navigation|Preferences'), link: profile_preferences_path, icon: 'preferences' }
           ]
         end
 
-        let_it_be(:admin_area_link) do
-          { title: s_('Navigation|Admin area'), link: '/admin', icon: 'admin' }
+        let(:admin_area_link) do
+          { title: s_('Navigation|Admin area'), link: admin_root_path, icon: 'admin' }
         end
 
         subject do
@@ -668,7 +522,8 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
                 current_user_mode.enable_admin_mode!(password: user.password)
               end
 
-              it 'returns public links, admin area and leave admin mode links' do
+              it 'returns public links, admin area and leave admin mode links',
+                quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/525378' do
                 expect(subject[:context_switcher_links]).to eq([
                   *public_links_for_user,
                   admin_area_link
@@ -700,21 +555,7 @@ RSpec.describe SidebarsHelper, feature_category: :navigation do
         end
       end
 
-      context 'when Organization has scoped paths' do
-        before do
-          allow(current_organization).to receive(:scoped_paths?).and_return(true)
-        end
-
-        include_examples 'context switcher with persistent links'
-      end
-
-      context 'when Organization does not have scoped paths' do
-        before do
-          allow(current_organization).to receive(:scoped_paths?).and_return(false)
-        end
-
-        include_examples 'context switcher with persistent links'
-      end
+      include_examples 'context switcher with persistent links'
     end
 
     describe 'impersonation data' do
