@@ -19,7 +19,12 @@ RSpec.describe Banzai::Filter::IframeLinkFilter, feature_category: :markdown do
     img.to_html
   end
 
-  let_it_be(:project) { create(:project, :repository) }
+  let_it_be(:group) { create(:group) }
+  let_it_be(:subgroup) { create(:group, parent: group) }
+  let_it_be(:project) { create(:project, :repository, group: subgroup) }
+
+  let(:width) { nil }
+  let(:height) { nil }
 
   before do
     allow(Gitlab::CurrentSettings).to receive_messages(
@@ -36,16 +41,12 @@ RSpec.describe Banzai::Filter::IframeLinkFilter, feature_category: :markdown do
       expect(container.name).to eq 'span'
       expect(container['class']).to eq 'media-container img-container'
 
-      link, iframe = container.children
+      iframe = container.children.first
 
       expect(iframe.name).to eq 'img'
       expect(iframe['src']).to eq src
       expect(iframe['height']).to eq height if height
       expect(iframe['width']).to eq width if width
-
-      expect(link.name).to eq 'a'
-      expect(link['href']).to eq src
-      expect(link['target']).to eq '_blank'
     end
   end
 
@@ -59,9 +60,6 @@ RSpec.describe Banzai::Filter::IframeLinkFilter, feature_category: :markdown do
   end
 
   context 'when the element src has a supported iframe domain' do
-    let(:height) { nil }
-    let(:width) { nil }
-
     it_behaves_like 'an iframe element' do
       let(:src) { "https://www.youtube.com/embed/foo" }
     end
@@ -76,13 +74,11 @@ RSpec.describe Banzai::Filter::IframeLinkFilter, feature_category: :markdown do
     end
 
     it_behaves_like 'an iframe element' do
-      let(:height) { nil }
       let(:width) { '50px' }
     end
 
     it_behaves_like 'an iframe element' do
       let(:height) { '50px' }
-      let(:width) { nil }
     end
   end
 
@@ -103,8 +99,6 @@ RSpec.describe Banzai::Filter::IframeLinkFilter, feature_category: :markdown do
 
     context 'and src is for an iframe' do
       let(:src) { "https://www.youtube.com/embed/foo" }
-      let(:height) { nil }
-      let(:width) { nil }
 
       it_behaves_like 'an iframe element'
     end
@@ -125,25 +119,53 @@ RSpec.describe Banzai::Filter::IframeLinkFilter, feature_category: :markdown do
 
       expect(container['class']).to eq 'media-container img-container'
 
-      link, iframe = container.children
+      iframe = container.children.first
 
       expect(iframe['src']).to eq proxy_src
       expect(iframe['data-canonical-src']).to eq canonical_src
-
-      expect(link['href']).to eq proxy_src
     end
   end
 
   context 'when allow_iframes_in_markdown is disabled' do
-    let(:src) { 'https://www.youtube.com/embed/foo' }
-
     before do
       stub_feature_flags(allow_iframes_in_markdown: false)
     end
 
+    let(:src) { 'https://www.youtube.com/embed/foo' }
+
     it_behaves_like 'an unchanged element'
   end
 
+  context 'when allow_iframes_in_markdown is set for the project' do
+    before do
+      stub_feature_flags(allow_iframes_in_markdown: project)
+    end
+
+    let(:src) { 'https://www.youtube.com/embed/foo' }
+
+    it_behaves_like 'an iframe element'
+  end
+
+  context 'when allow_iframes_in_markdown is set for the immediate group' do
+    before do
+      stub_feature_flags(allow_iframes_in_markdown: subgroup)
+    end
+
+    let(:src) { 'https://www.youtube.com/embed/foo' }
+
+    it_behaves_like 'an iframe element'
+  end
+
+  context 'when allow_iframes_in_markdown is set for an ancestor group' do
+    before do
+      stub_feature_flags(allow_iframes_in_markdown: group)
+    end
+
+    let(:src) { 'https://www.youtube.com/embed/foo' }
+
+    it_behaves_like 'an iframe element'
+  end
+
   it_behaves_like 'pipeline timing check' do
     let(:context) { { project: } }
   end
