@@ -5,54 +5,52 @@ require 'spec_helper'
 RSpec.describe Banzai::Filter::MarkdownEngines::GlfmMarkdown, feature_category: :markdown do
   it 'defaults to generating sourcepos' do
     engine = described_class.new({})
-    expected = <<~TEXT
-      <h1 data-sourcepos="1:1-1:4"><a href="#hi" aria-hidden="true" class="anchor" id="user-content-hi"></a>hi</h1>
-    TEXT
+    html = engine.render('# hi')
 
-    expect(engine.render('# hi')).to eq expected
+    fragment = Nokogiri::HTML.fragment(html)
+    expect(fragment.css('h1').first['data-sourcepos']).to eq('1:1-1:4')
   end
 
   it 'turns off sourcepos' do
     engine = described_class.new({ no_sourcepos: true })
-    expected = <<~TEXT
-      <h1><a href="#hi" aria-hidden="true" class="anchor" id="user-content-hi"></a>hi</h1>
-    TEXT
+    html = engine.render('# hi')
 
-    expect(engine.render('# hi')).to eq expected
+    fragment = Nokogiri::HTML.fragment(html)
+    expect(fragment.css('h1').first['data-sourcepos']).to be_nil
   end
 
   it 'turns off header anchors' do
     engine = described_class.new({ no_header_anchors: true, no_sourcepos: true })
-    expected = <<~TEXT
+    expected = <<~HTML
       <h1>hi</h1>
-    TEXT
+    HTML
 
     expect(engine.render('# hi')).to eq expected
   end
 
   it 'turns off autolinking' do
     engine = described_class.new({ autolink: false, no_sourcepos: true })
-    expected = <<~TEXT
+    expected = <<~HTML
       <p>http://example.com</p>
-    TEXT
+    HTML
 
     expect(engine.render('http://example.com')).to eq expected
   end
 
   it 'returns proper inline sourcepos' do
     engine = described_class.new({})
-    expected = <<~TEXT
+    expected = <<~HTML
       <p data-sourcepos="1:1-1:6"><code data-sourcepos="1:1-1:6">code</code></p>
-    TEXT
+    HTML
 
     expect(engine.render('`code`')).to eq expected
   end
 
   it 'turns on minimal markdown options' do
     engine = described_class.new({ minimum_markdown: true })
-    expected = <<~TEXT
+    expected = <<~HTML
       <p><a href="http://example.com">http://example.com</a> <em>emphasis</em> $x + y$</p>
-    TEXT
+    HTML
 
     expect(engine.render('http://example.com _emphasis_ $x + y$')).to eq expected
   end
@@ -66,9 +64,9 @@ RSpec.describe Banzai::Filter::MarkdownEngines::GlfmMarkdown, feature_category:
     shared_examples 'enables placeholder rendering by default' do
       it 'processes %{} syntax as placeholders' do
         engine = described_class.new({ project: project_reference, no_sourcepos: true })
-        expected = <<~TEXT
+        expected = <<~HTML
           <p><span data-placeholder>%{test}</span></p>
-        TEXT
+        HTML
 
         expect(engine.render('%{test}')).to eq expected
       end
@@ -84,18 +82,18 @@ RSpec.describe Banzai::Filter::MarkdownEngines::GlfmMarkdown, feature_category:
 
     it 'turns off placeholder detection when :disable_placeholders' do
       engine = described_class.new({ disable_placeholders: true, project: project, no_sourcepos: true })
-      expected = <<~TEXT
+      expected = <<~HTML
         <p>%{test}</p>
-      TEXT
+      HTML
 
       expect(engine.render('%{test}')).to eq expected
     end
 
     it 'turns off placeholder detection when :broadcast_message_placeholders' do
       engine = described_class.new({ broadcast_message_placeholders: true, project: project, no_sourcepos: true })
-      expected = <<~TEXT
+      expected = <<~HTML
         <p>%{test}</p>
-      TEXT
+      HTML
 
       expect(engine.render('%{test}')).to eq expected
     end
@@ -104,9 +102,9 @@ RSpec.describe Banzai::Filter::MarkdownEngines::GlfmMarkdown, feature_category:
       stub_feature_flags(markdown_placeholders: false)
 
       engine = described_class.new({ project: project, no_sourcepos: true })
-      expected = <<~TEXT
+      expected = <<~HTML
         <p>%{test}</p>
-      TEXT
+      HTML
 
       expect(engine.render('%{test}')).to eq expected
     end
