@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require 'spec_helper'
+require 'fast_spec_helper'
 
 RSpec.describe ClickHouse::Errors::DisabledError, feature_category: :database do
   describe '#initialize' do
