@@ -53,61 +53,49 @@ RSpec.describe Gitlab::Access, feature_category: :permissions do
   end
 
   describe '.options' do
-    it 'returns correct role options in correct order' do
-      expect(described_class.options.keys).to eq(%w[Guest Planner Reporter Developer Maintainer])
+    it 'returns roles in correct order' do
+      expect(described_class.options.keys).to eq(["Guest", "Planner", "Reporter", "Security Manager", "Developer",
+        "Maintainer"])
     end
 
-    context 'when security manager role is enabled' do
-      before do
-        allow(Gitlab::Security::SecurityManagerConfig).to receive(:enabled?).and_return(true)
-      end
+    it 'includes Security Manager with correct access level' do
+      expect(described_class.options['Security Manager']).to eq(25)
+    end
 
-      it 'returns roles in correct order between Reporter and Developer' do
-        expect(described_class.options.keys).to eq(["Guest", "Planner", "Reporter", "Security Manager", "Developer",
-          "Maintainer"])
-      end
-
-      it 'includes Security Manager with correct access level' do
-        expect(described_class.options['Security Manager']).to eq(25)
+    context 'when the security manager role is disabled', :disable_security_manager do
+      it 'does not include Security Manager' do
+        expect(described_class.options.keys).to eq(%w[Guest Planner Reporter Developer Maintainer])
       end
     end
   end
 
   describe '.option_descriptions' do
-    it 'does not include Security Manager description' do
-      expect(described_class.option_descriptions).not_to have_key(25)
+    it 'includes Security Manager description' do
+      expect(described_class.option_descriptions).to have_key(25)
+      expect(described_class.option_descriptions[25]).to include('Security Manager')
     end
 
-    context 'when security manager role is enabled' do
-      before do
-        allow(Gitlab::Security::SecurityManagerConfig).to receive(:enabled?).and_return(true)
-      end
-
-      it 'includes Security Manager description' do
-        expect(described_class.option_descriptions).to have_key(25)
-        expect(described_class.option_descriptions[25]).to include('Security Manager')
+    context 'when the security manager role is disabled', :disable_security_manager do
+      it 'does not include Security Manager description' do
+        expect(described_class.option_descriptions).not_to have_key(25)
       end
     end
   end
 
   describe '.sym_options' do
     it 'returns roles in correct order' do
-      expect(described_class.sym_options.keys).to eq([:guest, :planner, :reporter, :developer, :maintainer])
+      expect(described_class.sym_options.keys).to eq(
+        [:guest, :planner, :reporter, :security_manager, :developer, :maintainer]
+      )
     end
 
-    context 'when security manager role is enabled' do
-      before do
-        allow(Gitlab::Security::SecurityManagerConfig).to receive(:enabled?).and_return(true)
-      end
+    it 'includes security_manager with correct access level' do
+      expect(described_class.sym_options[:security_manager]).to eq(25)
+    end
 
-      it 'returns roles in correct order between reporter and developer' do
-        expect(described_class.sym_options.keys).to eq(
-          [:guest, :planner, :reporter, :security_manager, :developer, :maintainer]
-        )
-      end
-
-      it 'includes security_manager with correct access level' do
-        expect(described_class.sym_options[:security_manager]).to eq(25)
+    context 'when the security manager role is disabled', :disable_security_manager do
+      it 'does not include security_manager' do
+        expect(described_class.sym_options.keys).to eq([:guest, :planner, :reporter, :developer, :maintainer])
       end
     end
   end
