@@ -3,8 +3,7 @@
 require 'spec_helper'
 
 RSpec.describe Gitlab::BackgroundMigration::BackfillPushEventPayloadsProjectId,
-  feature_category: :source_code_management,
-  schema: 20250301122035 do
+  feature_category: :source_code_management do
   include_examples 'desired sharding key backfill job' do
     let(:batch_table) { :push_event_payloads }
     let(:backfill_column) { :project_id }
