@@ -8,7 +8,7 @@ RSpec.describe Gitlab::BitbucketServerImport::Importers::PullRequestNotes::Stand
   let_it_be_with_reload(:project) do
     create(
       :project, :repository, :bitbucket_server_import, :in_group,
-      :import_user_mapping_enabled, :user_mapping_to_personal_namespace_owner_enabled
+      :import_user_mapping_enabled
     )
   end
 
@@ -240,29 +240,6 @@ RSpec.describe Gitlab::BitbucketServerImport::Importers::PullRequestNotes::Stand
           author_id: user_namespace.owner_id
         )
       end
-
-      context 'when user_mapping_to_personal_namespace_owner is disabled' do
-        before do
-          project.build_or_assign_import_data(
-            data: { user_mapping_to_personal_namespace_owner_enabled: false }
-          ).save!
-        end
-
-        it 'pushes placeholder reference' do
-          importer.execute(pr_comment)
-
-          expect(cached_references).to contain_exactly(
-            ['Note', instance_of(Integer), 'author_id', source_user.id]
-          )
-        end
-
-        it 'imports the stand alone comments mapped to the placeholder user' do
-          expect { importer.execute(pr_comment) }.to change { Note.count }.by(1)
-          expect(merge_request.notes.first).to have_attributes(
-            author_id: source_user.mapped_user_id
-          )
-        end
-      end
     end
 
     context 'when user contribution mapping is disabled' do
