@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # TODO: Change back to fast_spec_helper when removing FF
-require 'spec_helper'
+require 'fast_spec_helper'
 
 RSpec.describe Gitlab::Ci::MaskSecret, feature_category: :pipeline_composition do
   subject { described_class }
