@@ -7,6 +7,7 @@ RSpec.describe Gitlab::Email::Handler::CreateNoteHandler, feature_category: :sha
 
   let_it_be_with_reload(:user) { create(:user, email: 'jake@adventuretime.ooo') }
   let_it_be(:project) { create(:project, :public, :repository) }
+  let_it_be(:support_bot) { create(:support_bot) }
 
   let(:noteable)  { note.noteable }
   let(:note)      { create(:diff_note_on_merge_request, project: project) }
@@ -69,7 +70,7 @@ RSpec.describe Gitlab::Email::Handler::CreateNoteHandler, feature_category: :sha
     end
 
     context 'when the issue is a Service Desk issue' do
-      let(:original_recipient) { Users::Internal.support_bot }
+      let(:original_recipient) { support_bot }
 
       it 'does not raise a UserNotFoundError' do
         expect { receiver.execute }.not_to raise_error
@@ -221,7 +222,7 @@ RSpec.describe Gitlab::Email::Handler::CreateNoteHandler, feature_category: :sha
 
   context 'when note is authored from external author for service desk' do
     before do
-      SentNotification.for(mail_key).update!(recipient: Users::Internal.support_bot)
+      SentNotification.for(mail_key).update!(recipient: support_bot)
     end
 
     context 'when email contains text, quoted text and quick commands' do
@@ -246,103 +247,130 @@ RSpec.describe Gitlab::Email::Handler::CreateNoteHandler, feature_category: :sha
     let_it_be(:noteable) { create(:issue, :closed, :confidential, project: project) }
     let_it_be(:note) { create(:note, noteable: noteable, project: project) }
 
-    let!(:sent_notification) do
-      allow(::ServiceDesk).to receive(:enabled?).with(project).and_return(true)
-      SentNotification.record_note(note, Users::Internal.support_bot.id)
+    context "when the send notification recipient is not a support bot" do
+      before_all do
+        project.add_developer(user)
+      end
+
+      let!(:sent_notification) do
+        allow(::ServiceDesk).to receive(:enabled?).with(project).and_return(true)
+        SentNotification.record_note(note, user.id, { reply_key: mail_key })
+      end
+
+      it 'does not reopen issue but adds comment' do
+        # Only 1 from received email, no reopen note
+        expect { receiver.execute }.to change { noteable.notes.count }.by(1)
+        expect(noteable.reload).to be_closed
+      end
+
+      it 'does not create a reopen note' do
+        initial_count = noteable.notes.count
+        receiver.execute
+
+        # Only the comment should be created, no reopen note
+        expect(noteable.notes.count).to eq(initial_count + 1)
+      end
     end
 
-    let(:reply_address) { "support+#{sent_notification.partitioned_reply_key}@example.com" }
-    let(:reopen_note) { noteable.notes.last }
-    let(:email_raw) do
-      <<~EMAIL
+    context "when sent notification recipient is a support bot" do
+      let!(:sent_notification) do
+        allow(::ServiceDesk).to receive(:enabled?).with(project).and_return(true)
+        SentNotification.record_note(note, support_bot.id)
+      end
+
+      let(:reply_address) { "support+#{sent_notification.partitioned_reply_key}@example.com" }
+      let(:reopen_note) { noteable.notes.last }
+      let(:email_raw) do
+        <<~EMAIL
       From: from@example.com
       To: #{reply_address}
       Subject: Issue title
 
       Issue description
-      EMAIL
-    end
+        EMAIL
+      end
 
-    before do
-      stub_incoming_email_setting(enabled: true, address: 'support+%{key}@example.com')
-    end
-
-    it 'does not reopen issue but adds external participants comment' do
-      # Only 1 from received email
-      expect { receiver.execute }.to change { noteable.notes.count }.by(1)
-      expect(noteable).to be_closed
-    end
-
-    context 'when noteable is a commit' do
-      let!(:note) { create(:note_on_commit, project: project) }
-      let!(:noteable) { note.noteable }
-
-      let!(:sent_notification) do
-        allow(::ServiceDesk).to receive(:enabled?).with(project).and_return(true)
-        SentNotification.record_note(note, Users::Internal.support_bot.id)
+      before do
+        stub_incoming_email_setting(enabled: true, address: 'support+%{key}@example.com')
       end
 
       it 'does not reopen issue but adds external participants comment' do
+        # Only 1 from received email
         expect { receiver.execute }.to change { noteable.notes.count }.by(1)
+        expect(noteable).to be_closed
       end
-    end
 
-    context 'when reopen_issue_on_external_participant_note is true' do
-      shared_examples 'an automatically reopened issue' do
-        it 'reopens issue, adds external participants comment and reopen comment' do
-          # 1 from received email and 1 reopen comment
-          expect { receiver.execute }.to change { noteable.notes.count }.by(2)
-          expect(noteable.reset).to be_open
+      context 'when noteable is a commit' do
+        let!(:note) { create(:note_on_commit, project: project) }
+        let!(:noteable) { note.noteable }
 
-          expect(reopen_note).to be_confidential
-          expect(reopen_note.author).to eq(Users::Internal.support_bot)
-          expect(reopen_note.note).to include(reopen_comment_body)
+        let!(:sent_notification) do
+          allow(::ServiceDesk).to receive(:enabled?).with(project).and_return(true)
+          SentNotification.record_note(note, support_bot.id)
+        end
+
+        it 'does not reopen issue but adds external participants comment' do
+          expect { receiver.execute }.to change { noteable.notes.count }.by(1)
         end
       end
 
-      let!(:settings) do
-        create(:service_desk_setting, project: project, reopen_issue_on_external_participant_note: true)
-      end
+      context 'when reopen_issue_on_external_participant_note is true' do
+        shared_examples 'an automatically reopened issue' do
+          it 'reopens issue, adds external participants comment and reopen comment' do
+            # 1 from received email and 1 reopen comment
+            expect { receiver.execute }.to change { noteable.notes.count }.by(2)
+            expect(noteable.reset).to be_open
 
-      let(:reopen_comment_body) do
-        s_(
-          "ServiceDesk|This issue has been reopened because it received a new comment from an external participant."
-        )
-      end
+            expect(reopen_note).to be_confidential
+            expect(reopen_note.author).to eq(support_bot)
+            expect(reopen_note.note).to include(reopen_comment_body)
+          end
+        end
 
-      it_behaves_like 'an automatically reopened issue'
+        let!(:settings) do
+          create(:service_desk_setting, project: project, reopen_issue_on_external_participant_note: true)
+        end
 
-      it 'does not contain an assignee mention' do
-        receiver.execute
-        expect(reopen_note.note).not_to include("@")
-      end
-
-      context 'when issue is assigned to a user' do
-        before do
-          noteable.update!(assignees: [user])
+        let(:reopen_comment_body) do
+          s_(
+            "ServiceDesk|This issue has been reopened because it received a new comment from an external participant."
+          )
         end
 
         it_behaves_like 'an automatically reopened issue'
 
-        it 'contains an assignee mention' do
+        it 'does not contain an assignee mention' do
           receiver.execute
-          expect(reopen_note.note).to include(user.to_reference)
-        end
-      end
-
-      context 'when issue is assigned to multiple users' do
-        let_it_be(:another_user) { create(:user) }
-
-        before do
-          noteable.update!(assignees: [user, another_user])
+          expect(reopen_note.note).not_to include("@")
         end
 
-        it_behaves_like 'an automatically reopened issue'
+        context 'when issue is assigned to a user' do
+          before do
+            noteable.update!(assignees: [user])
+          end
 
-        it 'contains two assignee mentions' do
-          receiver.execute
-          expect(reopen_note.note).to include(user.to_reference)
-          expect(reopen_note.note).to include(another_user.to_reference)
+          it_behaves_like 'an automatically reopened issue'
+
+          it 'contains an assignee mention' do
+            receiver.execute
+            expect(reopen_note.note).to include(user.to_reference)
+          end
+        end
+
+        context 'when issue is assigned to multiple users' do
+          let_it_be(:another_user) { create(:user) }
+
+          before do
+            noteable.update!(assignees: [user, another_user])
+          end
+
+          it_behaves_like 'an automatically reopened issue'
+
+          it 'contains two assignee mentions' do
+            receiver.execute
+            expect(reopen_note.note).to include(user.to_reference)
+            expect(reopen_note.note).to include(another_user.to_reference)
+          end
         end
       end
     end
