@@ -17,6 +17,7 @@ RSpec.describe Gitlab::Git::Tag, feature_category: :source_code_management do
       it { expect(tag.has_signature?).to be_falsey }
       it { expect(tag.signature_type).to eq(:NONE) }
       it { expect(tag.signature).to be_nil }
+      it { expect(tag.lazy_cached_signature).to be_nil }
       it { expect(tag.user_name).to eq("Dmitriy Zaporozhets") }
       it { expect(tag.user_email).to eq("dmitriy.zaporozhets@gmail.com") }
       it { expect(tag.date).to eq(Time.at(1393491299).utc) }
@@ -32,6 +33,7 @@ RSpec.describe Gitlab::Git::Tag, feature_category: :source_code_management do
       it { expect(tag.has_signature?).to be_truthy }
       it { expect(tag.signature_type).to eq(:X509) }
       it { expect(tag.signature).not_to be_nil }
+      it { expect(tag.lazy_cached_signature).to be_nil }
       it { expect(tag.user_name).to eq("Roger Meier") }
       it { expect(tag.user_email).to eq("r.meier@siemens.com") }
       it { expect(tag.date).to eq(Time.at(1574261780).utc) }
@@ -61,6 +63,7 @@ RSpec.describe Gitlab::Git::Tag, feature_category: :source_code_management do
       it { expect(tag.signature_type).to eq(:PGP) }
       it { expect(tag.has_signature?).to be_truthy }
       it { expect(tag.signature).not_to be_nil }
+      it { expect(tag.lazy_cached_signature).to be_nil }
       it { expect(tag.user_name).to eq(gitaly_commit_author.name) }
       it { expect(tag.user_email).to eq(gitaly_commit_author.email) }
       it { expect(tag.date).to eq(Time.at(1574261780).utc) }
@@ -71,6 +74,7 @@ RSpec.describe Gitlab::Git::Tag, feature_category: :source_code_management do
         end
 
         it { expect(tag.signature).to be_nil }
+        it { expect(tag.lazy_cached_signature).to be_nil }
       end
     end
 
@@ -97,6 +101,7 @@ RSpec.describe Gitlab::Git::Tag, feature_category: :source_code_management do
       it { expect(tag.signature_type).to eq(:SSH) }
       it { expect(tag.has_signature?).to be_truthy }
       it { expect(tag.signature).not_to be_nil }
+      it { expect(tag.lazy_cached_signature).not_to be_nil }
       it { expect(tag.user_email).to eq('test@example.com') }
 
       context 'when render_ssh_signed_tags_verification_status is not enabled' do
@@ -105,6 +110,7 @@ RSpec.describe Gitlab::Git::Tag, feature_category: :source_code_management do
         end
 
         it { expect(tag.signature).to be_nil }
+        it { expect(tag.lazy_cached_signature).to be_nil }
       end
     end
 
@@ -208,7 +214,7 @@ RSpec.describe Gitlab::Git::Tag, feature_category: :source_code_management do
         described_class.extract_signature_lazily(other_repository, tag_ids.first)
 
         expect(described_class).to receive(:batch_signature_extraction)
-          .with(repository, tag_ids)
+          .with(repository, tag_ids, timeout: Gitlab::GitalyClient.fast_timeout)
           .once
           .and_return({})
 
@@ -277,4 +283,45 @@ RSpec.describe Gitlab::Git::Tag, feature_category: :source_code_management do
       expect(subject.cache_key).to eq("tag:#{digest}")
     end
   end
+
+  describe '#can_use_lazy_cached_signature?' do
+    let(:tag) { repository.tags.first }
+    let(:stubbed_signature_type) { :NONE }
+
+    subject { tag.can_use_lazy_cached_signature? }
+
+    before do
+      allow(tag).to receive(:signature_type).and_return(stubbed_signature_type)
+    end
+
+    it { is_expected.to be_falsey }
+
+    context 'when signed with gpg' do
+      let(:stubbed_signature_type) { :PGP }
+
+      it { is_expected.to be_truthy }
+
+      context 'when render_gpg_signed_tags_verification_status is not enabled' do
+        before do
+          stub_feature_flags(render_gpg_signed_tags_verification_status: false)
+        end
+
+        it { is_expected.to be_falsey }
+      end
+    end
+
+    context 'when signed with ssh' do
+      let(:stubbed_signature_type) { :SSH }
+
+      it { is_expected.to be_truthy }
+
+      context 'when render_ssh_signed_tags_verification_status is not enabled' do
+        before do
+          stub_feature_flags(render_ssh_signed_tags_verification_status: false)
+        end
+
+        it { is_expected.to be_falsey }
+      end
+    end
+  end
 end
