@@ -231,6 +231,18 @@ RSpec.describe Gitlab::GithubImport::Importer::DiffNoteImporter, :aggregate_fail
             end
           end
 
+          context 'when direct reassignment is supported' do
+            before do
+              allow(Import::DirectReassignService).to receive(:supported?).and_return(true)
+            end
+
+            it 'does not push any placeholder references' do
+              subject.execute
+
+              expect(cached_references).to be_empty
+            end
+          end
+
           context 'when importing into a personal namespace' do
             let_it_be(:user_namespace) { create(:namespace) }
 
@@ -263,6 +275,18 @@ RSpec.describe Gitlab::GithubImport::Importer::DiffNoteImporter, :aggregate_fail
           end
         end
 
+        context 'when direct reassignment is supported' do
+          before do
+            allow(Import::DirectReassignService).to receive(:supported?).and_return(true)
+          end
+
+          it 'does not push any placeholder references' do
+            subject.execute
+
+            expect(cached_references).to be_empty
+          end
+        end
+
         context 'when importing into a personal namespace' do
           let_it_be(:user_namespace) { create(:namespace) }
           let_it_be(:project) do
