@@ -24,6 +24,22 @@ RSpec.describe ::Gitlab::Metrics::Labkit, :prometheus, feature_category: :scalab
     end
   end
 
+  describe '#prometheus_metrics_enabled?' do
+    it 'memoizes true values' do
+      stub_application_setting(prometheus_metrics_enabled: true)
+      expect(client).to receive(:enabled?).once.and_return(true)
+
+      2.times { expect(all_metrics.prometheus_metrics_enabled?).to be_truthy }
+    end
+
+    it 'memoizes false values' do
+      stub_application_setting(prometheus_metrics_enabled: false)
+      expect(client).to receive(:enabled?).once.and_return(true)
+
+      2.times { expect(all_metrics.prometheus_metrics_enabled?).to be_falsey }
+    end
+  end
+
   describe '#error_detected!' do
     after do
       Labkit::Metrics::Client.enable!
