@@ -3,7 +3,7 @@
 require 'spec_helper'
 
 RSpec.describe Gitlab::Usage::Metrics::Instrumentations::CountCiRunnerManagerCustomExecutorsMetric,
-  feature_category: :runner do
+  feature_category: :runner_core do
   let_it_be(:docker_executor) { create(:ci_runner_machine, executor_type: :custom) }
   let(:expected_value) { 1 }
 
