@@ -46,7 +46,7 @@ RSpec.describe Mattermost::Session, type: :request do
 
     context 'with oauth_uri' do
       let!(:doorkeeper) do
-        Doorkeeper::Application.create!(
+        Authn::OauthApplication.create!(
           name: 'GitLab Mattermost',
           redirect_uri: "#{mattermost_url}/signup/gitlab/complete\n#{mattermost_url}/login/gitlab/complete",
           scopes: '')
@@ -114,7 +114,7 @@ RSpec.describe Mattermost::Session, type: :request do
           expect { subject.with_session {} }
             .to change { OauthAccessToken.find_by(resource_owner: user)&.organization_id }
             .from(nil)
-            .to(user.organizations.first.id)
+            .to(user.organization.id)
         end
       end
     end
