@@ -22,7 +22,6 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
   it { is_expected.to have_one(:provider_gcp) }
   it { is_expected.to have_one(:provider_aws) }
   it { is_expected.to have_one(:platform_kubernetes) }
-  it { is_expected.to have_one(:integration_prometheus) }
   it { is_expected.to have_one(:agent_migration).class_name('Clusters::AgentMigration').inverse_of(:cluster) }
   it { is_expected.to have_many(:kubernetes_namespaces) }
   it { is_expected.to have_one(:cluster_project) }
@@ -164,24 +163,6 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     end
   end
 
-  describe '.with_integration_prometheus' do
-    subject { described_class.with_integration_prometheus }
-
-    let!(:cluster) { create(:cluster) }
-
-    context 'cluster has prometheus application' do
-      let!(:application) { create(:clusters_integrations_prometheus, cluster: cluster) }
-
-      it { is_expected.to include(cluster) }
-    end
-
-    context 'cluster does not have prometheus application' do
-      let(:cluster) { create(:cluster) }
-
-      it { is_expected.not_to include(cluster) }
-    end
-  end
-
   describe '.distinct_with_deployed_environments' do
     subject { described_class.distinct_with_deployed_environments }
 
@@ -290,17 +271,17 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
         let(:group) { create(:group) }
 
         before do
-          create(:cluster, cluster_type: :group_type, groups: [group], environment_scope: 'product/*')
+          create(:cluster, :group, groups: [group], environment_scope: 'product/*')
         end
 
         context 'when identical environment scope exists in group' do
-          let(:cluster) { build(:cluster, cluster_type: :group_type, groups: [group], environment_scope: 'product/*') }
+          let(:cluster) { build(:cluster, :group, groups: [group], environment_scope: 'product/*') }
 
           it { is_expected.to be_falsey }
         end
 
         context 'when identical environment scope does not exist in group' do
-          let(:cluster) { build(:cluster, cluster_type: :group_type, groups: [group], environment_scope: '*') }
+          let(:cluster) { build(:cluster, :group, groups: [group], environment_scope: '*') }
 
           it { is_expected.to be_truthy }
         end
@@ -388,11 +369,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
         end
 
         context 'when record is persisted' do
-          let(:name) { 'cluster-name-1' }
-
-          before do
-            cluster.save!
-          end
+          let!(:cluster) { create(:cluster, :provided_by_gcp, name: 'cluster-name-1') }
 
           context 'when name is changed' do
             before do
@@ -404,7 +381,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
 
           context 'when name is same' do
             before do
-              cluster.name = name
+              cluster.name = 'cluster-name-1'
             end
 
             it { is_expected.to be_truthy }
@@ -536,7 +513,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
   end
 
   describe '.ancestor_clusters_for_clusterable' do
-    let(:group_cluster) { create(:cluster, :provided_by_gcp, :group) }
+    let(:group_cluster) { create(:cluster, :group) }
     let(:group) { group_cluster.group }
     let(:hierarchy_order) { :desc }
     let(:clusterable) { project }
@@ -563,7 +540,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
 
     context 'when group and instance have configured kubernetes clusters' do
       let(:project) { create(:project, group: group) }
-      let!(:instance_cluster) { create(:cluster, :provided_by_gcp, :instance) }
+      let!(:instance_cluster) { create(:cluster, :instance) }
 
       it 'returns clusters in order, descending the hierachy' do
         is_expected.to eq([group_cluster, instance_cluster])
@@ -571,7 +548,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     end
 
     context 'when sub-group has configured kubernetes cluster' do
-      let(:sub_group_cluster) { create(:cluster, :provided_by_gcp, :group) }
+      let(:sub_group_cluster) { create(:cluster, :group) }
       let(:sub_group) { sub_group_cluster.group }
       let(:project) { create(:project, group: sub_group) }
 
@@ -589,7 +566,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
           described_class.ancestor_clusters_for_clusterable(another_project, hierarchy_order: hierarchy_order)
         end
 
-        cluster2 = create(:cluster, :provided_by_gcp, :group)
+        cluster2 = create(:cluster, :group)
         child2 = cluster2.group
         child2.update!(parent: sub_group)
         project = create(:project, group: child2)
@@ -669,7 +646,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     end
 
     context 'when cluster does not belong to projects' do
-      let(:cluster) { create(:cluster) }
+      let(:cluster) { create(:cluster, :group) }
 
       it { is_expected.to be_nil }
     end
@@ -697,13 +674,13 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
 
     context 'project type cluster' do
       context 'gitlab managed' do
-        let(:cluster) { build(:cluster, :provided_by_gcp) }
+        let(:cluster) { build(:cluster) }
 
         it { is_expected.to be_truthy }
       end
 
       context 'not managed' do
-        let(:cluster) { build(:cluster, :provided_by_gcp, managed: false) }
+        let(:cluster) { build(:cluster, managed: false) }
 
         it { is_expected.to be_truthy }
       end
@@ -711,13 +688,13 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
 
     context 'group type cluster' do
       context 'gitlab managed' do
-        let(:cluster) { build(:cluster, :provided_by_gcp, :group) }
+        let(:cluster) { build(:cluster, :group) }
 
         it { is_expected.to be_falsey }
       end
 
       context 'not managed' do
-        let(:cluster) { build(:cluster, :provided_by_gcp, :group, managed: false) }
+        let(:cluster) { build(:cluster, :group, managed: false) }
 
         it { is_expected.to be_truthy }
       end
@@ -725,13 +702,13 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
 
     context 'instance type cluster' do
       context 'gitlab managed' do
-        let(:cluster) { build(:cluster, :provided_by_gcp, :instance) }
+        let(:cluster) { build(:cluster, :instance) }
 
         it { is_expected.to be_falsey }
       end
 
       context 'not managed' do
-        let(:cluster) { build(:cluster, :provided_by_gcp, :instance, managed: false) }
+        let(:cluster) { build(:cluster, :instance, managed: false) }
 
         it { is_expected.to be_truthy }
       end
@@ -769,18 +746,18 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
   end
 
   describe '#kube_ingress_domain' do
-    let(:cluster) { build(:cluster, :provided_by_gcp) }
+    let(:cluster) { build(:cluster) }
 
     subject { cluster.kube_ingress_domain }
 
     context 'with domain set in cluster' do
-      let(:cluster) { build(:cluster, :provided_by_gcp, :with_domain) }
+      let(:cluster) { build(:cluster, :with_domain) }
 
       it { is_expected.to eq(cluster.domain) }
     end
 
     context 'with no domain on cluster' do
-      let(:cluster) { build(:cluster, :project, :provided_by_gcp) }
+      let(:cluster) { build(:cluster, :project) }
       let(:project) { cluster.project }
 
       context 'with domain set at instance level' do
@@ -816,10 +793,6 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     end
 
     context 'when cluster is managed' do
-      before do
-        stub_feature_flags(ci_validate_config_options: false)
-      end
-
       let(:build_options) { { environment: { kubernetes: { namespace: 'ci yaml namespace' } } } }
 
       it 'returns the cached namespace if present, ignoring CI config' do
@@ -833,10 +806,6 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     end
 
     context 'when cluster is not managed' do
-      before do
-        stub_feature_flags(ci_validate_config_options: false)
-      end
-
       let(:managed_cluster) { false }
       let(:build_options) { { environment: { kubernetes: { namespace: 'ci yaml namespace' } } } }
 
@@ -863,7 +832,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     subject { cluster.predefined_variables }
 
     context 'with an instance domain' do
-      let(:cluster) { create(:cluster, :provided_by_gcp) }
+      let(:cluster) { create(:cluster) }
 
       before do
         stub_application_setting(auto_devops_domain: 'global_domain.com')
@@ -875,7 +844,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     end
 
     context 'with a cluster domain' do
-      let(:cluster) { create(:cluster, :provided_by_gcp, domain: 'example.com') }
+      let(:cluster) { create(:cluster, domain: 'example.com') }
 
       it 'includes KUBE_INGRESS_BASE_DOMAIN' do
         expect(subject.to_hash).to include(KUBE_INGRESS_BASE_DOMAIN: 'example.com')
@@ -883,7 +852,7 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     end
 
     context 'with no domain' do
-      let(:cluster) { build(:cluster, :provided_by_gcp, :project) }
+      let(:cluster) { build(:cluster, :project) }
 
       it 'returns an empty array' do
         expect(subject.to_hash).to be_empty
@@ -911,7 +880,8 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     subject { cluster.status_name }
 
     context 'the cluster has a provider' do
-      let(:cluster) { build(:cluster, :provided_by_gcp) }
+      let(:cluster) { create(:cluster, :provided_by_gcp) }
+
       let(:provider_status) { :errored }
 
       before do
@@ -1219,42 +1189,6 @@ RSpec.describe Clusters::Cluster, :use_clean_rails_memory_store_caching,
     end
   end
 
-  describe '#integration_prometheus_available?' do
-    let_it_be_with_reload(:cluster) { create(:cluster, :project) }
-
-    subject { cluster.integration_prometheus_available? }
-
-    it { is_expected.to be_falsey }
-
-    context 'when integration is enabled' do
-      let!(:integration) { create(:clusters_integrations_prometheus, cluster: cluster) }
-
-      it { is_expected.to be_truthy }
-    end
-
-    context 'when integration is disabled' do
-      let!(:integration) { create(:clusters_integrations_prometheus, enabled: false, cluster: cluster) }
-
-      it { is_expected.to be_falsey }
-    end
-  end
-
-  describe '#prometheus_adapter' do
-    let_it_be_with_reload(:cluster) { create(:cluster, :project) }
-
-    it 'returns nothing' do
-      expect(cluster.prometheus_adapter).to be_nil
-    end
-
-    context 'has integration_prometheus' do
-      let_it_be(:integration) { create(:clusters_integrations_prometheus, cluster: cluster) }
-
-      it 'returns the integration' do
-        expect(cluster.prometheus_adapter).to eq(integration)
-      end
-    end
-  end
-
   describe '#delete_cached_resources!' do
     let!(:cluster) { create(:cluster, :project) }
     let!(:staging_namespace) { create(:cluster_kubernetes_namespace, cluster: cluster, namespace: 'staging') }
