@@ -10,14 +10,16 @@ RSpec.describe CommitSignatures::X509CommitSignature, feature_category: :source_
   let_it_be(:project) { create(:project, :public, :repository) }
   let_it_be(:commit) { create(:commit, project: project, sha: commit_sha) }
   let_it_be(:x509_certificate) { create(:x509_certificate, email: 'r.meier@siemens.com') }
-  let_it_be(:verification_status) { "verified" }
+  let_it_be(:verification_status) { "unverified_author_email" }
+  let_it_be(:committer_email) { nil }
 
   let(:attributes) do
     {
       commit_sha: commit_sha,
       project: project,
       x509_certificate_id: x509_certificate.id,
-      verification_status: verification_status
+      verification_status: verification_status,
+      committer_email: committer_email
     }
   end
 
@@ -51,31 +53,50 @@ RSpec.describe CommitSignatures::X509CommitSignature, feature_category: :source_
 
   describe '#verification_status' do
     let_it_be(:matching_email) { 'r.meier@siemens.com' }
+    let_it_be(:verification_status) { "verified" }
 
     subject(:signature) { described_class.safe_create!(attributes) }
 
-    context 'when the commit email matches the x509 certificate emails' do
-      let_it_be(:x509_certificate) { create(:x509_certificate, email: matching_email) }
+    context 'when the commit email matches certificate emails' do
+      shared_examples 'verification based on committer email verification' do
+        let_it_be(:committer_email) { matching_email }
 
-      it 'returns verified' do
-        expect(signature.verification_status).to eq('verified')
+        context 'when the commit email is verified for the author' do
+          let_it_be(:user) { create(:user, email: matching_email) }
+
+          it 'returns verified' do
+            expect(signature.verification_status).to eq('verified')
+          end
+        end
+
+        context 'when the committer email is not verified for the author' do
+          let_it_be(:user) { create(:user) }
+
+          it 'returns unverified_author_email' do
+            expect(signature.verification_status).to eq('unverified_author_email')
+          end
+        end
+      end
+
+      context 'when the commit email matches the primary x509 certificate email' do
+        let_it_be(:x509_certificate) { create(:x509_certificate, email: matching_email) }
+
+        include_examples 'verification based on committer email verification'
+      end
+
+      context 'when the commit email matches one of the x509 certificate secondary emails' do
+        let_it_be(:x509_certificate) do
+          create(:x509_certificate,
+            email: 'different@test.com',
+            emails: [matching_email, 'also-different@test.com']
+          )
+        end
+
+        include_examples 'verification based on committer email verification'
       end
     end
 
-    context 'when the commit email matches one of the x509 certificate secondary emails' do
-      let_it_be(:x509_certificate) do
-        create(:x509_certificate,
-          email: 'different@test.com',
-          emails: [matching_email, 'also-different@test.com']
-        )
-      end
-
-      it 'returns verified' do
-        expect(signature.verification_status).to eq('verified')
-      end
-    end
-
-    context 'when the commit email does not matche any of the x509 certificate emails' do
+    context 'when the commit email does not match any of the x509 certificate emails' do
       let_it_be(:x509_certificate) do
         create(:x509_certificate,
           email: 'different@test.com',
