@@ -5,6 +5,17 @@ require 'spec_helper'
 RSpec.describe Ci::Metadatable, feature_category: :continuous_integration do
   let_it_be_with_refind(:processable) { create(:ci_processable, options: { script: 'echo' }) }
 
+  before_all do
+    Ci::ApplicationRecord.connection.execute(<<~SQL)
+      CREATE TABLE IF NOT EXISTS "gitlab_partitions_dynamic"."ci_builds_metadata_100"
+        PARTITION OF "p_ci_builds_metadata" FOR VALUES IN (100);
+      CREATE TABLE IF NOT EXISTS "gitlab_partitions_dynamic"."ci_builds_metadata_101"
+        PARTITION OF "p_ci_builds_metadata" FOR VALUES IN (101);
+      CREATE TABLE IF NOT EXISTS "gitlab_partitions_dynamic"."ci_builds_metadata_102"
+        PARTITION OF "p_ci_builds_metadata" FOR VALUES IN (102);
+    SQL
+  end
+
   describe '#options' do
     let(:job) { build(:ci_build, :without_job_definition) }
     let(:legacy_job_options) { { script: 'legacy job' } }
