@@ -53,4 +53,51 @@ RSpec.describe Import::Offline::Export, feature_category: :importers do
         .to contain_exactly('created', 'started', 'finished', 'failed')
     end
   end
+
+  describe 'configuration purge' do
+    let_it_be(:export) { create(:offline_export, :started) }
+    let_it_be(:configuration) { create(:offline_configuration, offline_export: export) }
+
+    describe 'after transitioning to finished' do
+      it 'schedules configuration purge worker' do
+        expect(Import::Offline::ConfigurationPurgeWorker)
+          .to receive(:perform_in)
+          .with(described_class::PURGE_CONFIGURATION_DELAY, configuration.id)
+
+        export.finish
+      end
+
+      context 'when export has no configuration' do
+        let_it_be(:export_without_config) { create(:offline_export) }
+
+        it 'does not schedule configuration purge worker' do
+          expect(Import::Offline::ConfigurationPurgeWorker).not_to receive(:perform_in)
+
+          export_without_config.finish
+        end
+      end
+    end
+
+    describe 'after transitioning to failed' do
+      it 'schedules configuration purge worker' do
+        expect(Import::Offline::ConfigurationPurgeWorker)
+          .to receive(:perform_in)
+          .with(described_class::PURGE_CONFIGURATION_DELAY, configuration.id)
+
+        export.fail_op
+      end
+
+      context 'when export has no configuration' do
+        let_it_be(:export_without_config) { create(:offline_export) }
+
+        it 'does not schedule configuration purge worker' do
+          export_without_config.start
+
+          expect(Import::Offline::ConfigurationPurgeWorker).not_to receive(:perform_in)
+
+          export_without_config.fail_op
+        end
+      end
+    end
+  end
 end
