@@ -11,6 +11,28 @@ RSpec.describe Namespace::Detail, type: :model, feature_category: :groups_and_pr
   describe 'validations' do
     it { is_expected.to validate_presence_of(:namespace) }
     it { is_expected.to validate_length_of(:description).is_at_most(2000) }
+
+    describe 'state_metadata' do
+      let(:namespace_detail) { create(:namespace).namespace_details }
+
+      it 'validates json_schema when state_metadata changes' do
+        namespace_detail.state_metadata = { invalid_key: 'value' }
+
+        expect(namespace_detail).not_to be_valid
+        expect(namespace_detail.errors[:state_metadata]).to be_present
+      end
+
+      it 'does not validate json_schema when state_metadata is unchanged' do
+        # Simulate invalid data already in the database
+        namespace_detail.update_column(:state_metadata, { invalid_key: 'value' })
+        namespace_detail.reload
+
+        # Update a different attribute
+        namespace_detail.description = 'New description'
+
+        expect(namespace_detail).to be_valid
+      end
+    end
   end
 
   context 'with loose foreign key on namespace_details.creator_id' do
