@@ -805,7 +805,7 @@ RSpec.describe Note, feature_category: :team_planning do
       end
 
       it 'returns the ghost user' do
-        expect(note.last_edited_by).to eq(Users::Internal.for_organization(note.organization_id).ghost)
+        expect(note.last_edited_by).to eq(Users::Internal.in_organization(note.organization_id).ghost)
       end
     end
 
