@@ -7,6 +7,10 @@ RSpec.describe Packages::Conan::PackageRevision, type: :model, feature_category:
 
   it { is_expected.to be_a(Packages::Conan::PackageFileable) }
 
+  describe 'enums' do
+    it { is_expected.to define_enum_for(:status).with_values(default: 0, processing: 1) }
+  end
+
   describe 'associations' do
     it 'belongs to package' do
       is_expected.to belong_to(:package).class_name('Packages::Conan::Package').inverse_of(:conan_package_revisions)
