@@ -18,6 +18,7 @@ RSpec.describe Packages::PackageFile, feature_category: :package_registry do
 
   describe 'relationships' do
     it { is_expected.to belong_to(:package) }
+    it { is_expected.to belong_to(:project) }
     it { is_expected.to have_one(:conan_file_metadatum) }
     it { is_expected.to have_many(:package_file_build_infos).inverse_of(:package_file) }
 
@@ -30,6 +31,11 @@ RSpec.describe Packages::PackageFile, feature_category: :package_registry do
       is_expected.to have_one(:helm_file_metadatum).inverse_of(:package_file)
         .class_name('Packages::Helm::FileMetadatum')
     end
+
+    it 'has one pypi file metadatum' do
+      is_expected.to have_one(:pypi_file_metadatum).inverse_of(:package_file)
+        .class_name('Packages::Pypi::FileMetadatum')
+    end
   end
 
   describe 'included modules' do
@@ -564,6 +570,14 @@ RSpec.describe Packages::PackageFile, feature_category: :package_registry do
     end
   end
 
+  describe '.preload_project' do
+    subject(:packages) { described_class.preload_project }
+
+    it 'preloads project' do
+      expect(packages.first.association(:project)).to be_loaded
+    end
+  end
+
   describe '#pipelines' do
     let_it_be_with_refind(:package_file) { create(:package_file) }
 
