@@ -3,7 +3,7 @@
 require 'spec_helper'
 
 RSpec.describe UserAgentDetail, feature_category: :insider_threat do
-  it { is_expected.to belong_to(:organization).optional }
+  it { is_expected.to belong_to(:organization).required }
 
   describe '.submittable?' do
     it 'is submittable when not already submitted' do
