@@ -30,6 +30,14 @@ RSpec.describe API::Ci::SecureFiles, feature_category: :mobile_devops do
       end
     end
 
+    it_behaves_like 'authorizing granular token permissions', :read_secure_file do
+      let(:boundary_object) { project }
+      let(:user) { developer }
+      let(:request) do
+        get api("/projects/#{project.id}/secure_files", personal_access_token: pat)
+      end
+    end
+
     context 'authenticated user with admin permissions' do
       it 'returns project secure files' do
         get api("/projects/#{project.id}/secure_files", maintainer)
@@ -90,6 +98,14 @@ RSpec.describe API::Ci::SecureFiles, feature_category: :mobile_devops do
       end
     end
 
+    it_behaves_like 'authorizing granular token permissions', :read_secure_file do
+      let(:boundary_object) { project }
+      let(:user) { developer }
+      let(:request) do
+        get api("/projects/#{project.id}/secure_files/#{secure_file.id}", personal_access_token: pat)
+      end
+    end
+
     context 'authenticated user with admin permissions' do
       it 'returns project secure file details' do
         get api("/projects/#{project.id}/secure_files/#{secure_file.id}", maintainer)
@@ -162,6 +178,14 @@ RSpec.describe API::Ci::SecureFiles, feature_category: :mobile_devops do
       end
     end
 
+    it_behaves_like 'authorizing granular token permissions', :download_secure_file do
+      let(:boundary_object) { project }
+      let(:user) { developer }
+      let(:request) do
+        get api("/projects/#{project.id}/secure_files/#{secure_file.id}/download", personal_access_token: pat)
+      end
+    end
+
     context 'authenticated user with admin permissions' do
       it 'returns a secure file' do
         sample_file = fixture_file('ci_secure_files/upload-keystore.jks')
@@ -228,6 +252,14 @@ RSpec.describe API::Ci::SecureFiles, feature_category: :mobile_devops do
       end
     end
 
+    it_behaves_like 'authorizing granular token permissions', :create_secure_file do
+      let(:boundary_object) { project }
+      let(:user) { maintainer }
+      let(:request) do
+        post api("/projects/#{project.id}/secure_files", personal_access_token: pat), params: file_params
+      end
+    end
+
     context 'authenticated user with admin permissions' do
       it 'creates a secure file' do
         expect do
@@ -386,6 +418,14 @@ RSpec.describe API::Ci::SecureFiles, feature_category: :mobile_devops do
       end
     end
 
+    it_behaves_like 'authorizing granular token permissions', :delete_secure_file do
+      let(:boundary_object) { project }
+      let(:user) { maintainer }
+      let(:request) do
+        delete api("/projects/#{project.id}/secure_files/#{secure_file.id}", personal_access_token: pat)
+      end
+    end
+
     context 'authenticated user with admin permissions' do
       it 'deletes the secure file' do
         expect do
