@@ -35,7 +35,7 @@ RSpec.describe 'Update a work item', feature_category: :team_planning do
     # Ensure support bot user is created so creation doesn't count towards query limit
     # and we don't try to obtain an exclusive lease within a transaction.
     # See https://gitlab.com/gitlab-org/gitlab/-/issues/509629
-    Users::Internal.support_bot_id
+    create(:support_bot)
   end
 
   shared_examples 'request with error' do |message|
