@@ -137,7 +137,8 @@ RSpec.describe 'Project.cluster_agents', feature_category: :deployment_managemen
       })
     end
 
-    it 'preloads associations to prevent N+1 queries' do
+    it 'preloads associations to prevent N+1 queries',
+      quarantine: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/5181' do
       user = create(:user)
       token = create(:cluster_agent_token, agent: agents.second)
       create(:agent_activity_event, agent: agents.second, agent_token: token, user: user)
