@@ -436,6 +436,32 @@ RSpec.describe API::ProjectExport, :aggregate_failures, :clean_gitlab_redis_cach
           end
         end
 
+        context 'when export is already in progress' do
+          before do
+            allow_next_instance_of(Gitlab::ApplicationRateLimiter::BaseStrategy) do |strategy|
+              allow(strategy).to receive(:increment).and_return(0)
+            end
+          end
+
+          it '400 response if export already queued' do
+            create(:project_export_job, :queued, project: project, user: user)
+
+            request
+
+            expect(response).to have_gitlab_http_status(:bad_request)
+            expect(json_response["message"]).to include('An export is already running or queued for this project.')
+          end
+
+          it '400 response if export already started' do
+            create(:project_export_job, :started, project: project, user: user)
+
+            request
+
+            expect(response).to have_gitlab_http_status(:bad_request)
+            expect(json_response["message"]).to include('An export is already running or queued for this project.')
+          end
+        end
+
         context 'when rate limit is exceeded across projects' do
           before do
             allow_next_instance_of(Gitlab::ApplicationRateLimiter::BaseStrategy) do |strategy|
@@ -704,6 +730,16 @@ RSpec.describe API::ProjectExport, :aggregate_failures, :clean_gitlab_redis_cach
             end
           end
         end
+
+        context 'when export is from an offline transfer export' do
+          let_it_be(:export) { create(:bulk_import_export, :offline, project: project, relation: 'labels', user: user) }
+
+          it 'returns 404' do
+            get api(download_path, user)
+
+            expect(response).to have_gitlab_http_status(:not_found)
+          end
+        end
       end
 
       describe 'GET /projects/:id/export_relations/status' do
@@ -781,6 +817,26 @@ RSpec.describe API::ProjectExport, :aggregate_failures, :clean_gitlab_redis_cach
             expect(json_response).to be_empty
           end
         end
+
+        context 'when exports exist from offline transfer exports' do
+          let_it_be(:offline_self_export) do
+            create(:bulk_import_export, :pending, :offline, project: project, relation: 'self', user: user)
+          end
+
+          it 'returns not_found when a relation not yet exported by direct transfer was specified' do
+            get api(status_path, user), params: { relation: 'self' }
+
+            expect(response).to have_gitlab_http_status(:not_found)
+          end
+
+          it 'does not return offline transfer relation ExportService in the list of all statuses' do
+            get api(status_path, user)
+
+            expect(response).to have_gitlab_http_status(:ok)
+            expect(json_response.pluck('relation')).not_to include('self')
+            expect(json_response.pluck('status')).not_to include(-2)
+          end
+        end
       end
 
       context 'with bulk_import is disabled' do
