@@ -19,6 +19,13 @@ RSpec.describe API::Tags, feature_category: :source_code_management do
   describe 'GET /projects/:id/repository/tags', :use_clean_rails_memory_store_caching do
     let(:route) { "/projects/#{project_id}/repository/tags" }
 
+    it_behaves_like 'authorizing granular token permissions', :read_repository_tag do
+      let(:boundary_object) { project }
+      let(:request) do
+        get api(route, personal_access_token: pat)
+      end
+    end
+
     it_behaves_like 'enforcing job token policies', :read_repositories,
       allow_public_access_for_enabled_project_features: :repository do
       let(:request) do
@@ -331,6 +338,20 @@ RSpec.describe API::Tags, feature_category: :source_code_management do
   describe 'GET /projects/:id/repository/tags/:tag_name' do
     let(:route) { "/projects/#{project_id}/repository/tags/#{tag_name}" }
 
+    it_behaves_like 'authorizing granular token permissions', :read_repository_tag do
+      let(:boundary_object) { project }
+      let(:request) do
+        get api(route, personal_access_token: pat)
+      end
+    end
+
+    it_behaves_like 'enforcing job token policies', :read_repositories,
+      allow_public_access_for_enabled_project_features: :repository do
+      let(:request) do
+        get api(route), params: { job_token: target_job.token }
+      end
+    end
+
     shared_examples_for 'repository tag' do
       it 'returns the repository branch' do
         get api(route, current_user)
@@ -427,6 +448,13 @@ RSpec.describe API::Tags, feature_category: :source_code_management do
     let(:tag_name) { 'new_tag' }
     let(:route) { "/projects/#{project_id}/repository/tags" }
 
+    it_behaves_like 'authorizing granular token permissions', :create_repository_tag do
+      let(:boundary_object) { project }
+      let(:request) do
+        post api(route, personal_access_token: pat), params: { tag_name: tag_name, ref: 'master' }
+      end
+    end
+
     shared_examples_for 'repository new tag' do
       it 'creates a new tag' do
         post api(route, current_user), params: { tag_name: tag_name, ref: 'master' }
@@ -531,6 +559,13 @@ RSpec.describe API::Tags, feature_category: :source_code_management do
       end
     end
 
+    it_behaves_like 'authorizing granular token permissions', :delete_repository_tag do
+      let(:boundary_object) { project }
+      let(:request) do
+        delete api(route, personal_access_token: pat)
+      end
+    end
+
     shared_examples_for 'repository delete tag' do
       it 'deletes a tag' do
         delete api(route, current_user)
@@ -647,6 +682,13 @@ RSpec.describe API::Tags, feature_category: :source_code_management do
       let(:x509_certificate) { signature.x509_certificate }
       let(:x509_issuer) { x509_certificate.x509_issuer }
 
+      it_behaves_like 'authorizing granular token permissions', :read_repository_tag_signature do
+        let(:boundary_object) { project }
+        let(:request) do
+          get api(route, personal_access_token: pat)
+        end
+      end
+
       it 'returns correct JSON' do
         get api(route, current_user)
 
