@@ -194,7 +194,8 @@ RSpec.describe IdeController, feature_category: :web_ide do
       it 'updates the content security policy with the correct frame sources' do
         subject
 
-        expect(find_csp_directive('frame-src')).to include("http://www.example.com/assets/webpack/", "https://*.web-ide.gitlab-static.net/",
+        expect(find_csp_directive('frame-src')).to include("http://www.example.com/assets/webpack/",
+          "https://*.cdn.web-ide.gitlab-static.net/",
           ide_oauth_redirect_url, oauth_authorization_url)
         expect(find_csp_directive('worker-src')).to include("http://www.example.com/assets/webpack/")
       end
