@@ -6,7 +6,7 @@ RSpec.describe Organizations::GroupsController, :routing, feature_category: :org
   let_it_be(:organization) { build(:organization) }
   let_it_be(:project) { create(:project, organization: organization) }
 
-  it 'routes to projects#edit' do
+  specify 'to projects#edit' do
     expect(get("/-/organizations/#{organization.path}/projects/#{project.path_with_namespace}/edit"))
       .to route_to(
         'organizations/projects#edit', organization_path: organization.path,
