@@ -5,7 +5,7 @@ require 'spec_helper'
 RSpec.describe Organizations::SettingsController, :routing, feature_category: :organization do
   let_it_be(:organization) { build(:organization) }
 
-  it 'routes to settings#general' do
+  specify 'to settings#general' do
     expect(get("/-/organizations/#{organization.path}/settings/general"))
       .to route_to('organizations/settings#general', organization_path: organization.path)
   end
