@@ -3,8 +3,8 @@
 require 'spec_helper'
 
 RSpec.describe ::Authz::Tokens::AuthorizeGranularScopesService, feature_category: :permissions do
-  let_it_be(:boundary) { Authz::Boundary.for(nil) }
-  let_it_be(:granular_pat) { create(:granular_pat, namespace: boundary.namespace, permissions: :create_member_role) }
+  let_it_be(:boundary) { Authz::Boundary.for(:instance) }
+  let_it_be(:granular_pat) { create(:granular_pat, boundary: boundary, permissions: :create_member_role) }
   let_it_be(:token) { granular_pat }
   let_it_be(:permissions) { :create_member_role }
 
