@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-RSpec.describe ::Ci::Runners::CreateRunnerService, "#execute", feature_category: :runner do
+RSpec.describe ::Ci::Runners::CreateRunnerService, "#execute", feature_category: :runner_core do
   subject(:execute) { described_class.new(user: current_user, params: params).execute }
 
   let(:runner) { execute.payload[:runner] }
