@@ -164,8 +164,6 @@ RSpec.describe DraftNotes::PublishService, feature_category: :code_review_workfl
     it 'invalidates cache counts' do
       expect(merge_request.assignees).to all(receive(:invalidate_merge_request_cache_counts))
 
-      stub_feature_flags(merge_request_dashboard: true)
-
       publish
     end
 
@@ -197,6 +195,8 @@ RSpec.describe DraftNotes::PublishService, feature_category: :code_review_workfl
         notes = merge_request.notes.order(id: :asc)
         expect(notes.first.diff_note_positions).to be_any
         expect(notes.last.diff_note_positions).to be_any
+        expect(notes.flat_map(&:diff_note_positions).pluck(:namespace_id).uniq)
+          .to contain_exactly(project.project_namespace_id)
       end
 
       it 'keeps around the commits of each published note' do
