@@ -122,22 +122,26 @@ RSpec.describe Notes::QuickActionsService, feature_category: :text_editors do
           context 'when not specifying a date' do
             let(:note_text) { "/spend 1h" }
 
-            it 'does not include the date' do
-              _, update_params = service.execute(note)
-              service.apply_updates(update_params, note)
+            it 'includes the date, time and timezone' do
+              allow_any_instance_of(User).to receive(:timezone).and_return('Hawaii') # rubocop:disable RSpec/AnyInstanceOf -- It's not the next instance
 
-              expect(Note.last.note).to eq('added 1h of time spent')
+              travel_to(Time.utc(2025, 5, 1)) do
+                _, update_params = service.execute(note)
+                service.apply_updates(update_params, note)
+
+                expect(Note.last.note).to eq('added 1h of time spent at 2025-04-30 14:00:00 -1000')
+              end
             end
           end
 
           context 'when specifying a date' do
             let(:note_text) { "/spend 1h 2020-01-01" }
 
-            it 'does include the date' do
+            it 'includes the date, time and timezone' do
               _, update_params = service.execute(note)
               service.apply_updates(update_params, note)
 
-              expect(Note.last.note).to eq('added 1h of time spent at 2020-01-01')
+              expect(Note.last.note).to eq('added 1h of time spent at 2020-01-01 12:00:00 UTC')
             end
           end
         end
@@ -349,38 +353,6 @@ RSpec.describe Notes::QuickActionsService, feature_category: :text_editors do
       end
     end
 
-    describe '/remind_me' do
-      let(:issue) { create(:issue, project: project, milestone: milestone) }
-      let(:note_text) { '/remind_me 1d' }
-      let(:note) { create(:note_on_issue, noteable: issue, project: project, note: note_text) }
-
-      context 'on an issue' do
-        it 'leaves the note empty' do
-          expect(execute(note)).to be_empty
-        end
-
-        it 'attempts to set a reminder' do
-          expect(Issuable::CreateReminderWorker).to receive(:perform_in)
-
-          execute(note)
-        end
-      end
-
-      context 'on a merge request' do
-        let(:note_mr) { create(:note_on_merge_request, project: project, note: note_text) }
-
-        it 'leaves the note empty' do
-          expect(execute(note_mr)).to be_empty
-        end
-
-        it 'attempts to set a reminder' do
-          expect(Issuable::CreateReminderWorker).to receive(:perform_in)
-
-          execute(note)
-        end
-      end
-    end
-
     describe '/add_child' do
       let_it_be_with_reload(:noteable) { create(:work_item, :objective, project: project) }
       let_it_be(:child) { create(:work_item, :objective, project: project) }
@@ -776,6 +748,36 @@ RSpec.describe Notes::QuickActionsService, feature_category: :text_editors do
           end
         end
       end
+
+      describe '/subscribe or /unsubscribe' do
+        shared_examples 'when applying to work_item' do
+          it 'leaves the note empty' do
+            expect(execute(note)).to be_empty
+          end
+
+          it 'triggers work item updated subscription' do
+            expect(GraphqlTriggers).to receive(:work_item_updated).with(work_item)
+
+            execute(note)
+          end
+        end
+
+        describe '/subscribe' do
+          let_it_be(:note_text) { '/subscribe' }
+
+          it_behaves_like 'when applying to work_item'
+        end
+
+        describe '/unsubscribe' do
+          let_it_be(:note_text) { '/unsubscribe' }
+
+          before do
+            work_item.subscribe(maintainer, project)
+          end
+
+          it_behaves_like 'when applying to work_item'
+        end
+      end
     end
   end
 
