@@ -3,7 +3,10 @@
 require 'spec_helper'
 
 RSpec.describe Projects::AdjournedDeletionService, feature_category: :groups_and_projects do
-  let(:project) { create(:project, marked_for_deletion_at: 10.days.ago, marked_for_deletion_by_user_id: user&.id) }
+  let(:project) do
+    create(:project, marked_for_deletion_at: 10.days.ago, marked_for_deletion_by_user_id: user&.id).reload
+  end
+
   let(:resource) { project }
   let(:destroy_worker) { ProjectDestroyWorker }
   let(:destroy_worker_params) { [project.id, user.id, {}] }
