@@ -28,6 +28,19 @@ RSpec.describe Projects::ArchiveService, feature_category: :groups_and_projects
         project.add_owner(user)
       end
 
+      context 'when project is already archived' do
+        before do
+          project.update!(archived: true)
+        end
+
+        it 'returns already archived error' do
+          result = service.execute
+
+          expect(result).to be_error
+          expect(result.message).to eq('Project is already archived.')
+        end
+      end
+
       context 'when project ancestors are already archived' do
         before do
           group.update!(archived: true)
@@ -41,6 +54,30 @@ RSpec.describe Projects::ArchiveService, feature_category: :groups_and_projects
         end
       end
 
+      context 'when group is scheduled for deletion' do
+        let_it_be(:deletion_schedule) { create(:group_deletion_schedule, group: group) }
+
+        it 'returns scheduled deletion error' do
+          result = service.execute
+
+          expect(result).to be_error
+          expect(result.message).to eq('Cannot archive project since it is scheduled for deletion.')
+        end
+      end
+
+      context 'when project is scheduled for deletion' do
+        before do
+          project.update!(marked_for_deletion_at: Date.current)
+        end
+
+        it 'returns scheduled deletion error' do
+          result = service.execute
+
+          expect(result).to be_error
+          expect(result.message).to eq('Cannot archive project since it is scheduled for deletion.')
+        end
+      end
+
       context 'when project ancestors are not archived' do
         context 'when archiving project fails' do
           before do
@@ -81,6 +118,11 @@ RSpec.describe Projects::ArchiveService, feature_category: :groups_and_projects
             expect(result).to be_success
           end
 
+          it 'updates the project_namespace state' do
+            expect { service.execute }.to change { project.project_namespace.state }
+              .from(Namespaces::Stateful::STATES[:ancestor_inherited]).to(Namespaces::Stateful::STATES[:archived])
+          end
+
           it 'updates the project archived status to true' do
             expect { service.execute }.to change { project.reload.archived }.from(false).to(true)
           end
@@ -101,18 +143,6 @@ RSpec.describe Projects::ArchiveService, feature_category: :groups_and_projects
             service.execute
           end
 
-          context 'with feature flag destroy_fork_network_on_archive disabled' do
-            before do
-              stub_feature_flags(destroy_fork_network_on_archive: false)
-            end
-
-            it 'does not unlink fork' do
-              expect(unlink_fork_service).not_to receive(:execute)
-
-              service.execute
-            end
-          end
-
           it 'publishes a ProjectArchivedEvent' do
             expect { service.execute }.to publish_event(Projects::ProjectArchivedEvent)
               .with(
