@@ -3,6 +3,8 @@
 require 'spec_helper'
 
 RSpec.describe Projects::RestoreService, feature_category: :groups_and_projects do
+  include Namespaces::StatefulHelpers
+
   let_it_be(:user) { create(:user, :with_namespace) }
 
   subject(:execute) { described_class.new(project, user).execute }
@@ -78,7 +80,7 @@ RSpec.describe Projects::RestoreService, feature_category: :groups_and_projects
       end
 
       context "when the original project path does not contain the -#{suffix}- suffix" do
-        let_it_be(:project) do
+        let_it_be_with_reload(:project) do
           create(
             :project,
             :repository,
@@ -97,6 +99,31 @@ RSpec.describe Projects::RestoreService, feature_category: :groups_and_projects
           expect { execute }.not_to change { project.name }
         end
       end
+
+      context 'when project_namespace state is deletion_scheduled' do
+        before do
+          set_state(project.project_namespace, :deletion_scheduled)
+        end
+
+        it 'changes the state of the project' do
+          expect { execute }.to change { project.project_namespace.state }
+            .from(Namespaces::Stateful::STATES[:deletion_scheduled])
+            .to(Namespaces::Stateful::STATES[:ancestor_inherited])
+        end
+      end
+
+      context 'when deletion schedule creation fails' do
+        before do
+          allow(project).to receive(:cancel_deletion).and_return(false)
+          allow(project.project_namespace).to receive_message_chain(:errors, :full_messages)
+                                                .and_return(['state transition error'])
+        end
+
+        it 'returns error with resource errors' do
+          expect(execute).to be_error
+          expect(execute.message).to eq('state transition error')
+        end
+      end
     end
   end
 
