@@ -59,7 +59,7 @@ RSpec.describe Snippets::CreateService, feature_category: :source_code_managemen
         end
       end
 
-      context 'when user is an admin' do
+      context 'when user is an admin', :enable_admin_mode do
         it 'responds with success' do
           expect(subject).to be_success
         end
@@ -408,9 +408,9 @@ RSpec.describe Snippets::CreateService, feature_category: :source_code_managemen
       end
 
       context 'when Current.organization is not set' do
-        it 'uses user first organization' do
+        it 'uses user organization' do
           expect(snippet.organization_id)
-            .to eq(user.organizations.first.id)
+            .to eq(user.organization.id)
         end
       end
 
