@@ -125,7 +125,7 @@ RSpec.describe SystemNoteService, feature_category: :shared do
         expect(service).to receive(:relate_issuable).with(noteable_ref)
       end
 
-      described_class.relate_issuable(noteable, noteable_ref, double)
+      described_class.relate_issuable(noteable, noteable_ref, author)
     end
   end
 
@@ -142,7 +142,7 @@ RSpec.describe SystemNoteService, feature_category: :shared do
         expect(service).to receive(:unrelate_issuable).with(noteable_ref)
       end
 
-      described_class.unrelate_issuable(noteable, noteable_ref, double)
+      described_class.unrelate_issuable(noteable, noteable_ref, author)
     end
   end
 
@@ -319,7 +319,7 @@ RSpec.describe SystemNoteService, feature_category: :shared do
         expect(service).to receive(:cross_reference).with(mentioned_in)
       end
 
-      described_class.cross_reference(double, mentioned_in, double)
+      described_class.cross_reference(double, mentioned_in, author)
     end
   end
 
@@ -356,7 +356,7 @@ RSpec.describe SystemNoteService, feature_category: :shared do
         expect(service).to receive(:noteable_moved).with(noteable_ref, direction)
       end
 
-      described_class.noteable_moved(double, double, noteable_ref, double, direction: direction)
+      described_class.noteable_moved(double, double, noteable_ref, author, direction: direction)
     end
   end
 
@@ -370,7 +370,7 @@ RSpec.describe SystemNoteService, feature_category: :shared do
         expect(service).to receive(:noteable_cloned).with(noteable_ref, direction, created_at: created_at)
       end
 
-      described_class.noteable_cloned(double, double, noteable_ref, double, direction: direction, created_at: created_at)
+      described_class.noteable_cloned(double, double, noteable_ref, author, direction: direction, created_at: created_at)
     end
   end
 
@@ -551,7 +551,7 @@ RSpec.describe SystemNoteService, feature_category: :shared do
         expect(service).to receive(:discussion_lock)
       end
 
-      described_class.discussion_lock(issuable, double)
+      described_class.discussion_lock(issuable, author)
     end
   end
 
@@ -778,7 +778,7 @@ RSpec.describe SystemNoteService, feature_category: :shared do
         expect(service).to receive(:hierarchy_changed).with(work_item, 'relate')
       end
 
-      described_class.relate_work_item(noteable, work_item, double)
+      described_class.relate_work_item(noteable, work_item, author)
     end
   end
 
@@ -795,7 +795,7 @@ RSpec.describe SystemNoteService, feature_category: :shared do
         expect(service).to receive(:hierarchy_changed).with(work_item, 'unrelate')
       end
 
-      described_class.unrelate_work_item(noteable, work_item, double)
+      described_class.unrelate_work_item(noteable, work_item, author)
     end
   end
 
