@@ -375,39 +375,6 @@ RSpec.describe TodoService, feature_category: :notifications do
       end
     end
 
-    describe '#resolve_todos_with_attributes_for_target' do
-      it 'marks related pending todos to the target for all the users as done' do
-        first_todo = create(:todo, :assigned, user: member, project: project, target: issue, author: author)
-        second_todo = create(:todo, :review_requested, user: john_doe, project: project, target: issue, author: author)
-        another_todo = create(:todo, :assigned, user: john_doe, project: project, target: project, author: author)
-
-        service.resolve_todos_with_attributes_for_target(issue, {})
-
-        expect(first_todo.reload).to be_done
-        expect(second_todo.reload).to be_done
-        expect(another_todo.reload).to be_pending
-      end
-
-      it 'marks related only filtered pending todos to the target for all the users as done' do
-        first_todo = create(:todo, :assigned, user: member, project: project, target: issue, author: author)
-        second_todo = create(:todo, :review_requested, user: john_doe, project: project, target: issue, author: author)
-        another_todo = create(:todo, :assigned, user: john_doe, project: project, target: project, author: author)
-
-        service.resolve_todos_with_attributes_for_target(issue, { action: Todo::ASSIGNED })
-
-        expect(first_todo.reload).to be_done
-        expect(second_todo.reload).to be_pending
-        expect(another_todo.reload).to be_pending
-      end
-
-      it 'fetches the pending todos with users preloaded' do
-        expect(PendingTodosFinder).to receive(:new)
-          .with(a_hash_including(preload_user_association: true)).and_call_original
-
-        service.resolve_todos_with_attributes_for_target(issue, { action: Todo::ASSIGNED })
-      end
-    end
-
     describe '#new_note' do
       let!(:first_todo) { create(:todo, :assigned, user: john_doe, project: project, target: issue, author: author) }
       let!(:second_todo) { create(:todo, :assigned, user: john_doe, project: project, target: issue, author: author) }
@@ -1179,6 +1146,10 @@ RSpec.describe TodoService, feature_category: :notifications do
 
     describe '#new_note' do
       let_it_be(:project) { create(:project, :repository) }
+      let(:mention) { john_doe.to_reference }
+      let(:diff_note_on_merge_request) { create(:diff_note_on_merge_request, project: project, noteable: unassigned_mr, author: author, note: "Hey #{mention}") }
+      let(:addressed_diff_note_on_merge_request) { create(:diff_note_on_merge_request, project: project, noteable: unassigned_mr, author: author, note: "#{mention}, hey!") }
+      let(:legacy_diff_note_on_merge_request) { create(:legacy_diff_note_on_merge_request, project: project, noteable: unassigned_mr, author: author, note: "Hey #{mention}") }
 
       before_all do
         project.add_guest(guest)
@@ -1189,11 +1160,6 @@ RSpec.describe TodoService, feature_category: :notifications do
         project.add_developer(skipped)
       end
 
-      let(:mention) { john_doe.to_reference }
-      let(:diff_note_on_merge_request) { create(:diff_note_on_merge_request, project: project, noteable: unassigned_mr, author: author, note: "Hey #{mention}") }
-      let(:addressed_diff_note_on_merge_request) { create(:diff_note_on_merge_request, project: project, noteable: unassigned_mr, author: author, note: "#{mention}, hey!") }
-      let(:legacy_diff_note_on_merge_request) { create(:legacy_diff_note_on_merge_request, project: project, noteable: unassigned_mr, author: author, note: "Hey #{mention}") }
-
       it 'creates a todo for mentioned user on new diff note' do
         service.new_note(diff_note_on_merge_request, author)
 
@@ -1226,13 +1192,37 @@ RSpec.describe TodoService, feature_category: :notifications do
         second_todo = create(:todo, :pending, :review_requested, user: john_doe, project: project, target: mentioned_mr, author: author)
         third_todo = create(:todo, :pending, :mentioned, user: john_doe, project: project, target: mentioned_mr, author: author)
 
-        review = Review.new(merge_request: mentioned_mr)
-        service.new_review(review, john_doe)
+        service.new_review(mentioned_mr, john_doe)
 
         expect(first_todo.reload).to be_done
         expect(second_todo.reload).to be_done
         expect(third_todo.reload).to be_done
       end
+
+      it 'creates a pending todo for reviewed merge request author and assignees' do
+        service.new_review(assigned_mr, member)
+
+        should_create_todo(user: john_doe, author: member, target: assigned_mr, action: Todo::REVIEW_SUBMITTED)
+        should_create_todo(user: assigned_mr.author, author: member, target: assigned_mr, action: Todo::REVIEW_SUBMITTED)
+      end
+
+      context 'when merge request author is the review author' do
+        it 'does not create a pending todo for reviewed merge request author' do
+          service.new_review(assigned_mr, assigned_mr.author)
+
+          should_create_todo(user: john_doe, author: assigned_mr.author, target: assigned_mr, action: Todo::REVIEW_SUBMITTED)
+          should_not_create_todo(user: assigned_mr.author, author: assigned_mr.author, target: assigned_mr, action: Todo::REVIEW_SUBMITTED)
+        end
+      end
+
+      context 'when merge request assignee is the review author' do
+        it 'does not create a pending todo for reviewed merge request author' do
+          service.new_review(assigned_mr, john_doe)
+
+          should_not_create_todo(user: john_doe, author: john_doe, target: assigned_mr, action: Todo::REVIEW_SUBMITTED)
+          should_create_todo(user: assigned_mr.author, author: john_doe, target: assigned_mr, action: Todo::REVIEW_SUBMITTED)
+        end
+      end
     end
   end
 
@@ -1242,13 +1232,6 @@ RSpec.describe TodoService, feature_category: :notifications do
     let(:issue) { create(:issue, project: project) }
     let(:design) { create(:design, issue: issue) }
 
-    before do
-      enable_design_management
-
-      project.add_guest(author)
-      project.add_developer(john_doe)
-    end
-
     let(:note) do
       build(
         :diff_note_on_design,
@@ -1258,6 +1241,13 @@ RSpec.describe TodoService, feature_category: :notifications do
       )
     end
 
+    before do
+      enable_design_management
+
+      project.add_guest(author)
+      project.add_developer(john_doe)
+    end
+
     it 'creates a todo for mentioned user on new diff note' do
       service.new_note(note, author)
 
@@ -1488,6 +1478,13 @@ RSpec.describe TodoService, feature_category: :notifications do
       expect(another_pending_todo.reload).to be_pending
       expect(another_project_todo.reload).to be_pending
     end
+
+    it 'fetches the pending todos with users preloaded' do
+      expect(PendingTodosFinder).to receive(:new)
+                                      .with(a_hash_including(preload_user_association: true)).and_call_original
+
+      service.resolve_access_request_todos(project_requester)
+    end
   end
 
   describe '#restore_todo' do
