@@ -3,8 +3,6 @@
 require 'spec_helper'
 
 RSpec.describe WorkItems::DataSync::Widgets::Notifications, feature_category: :team_planning do
-  include SentNotificationHelpers
-
   let_it_be(:current_user) { create(:user) }
   let_it_be_with_reload(:work_item) { create(:work_item) }
   let_it_be_with_reload(:subscription1) do
@@ -16,11 +14,11 @@ RSpec.describe WorkItems::DataSync::Widgets::Notifications, feature_category: :t
   end
 
   let_it_be_with_reload(:sent_notification1) do
-    create_sent_notification(project: work_item.project, noteable: work_item, recipient: create(:user))
+    create(:sent_notification, project: work_item.project, noteable: work_item, recipient: create(:user))
   end
 
   let_it_be_with_reload(:sent_notification2) do
-    create_sent_notification(project: work_item.project, noteable: work_item, recipient: create(:user))
+    create(:sent_notification, project: work_item.project, noteable: work_item, recipient: create(:user))
   end
 
   let_it_be(:target_work_item) { create(:work_item) }
@@ -56,22 +54,30 @@ RSpec.describe WorkItems::DataSync::Widgets::Notifications, feature_category: :t
         allow(work_item).to receive(:from_service_desk?).and_return(true)
       end
 
-      context 'when moving work item' do
-        it 'copies notifications from work_item to target_work_item' do
+      context 'when moving work item', :aggregate_failures do
+        it 'copies notifications from work_item to target_work_item and deletes sent_notifications from source' do
           expect(callback).to receive(:new_work_item_subscriptions).and_call_original
           expect(callback).to receive(:new_work_item_sent_notifications).and_call_original
           expect(::Subscription).to receive(:insert_all).and_call_original
-          expect(::SentNotification).to receive(:upsert_all).and_call_original
+          expect(::SentNotification).to receive(:insert_all).and_call_original
 
           expected_subscriptions = work_item.subscriptions.pluck(:user_id)
           expected_sent_notifications = work_item.sent_notifications.pluck(:recipient_id)
+          old_notification_ids = work_item.sent_notifications.pluck(:id)
 
-          callback.after_save_commit
+          expect do
+            callback.after_save_commit
+          end.to change { work_item.sent_notifications.count }.by(-2)
 
           subscriptions = target_work_item.reload.subscriptions.pluck(:user_id)
-          sent_notifications = target_work_item.reload.sent_notifications.pluck(:recipient_id)
+          notification_recipients = target_work_item.reload.sent_notifications.pluck(:recipient_id)
+          new_notification_ids = target_work_item.sent_notifications.pluck(:id)
           expect(subscriptions).to match_array(expected_subscriptions)
-          expect(sent_notifications).to match_array(expected_sent_notifications)
+          expect(notification_recipients).to match_array(expected_sent_notifications)
+          expect(new_notification_ids).not_to match_array(old_notification_ids)
+          expect(target_work_item.sent_notifications.pluck(:namespace_id).uniq).to contain_exactly(
+            target_work_item.namespace_id
+          )
         end
 
         it_behaves_like 'notifies participants'
@@ -84,7 +90,7 @@ RSpec.describe WorkItems::DataSync::Widgets::Notifications, feature_category: :t
           expect(callback).not_to receive(:new_work_item_subscriptions)
           expect(callback).not_to receive(:new_work_item_sent_notifications)
           expect(::Subscription).not_to receive(:insert_all)
-          expect(::SentNotification).not_to receive(:upsert_all)
+          expect(::SentNotification).not_to receive(:insert_all)
 
           callback.after_save_commit
 
@@ -104,7 +110,7 @@ RSpec.describe WorkItems::DataSync::Widgets::Notifications, feature_category: :t
           expect(callback).to receive(:new_work_item_subscriptions).and_call_original
           expect(callback).not_to receive(:new_work_item_sent_notifications)
           expect(::Subscription).to receive(:insert_all).and_call_original
-          expect(::SentNotification).not_to receive(:upsert_all)
+          expect(::SentNotification).not_to receive(:insert_all)
 
           expected_subscriptions = work_item.subscriptions.pluck(:user_id)
 
@@ -127,7 +133,7 @@ RSpec.describe WorkItems::DataSync::Widgets::Notifications, feature_category: :t
         expect(callback).not_to receive(:new_work_item_subscriptions)
         expect(callback).not_to receive(:new_work_item_sent_notifications)
         expect(::Subscription).not_to receive(:insert_all)
-        expect(::SentNotification).not_to receive(:upsert_all)
+        expect(::SentNotification).not_to receive(:insert_all)
 
         callback.after_save_commit
 
@@ -162,8 +168,8 @@ RSpec.describe WorkItems::DataSync::Widgets::Notifications, feature_category: :t
       it 'removes original work item notifications' do
         create(:subscription, subscribable: work_item, user: create(:user), subscribed: true)
         create(:subscription, subscribable: work_item, user: create(:user), subscribed: false)
-        create_sent_notification(project: work_item.project, noteable: work_item, recipient: create(:user))
-        create_sent_notification(project: work_item.project, noteable: work_item, recipient: create(:user))
+        create(:sent_notification, project: work_item.project, noteable: work_item, recipient: create(:user))
+        create(:sent_notification, project: work_item.project, noteable: work_item, recipient: create(:user))
 
         expect(work_item.subscriptions.count).to eq(4)
         expect(work_item.sent_notifications.count).to eq(4)
