@@ -18,7 +18,7 @@ RSpec.describe WorkItems::ParentLinks::DestroyService, feature_category: :team_p
       # Ensure support bot user is created so creation doesn't count towards query limit
       # and we don't try to obtain an exclusive lease within a transaction.
       # See https://gitlab.com/gitlab-org/gitlab/-/issues/509629
-      Users::Internal.support_bot_id
+      create(:support_bot)
     end
 
     before do
