@@ -35,6 +35,7 @@ module ClickHouseHelpers
         %i[id project_id pipeline_id status finished_at created_at started_at queued_at runner_id name
           stage_id]).symbolize_keys
           .merge(
+            stage_name: build.stage_name,
             runner_run_untagged: build.runner&.run_untagged,
             runner_type: Ci::Runner.runner_types[build.runner&.runner_type],
             runner_owner_namespace_id: build.runner&.owner_runner_namespace&.namespace_id,
@@ -67,7 +68,18 @@ module ClickHouseHelpers
     ActiveRecord.default_timezone
   end
 
-  def clickhouse_fixture(table, data, db = :main, &block)
+  def clickhouse_fixture(table_or_models, *args, &block)
+    case table_or_models
+    when String, Symbol then clickhouse_raw_fixture(table_or_models, *args, &block)
+    else clickhouse_model_fixture(table_or_models)
+    end
+  end
+
+  def clickhouse_model_fixture(models)
+    clickhouse_raw_fixture(models.first.class.clickhouse_table_name, models.map(&:to_clickhouse_csv_row))
+  end
+
+  def clickhouse_raw_fixture(table, data, db = :main, &block)
     return if data.empty?
 
     if data.map { |row| row.keys.sort }.uniq.size > 1
