@@ -5,9 +5,10 @@ module RolesHelpers
 
   def assignable_roles
     {
-      owner: [:owner, :maintainer, :planner, :developer, :reporter, :guest],
+      owner: [:owner, :maintainer, :planner, :developer, :security_manager, :reporter, :guest],
       maintainer: [:maintainer, :developer, :reporter, :guest],
       developer: [:developer, :reporter, :guest],
+      security_manager: [:security_manager, :reporter, :guest],
       reporter: [:reporter, :guest],
       planner: [:planner, :guest],
       guest: [:guest]
@@ -17,4 +18,8 @@ module RolesHelpers
   def access_level_value(name)
     Gitlab::Access.sym_options_with_owner[name]
   end
+
+  def testable_roles(include_owner: false)
+    include_owner ? Gitlab::Access.sym_options_with_owner.keys : Gitlab::Access.sym_options.keys
+  end
 end
