@@ -9,6 +9,6 @@ RSpec.shared_context 'with token authenticatable routable token context' do
       .to receive(:random_bytes).with(Authn::TokenField::Generator::RoutableToken::RANDOM_BYTES_LENGTH)
       .and_return(random_bytes)
     allow(Devise).to receive(:friendly_token).and_return(devise_token)
-    stub_config(cell: { enabled: true, id: 1 })
+    stub_config_cell({ enabled: true, id: 1 })
   end
 end
