@@ -49,5 +49,10 @@ RSpec.shared_context 'with container for work items service' do |container_type|
     memberships_container = container.is_a?(Namespaces::ProjectNamespace) ? container.reload.project : container
     memberships_container.add_guest(guest)
     memberships_container.add_reporter(reporter)
+
+    # Ensure support bot user is created so creation doesn't count towards query limit
+    # and we don't try to obtain an exclusive lease within a transaction.
+    # See https://gitlab.com/gitlab-org/gitlab/-/issues/509629
+    create(:support_bot)
   end
 end
