@@ -14,13 +14,17 @@ RSpec.shared_examples 'authorizing granular token permissions' do |permissions|
       request
 
       expect(response).to have_gitlab_http_status(:forbidden)
-      expect(json_response['error']).to eq('insufficient_granular_scope')
-      expect(json_response['error_description']).to eq(message)
+
+      # Only check JSON body if present (GET/POST/etc have bodies, HEAD doesn't)
+      if response.body.present?
+        expect(json_response['error']).to eq('insufficient_granular_scope')
+        expect(json_response['error_description']).to eq(message)
+      end
     end
   end
 
   context 'when authenticating with a legacy personal access token' do
-    let(:pat) { create(:personal_access_token, user:) }
+    let(:pat) { create(:personal_access_token, :admin_mode, user:) }
 
     it_behaves_like 'granting access'
   end
@@ -33,7 +37,7 @@ RSpec.shared_examples 'authorizing granular token permissions' do |permissions|
     end
 
     let(:boundary) { ::Authz::Boundary.for(boundary_object) }
-    let(:pat) { create(:granular_pat, user: user, namespace: boundary.namespace, permissions: assignables) }
+    let(:pat) { create(:granular_pat, user: user, boundary: boundary, permissions: assignables) }
 
     it_behaves_like 'granting access'
 
@@ -54,7 +58,7 @@ RSpec.shared_examples 'authorizing granular token permissions' do |permissions|
 
       let(:message) do
         'Access denied: Your Personal Access Token lacks the required permissions: ' \
-          "[#{Array(permissions).join(', ')}]" + (boundary_object.nil? ? '.' : " for \"#{boundary.path}\".")
+          "[#{Array(permissions).join(', ')}]" + (boundary.path ? " for \"#{boundary.path}\"." : '.')
       end
 
       it_behaves_like 'denying access'
