@@ -109,6 +109,7 @@ RSpec.shared_examples 'deploy token does not get confused with user' do
     expect_disallowed(*guest_permissions)
     expect_disallowed(*reporter_permissions)
     expect_disallowed(*team_member_reporter_permissions)
+    expect_disallowed(*security_manager_permissions)
     expect_disallowed(*developer_permissions)
     expect_disallowed(*maintainer_permissions)
     expect_disallowed(*owner_permissions)
@@ -129,6 +130,7 @@ RSpec.shared_examples 'project policies as guest' do
       specify do
         expect_allowed(*guest_permissions)
         expect_allowed(*public_permissions)
+        expect_disallowed(*security_manager_permissions)
         expect_disallowed(*developer_permissions)
         expect_disallowed(*maintainer_permissions)
         expect_disallowed(*owner_permissions)
@@ -143,6 +145,7 @@ RSpec.shared_examples 'project policies as guest' do
         expect_allowed(*guest_permissions)
         expect_disallowed(*reporter_public_build_permissions)
         expect_disallowed(*team_member_reporter_permissions)
+        expect_disallowed(*security_manager_permissions)
         expect_disallowed(*developer_permissions)
         expect_disallowed(*maintainer_permissions)
         expect_disallowed(*owner_permissions)
@@ -196,6 +199,7 @@ RSpec.shared_examples 'project policies as guest' do
         expect_allowed(*guest_permissions)
         expect_disallowed(*reporter_public_build_permissions)
         expect_disallowed(*team_member_reporter_permissions)
+        expect_disallowed(*security_manager_permissions)
         expect_disallowed(*developer_permissions)
         expect_disallowed(*maintainer_permissions)
         expect_disallowed(*owner_permissions)
@@ -231,6 +235,7 @@ RSpec.shared_examples 'project policies as planner' do
         expect_allowed(*planner_permissions)
         expect_allowed(*(base_reporter_permissions - disallowed_reporter_public_permissions))
         expect_disallowed(*disallowed_reporter_public_permissions)
+        expect_disallowed(*(security_manager_permissions - planner_permissions))
         expect_disallowed(*(developer_permissions - [:create_wiki]))
         expect_disallowed(*(maintainer_permissions - [:admin_wiki]))
         expect_disallowed(*(owner_permissions - [:destroy_issue]))
@@ -248,6 +253,7 @@ RSpec.shared_examples 'project policies as planner' do
         expect_allowed(*(base_reporter_permissions - disallowed_reporter_permissions))
         expect_disallowed(:create_merge_request_in)
         expect_disallowed(*disallowed_reporter_permissions)
+        expect_disallowed(*(security_manager_permissions - planner_permissions))
         expect_disallowed(*(developer_permissions - [:create_wiki]))
         expect_disallowed(*(maintainer_permissions - [:admin_wiki]))
         expect_disallowed(*(owner_permissions - [:destroy_issue]))
@@ -306,6 +312,7 @@ RSpec.shared_examples 'project policies as planner' do
         expect_allowed(*(base_reporter_permissions - disallowed_reporter_permissions))
         expect_disallowed(:create_merge_request_in)
         expect_disallowed(*disallowed_reporter_permissions)
+        expect_disallowed(*(security_manager_permissions - planner_permissions))
         expect_disallowed(*(developer_permissions - [:create_wiki]))
         expect_disallowed(*(maintainer_permissions - [:admin_wiki]))
         expect_disallowed(*(owner_permissions - [:destroy_issue]))
@@ -323,6 +330,7 @@ RSpec.shared_examples 'project policies as reporter' do
       expect_allowed(*guest_permissions)
       expect_allowed(*reporter_permissions)
       expect_allowed(*team_member_reporter_permissions)
+      expect_disallowed(*security_manager_permissions)
       expect_disallowed(*developer_permissions)
       expect_disallowed(*maintainer_permissions)
       expect_disallowed(*owner_permissions)
@@ -346,6 +354,7 @@ RSpec.shared_examples 'project policies as reporter' do
         expect_allowed(*guest_permissions)
         expect_allowed(*reporter_permissions)
         expect_allowed(*team_member_reporter_permissions)
+        expect_disallowed(*security_manager_permissions)
         expect_disallowed(*developer_permissions)
         expect_disallowed(*maintainer_permissions)
         expect_disallowed(*owner_permissions)
@@ -354,6 +363,50 @@ RSpec.shared_examples 'project policies as reporter' do
   end
 end
 
+RSpec.shared_examples 'project policies as security_manager' do
+  context 'abilities for non-public projects' do
+    let(:project) { private_project }
+    let(:current_user) { security_manager }
+
+    specify do
+      expect_allowed(*guest_permissions)
+      expect_allowed(*(security_manager_permissions - planner_permissions))
+      expect_allowed(*reporter_permissions)
+      expect_allowed(*team_member_reporter_permissions)
+      expect_allowed(*security_manager_permissions)
+      expect_disallowed(*(developer_permissions - security_manager_permissions))
+      expect_disallowed(*(maintainer_permissions - security_manager_permissions))
+      expect_disallowed(*(owner_permissions - security_manager_permissions))
+    end
+
+    it_behaves_like 'deploy token does not get confused with user' do
+      let(:user_id) { security_manager.id }
+    end
+
+    it_behaves_like 'archived project policies' do
+      let(:regular_abilities) { security_manager_permissions }
+    end
+  end
+
+  context 'as an inherited member from the group' do
+    context 'abilities for private projects' do
+      let(:project) { private_project_in_group }
+      let(:current_user) { inherited_security_manager }
+
+      specify do
+        expect_allowed(*guest_permissions)
+        expect_allowed(*(security_manager_permissions - planner_permissions))
+        expect_allowed(*reporter_permissions)
+        expect_allowed(*team_member_reporter_permissions)
+        expect_allowed(*security_manager_permissions)
+        expect_disallowed(*(developer_permissions - security_manager_permissions))
+        expect_disallowed(*(maintainer_permissions - security_manager_permissions))
+        expect_disallowed(*(owner_permissions - security_manager_permissions))
+      end
+    end
+  end
+end
+
 RSpec.shared_examples 'project policies as developer' do
   context 'abilities for non-public projects' do
     let(:project) { private_project }
@@ -363,6 +416,7 @@ RSpec.shared_examples 'project policies as developer' do
       expect_allowed(*guest_permissions)
       expect_allowed(*reporter_permissions)
       expect_allowed(*team_member_reporter_permissions)
+      expect_allowed(*(developer_permissions - security_manager_permissions))
       expect_allowed(*developer_permissions)
       expect_disallowed(*maintainer_permissions)
       expect_disallowed(*owner_permissions)
@@ -386,6 +440,7 @@ RSpec.shared_examples 'project policies as developer' do
         expect_allowed(*guest_permissions)
         expect_allowed(*reporter_permissions)
         expect_allowed(*team_member_reporter_permissions)
+        expect_allowed(*(developer_permissions - security_manager_permissions))
         expect_allowed(*developer_permissions)
         expect_disallowed(*maintainer_permissions)
         expect_disallowed(*owner_permissions)
@@ -403,6 +458,7 @@ RSpec.shared_examples 'project policies as maintainer' do
       expect_allowed(*guest_permissions)
       expect_allowed(*reporter_permissions)
       expect_allowed(*team_member_reporter_permissions)
+      expect_allowed(*(maintainer_permissions - security_manager_permissions))
       expect_allowed(*developer_permissions)
       expect_allowed(*maintainer_permissions)
       expect_disallowed(*owner_permissions)
@@ -428,6 +484,7 @@ RSpec.shared_examples 'project policies as owner' do
       expect_allowed(*planner_permissions)
       expect_allowed(*reporter_permissions)
       expect_allowed(*team_member_reporter_permissions)
+      expect_allowed(*security_manager_permissions)
       expect_allowed(*developer_permissions)
       expect_allowed(*maintainer_permissions)
       expect_allowed(*owner_permissions)
@@ -452,7 +509,8 @@ RSpec.shared_examples 'project policies as organization owner' do
       expect_allowed(*guest_permissions)
       expect_allowed(*planner_permissions)
       expect_allowed(*reporter_permissions)
-      expect_disallowed(*team_member_reporter_permissions)
+      expect_allowed(*team_member_reporter_permissions)
+      expect_allowed(*security_manager_permissions)
       expect_allowed(*developer_permissions)
       expect_allowed(*maintainer_permissions)
       expect_allowed(*owner_permissions)
@@ -484,7 +542,8 @@ RSpec.shared_examples 'project policies as admin with admin mode' do
       expect_allowed(*guest_permissions)
       expect_allowed(*planner_permissions)
       expect_allowed(*reporter_permissions)
-      expect_disallowed(*team_member_reporter_permissions)
+      expect_allowed(*team_member_reporter_permissions)
+      expect_allowed(*security_manager_permissions)
       expect_allowed(*developer_permissions)
       expect_allowed(*maintainer_permissions)
       expect_allowed(*admin_permissions)
