@@ -3,16 +3,9 @@
 require 'spec_helper'
 
 RSpec.describe Ci::Slsa::PublishProvenanceWorker, feature_category: :artifact_security do
-  let_it_be(:build) { create(:ci_build, :artifacts, :finished) }
-  let_it_be(:provenance_statement) { create(:provenance_statement) }
   let(:worker) { described_class.new }
 
-  let(:file_contents) { statement_artifact.file.file.read }
-  let(:statement_artifact) { statement_artifacts.first }
-
-  before do
-    allow(Ci::Slsa::ProvenanceStatement).to receive(:from_build).with(build).and_return(provenance_statement)
-  end
+  include_context 'with build, pipeline and artifacts'
 
   describe '#perform' do
     subject(:perform) { worker.perform(build.id) }
@@ -33,6 +26,14 @@ RSpec.describe Ci::Slsa::PublishProvenanceWorker, feature_category: :artifact_se
     it_behaves_like 'an idempotent worker' do
       let(:job_args) { [build.id] }
 
+      before do
+        # TODO: remove mocking once database persistence is in place in PublishProvenanceService.
+        upload_statement_service = instance_double(Ci::Slsa::PublishProvenanceService)
+        allow(Ci::Slsa::PublishProvenanceService)
+          .to receive(:new).with(build).and_return(upload_statement_service)
+        allow(upload_statement_service).to receive(:execute).twice
+      end
+
       it 'does not crash when called twice' do
         expect { perform_idempotent_work }.not_to raise_error
       end
