@@ -69,6 +69,7 @@ RSpec.describe WorkerAttributes, feature_category: :shared do
       :get_deduplicate_strategy               | :deduplicate                       | :until_executing | [:none]      | {} | :none
       :get_max_concurrency_limit_percentage   | :max_concurrency_limit_percentage  | 0.25             | 0.5          | {} | 0.5
       :get_concurrency_limit                  | :concurrency_limit                 | 0                | [-> { 5 }]   | {} | 5
+      :get_concurrency_limit                  | :concurrency_limit                 | 0                | [-> { 0 }]   | {} | 0
 
       :get_deduplication_options              | :deduplicate                       | {}               | [:none, { including_scheduled: true }] | {} | { including_scheduled: true }
       :database_health_check_attrs            | :defer_on_database_health_signal   | nil              | [:gitlab_main, [:users], 1.minute]     | {} | { gitlab_schema: :gitlab_main, tables: [:users], delay_by: 1.minute, block: nil }
@@ -489,16 +490,6 @@ RSpec.describe WorkerAttributes, feature_category: :shared do
           expect(get_concurrency_limit).to eq(0)
         end
       end
-
-      context 'when use_max_concurrency_limit_percentage_as_default_limit FF is disabled' do
-        before do
-          stub_feature_flags(use_max_concurrency_limit_percentage_as_default_limit: false)
-        end
-
-        it 'returns 0' do
-          expect(get_concurrency_limit).to eq(0)
-        end
-      end
     end
   end
 end
