@@ -55,6 +55,24 @@ RSpec.describe Issuable::RelatedLinksCreateWorker, feature_category: :portfolio_
       let(:job_args) { params }
     end
 
+    context 'with tracking work item events' do
+      let(:work_item) { issuable }
+      let(:current_user) { user }
+
+      context 'for relates_to links' do
+        before do
+          params.merge!(link_ids: [link1.id], link_type: 'relates_to')
+        end
+
+        def execute_service
+          described_class.new.perform(params)
+        end
+
+        it_behaves_like 'tracks work item event', :work_item, :current_user,
+          Gitlab::WorkItems::Instrumentation::EventActions::RELATED_ITEM_ADD, :execute_service
+      end
+    end
+
     context 'when params contain errors' do
       it 'does nothing when user is not found' do
         params['user_id'] = non_existing_record_id
