@@ -19,6 +19,8 @@ import (
 
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/config"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/gitaly"
+	"gitlab.com/gitlab-org/gitlab/workhorse/internal/healthcheck"
+	"gitlab.com/gitlab-org/gitlab/workhorse/internal/listener"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/queueing"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/redis"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/secret"
@@ -68,20 +70,16 @@ func main() {
 
 type alreadyPrintedError struct{ error }
 
-// buildConfig may print messages to os.Stderr if err != nil. If err is
-// of type alreadyPrintedError it has already been printed.
-func buildConfig(arg0 string, args []string) (*bootConfig, *config.Config, error) {
-	boot := &bootConfig{}
-	cfg := config.NewDefaultConfig()
-	cfg.Version = Version
-	fset := flag.NewFlagSet(arg0, flag.ContinueOnError)
+// setupFlagSet initializes and configures the flag set for command line parsing
+func setupFlagSet(arg0 string, boot *bootConfig, cfg *config.Config) (fset *flag.FlagSet, configFile, authBackend, cableBackend *string) {
+	fset = flag.NewFlagSet(arg0, flag.ContinueOnError)
 	fset.Usage = func() {
 		_, _ = fmt.Fprintf(fset.Output(), "Usage of %s:\n", arg0)
 		_, _ = fmt.Fprintf(fset.Output(), "\n  %s [OPTIONS]\n\nOptions:\n", arg0)
 		fset.PrintDefaults()
 	}
 
-	configFile := fset.String("config", "", "TOML file to load config from")
+	configFile = fset.String("config", "", "TOML file to load config from")
 
 	fset.StringVar(&boot.secretPath, "secretPath", "./.gitlab_workhorse_secret", "File with secret key to authenticate with authBackend")
 	fset.StringVar(&boot.listenAddr, "listenAddr", "localhost:8181", "Listen address for HTTP server")
@@ -96,11 +94,11 @@ func buildConfig(arg0 string, args []string) (*bootConfig, *config.Config, error
 	fset.BoolVar(&boot.printVersion, "version", false, "Print version and exit")
 
 	// gitlab-rails backend
-	authBackend := fset.String("authBackend", upstream.DefaultBackend.String(), "Authentication/authorization backend")
+	authBackend = fset.String("authBackend", upstream.DefaultBackend.String(), "Authentication/authorization backend")
 	fset.StringVar(&cfg.Socket, "authSocket", "", "Optional: Unix domain socket to dial authBackend at")
 
 	// actioncable backend
-	cableBackend := fset.String("cableBackend", "", "ActionCable backend")
+	cableBackend = fset.String("cableBackend", "", "ActionCable backend")
 	fset.StringVar(&cfg.CableSocket, "cableSocket", "", "Optional: Unix domain socket to dial cableBackend at")
 
 	fset.StringVar(&cfg.DocumentRoot, "documentRoot", "public", "Path to static files content")
@@ -112,6 +110,18 @@ func buildConfig(arg0 string, args []string) (*bootConfig, *config.Config, error
 	fset.DurationVar(&cfg.APICILongPollingDuration, "apiCiLongPollingDuration", 50, "Long polling duration for job requesting for runners")
 	fset.BoolVar(&cfg.PropagateCorrelationID, "propagateCorrelationID", false, "Reuse existing Correlation-ID from the incoming request header `X-Request-ID` if present")
 
+	return fset, configFile, authBackend, cableBackend
+}
+
+// buildConfig may print messages to os.Stderr if err != nil. If err is
+// of type alreadyPrintedError it has already been printed.
+func buildConfig(arg0 string, args []string) (*bootConfig, *config.Config, error) {
+	boot := &bootConfig{}
+	cfg := config.NewDefaultConfig()
+	cfg.Version = Version
+
+	fset, configFile, authBackend, cableBackend := setupFlagSet(arg0, boot, cfg)
+
 	if err := fset.Parse(args); err != nil {
 		return nil, nil, alreadyPrintedError{err}
 	}
@@ -160,7 +170,13 @@ func buildConfig(arg0 string, args []string) (*bootConfig, *config.Config, error
 	cfg.TrustedCIDRsForXForwardedFor = cfgFromFile.TrustedCIDRsForXForwardedFor
 	cfg.TrustedCIDRsForPropagation = cfgFromFile.TrustedCIDRsForPropagation
 	cfg.Listeners = cfgFromFile.Listeners
+	cfg.HealthCheckListener = cfgFromFile.HealthCheckListener
+
+	// Apply default health check configuration if not provided
+	cfg.ApplyHealthCheckDefaults()
+
 	cfg.CircuitBreakerConfig = cfgFromFile.CircuitBreakerConfig
+	cfg.AdoptCfRayHeader = cfgFromFile.AdoptCfRayHeader
 
 	return boot, cfg, nil
 }
@@ -224,7 +240,7 @@ func run(boot bootConfig, cfg config.Config) error {
 
 	monitoringOpts := []monitoring.Option{monitoring.WithBuildInformation(Version, BuildTime)}
 	if cfg.MetricsListener != nil {
-		l, err = newListener("metrics", *cfg.MetricsListener)
+		l, err = listener.New("metrics", *cfg.MetricsListener)
 		if err != nil {
 			return err
 		}
@@ -267,7 +283,14 @@ func run(boot bootConfig, cfg config.Config) error {
 
 	gitaly.InitializeSidechannelRegistry(accessLogger)
 
-	up := wrapRaven(upstream.NewUpstream(cfg, accessLogger, watchKeyFn, rdb))
+	// Initialize health check server
+	healthCheckServer, healthCancel, err := healthcheck.InitializeAndStart(cfg, accessLogger, finalErrors)
+	if err != nil {
+		return err
+	}
+	if healthCancel != nil {
+		defer healthCancel()
+	}
 
 	done := make(chan os.Signal, 1)
 	signal.Notify(done, syscall.SIGINT, syscall.SIGTERM)
@@ -279,7 +302,7 @@ func run(boot bootConfig, cfg config.Config) error {
 	var listeners []net.Listener
 	oldUmask := syscall.Umask(boot.listenUmask)
 	for _, cfg := range append(cfg.Listeners, listenerFromBootConfig) {
-		l, err := newListener("upstream", cfg)
+		l, err := listener.New("upstream", cfg)
 		if err != nil {
 			return err
 		}
@@ -287,7 +310,18 @@ func run(boot bootConfig, cfg config.Config) error {
 	}
 	syscall.Umask(oldUmask)
 
-	srv := &http.Server{Handler: up}
+	shutdownCh := make(chan struct{})
+	upgradedConnsManager := &upstream.UpgradedConnsManager{}
+	up := upstream.NewUpstream(
+		cfg,
+		accessLogger,
+		watchKeyFn,
+		rdb,
+		healthCheckServer,
+		shutdownCh,
+		upgradedConnsManager,
+	)
+	srv := &http.Server{Handler: wrapRaven(up)}
 
 	for _, l := range listeners {
 		go func(l net.Listener) { finalErrors <- srv.Serve(l) }(l)
@@ -299,11 +333,30 @@ func run(boot bootConfig, cfg config.Config) error {
 	case sig := <-done:
 		log.WithFields(log.Fields{"shutdown_timeout_s": cfg.ShutdownTimeout.Duration.Seconds(), "signal": sig.String()}).Infof("shutdown initiated")
 
+		if healthCheckServer != nil {
+			healthCheckServer.InitiateShutdown()
+			// Signal upstream to stop accepting long polling requests because
+			// requests can arrive during the graceful shutdown time.
+			close(shutdownCh)
+			// Kick out any long poll requests
+			redisKeyWatcher.Shutdown()
+
+			// Wait for the graceful shutdown delay to complete before shutting down the server
+			gracefulShutdownDelay := healthCheckServer.GetGracefulShutdownDelay()
+			if gracefulShutdownDelay > 0 {
+				log.WithField("shutdown_delay_s", gracefulShutdownDelay.Seconds()).Info("Waiting for graceful shutdown delay")
+
+				go upgradedConnsManager.Shutdown(gracefulShutdownDelay)
+
+				time.Sleep(gracefulShutdownDelay)
+			}
+		} else {
+			redisKeyWatcher.Shutdown()
+		}
+
 		ctx, cancel := context.WithTimeout(context.Background(), cfg.ShutdownTimeout.Duration) // lint:allow context.Background
 		defer cancel()
 
-		redisKeyWatcher.Shutdown()
-
 		return srv.Shutdown(ctx)
 	}
 }
